/*
! tailwindcss v3.2.7 | MIT License | https://tailwindcss.com
*/

/*
1. Prevent padding and border from affecting element width. (https://github.com/mozdevs/cssremedy/issues/4)
2. Allow adding a border to an element by just adding a border-width. (https://github.com/tailwindcss/tailwindcss/pull/116)
*/

*,
::before,
::after {
  box-sizing: border-box;
  /* 1 */
  border-width: 0;
  /* 2 */
  border-style: solid;
  /* 2 */
  border-color: #d0d7de;
  /* 2 */
}

::before,
::after {
  --tw-content: '';
}

/*
1. Use a consistent sensible line-height in all browsers.
2. Prevent adjustments of font size after orientation changes in iOS.
3. Use a more readable tab size.
4. Use the user's configured `sans` font-family by default.
5. Use the user's configured `sans` font-feature-settings by default.
*/

html {
  line-height: 1.5;
  /* 1 */
  -webkit-text-size-adjust: 100%;
  /* 2 */
  -moz-tab-size: 4;
  /* 3 */
  -o-tab-size: 4;
     tab-size: 4;
  /* 3 */
  font-family: Ubuntu, sans-serif;
  /* 4 */
  font-feature-settings: normal;
  /* 5 */
}

/*
1. Remove the margin in all browsers.
2. Inherit line-height from `html` so users can set them as a class directly on the `html` element.
*/

body {
  margin: 0;
  /* 1 */
  line-height: inherit;
  /* 2 */
}

/*
1. Add the correct height in Firefox.
2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)
3. Ensure horizontal rules are visible by default.
*/

hr {
  height: 0;
  /* 1 */
  color: inherit;
  /* 2 */
  border-top-width: 1px;
  /* 3 */
}

/*
Add the correct text decoration in Chrome, Edge, and Safari.
*/

abbr:where([title]) {
  -webkit-text-decoration: underline dotted;
          text-decoration: underline dotted;
}

/*
Remove the default font size and weight for headings.
*/

h1,
h2,
h3,
h4,
h5,
h6 {
  font-size: inherit;
  font-weight: inherit;
}

/*
Reset links to optimize for opt-in styling instead of opt-out.
*/

a {
  color: inherit;
  text-decoration: inherit;
}

/*
Add the correct font weight in Edge and Safari.
*/

b,
strong {
  font-weight: bolder;
}

/*
1. Use the user's configured `mono` font family by default.
2. Correct the odd `em` font sizing in all browsers.
*/

code,
kbd,
samp,
pre {
  font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */
}

/*
Add the correct font size in all browsers.
*/

small {
  font-size: 80%;
}

/*
Prevent `sub` and `sup` elements from affecting the line height in all browsers.
*/

sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sub {
  bottom: -0.25em;
}

sup {
  top: -0.5em;
}

/*
1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)
2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)
3. Remove gaps between table borders by default.
*/

table {
  text-indent: 0;
  /* 1 */
  border-color: inherit;
  /* 2 */
  border-collapse: collapse;
  /* 3 */
}

/*
1. Change the font styles in all browsers.
2. Remove the margin in Firefox and Safari.
3. Remove default padding in all browsers.
*/

button,
input,
optgroup,
select,
textarea {
  font-family: inherit;
  /* 1 */
  font-size: 100%;
  /* 1 */
  font-weight: inherit;
  /* 1 */
  line-height: inherit;
  /* 1 */
  color: inherit;
  /* 1 */
  margin: 0;
  /* 2 */
  padding: 0;
  /* 3 */
}

/*
Remove the inheritance of text transform in Edge and Firefox.
*/

button,
select {
  text-transform: none;
}

/*
1. Correct the inability to style clickable types in iOS and Safari.
2. Remove default button styles.
*/

button,
[type='button'],
[type='reset'],
[type='submit'] {
  -webkit-appearance: button;
  /* 1 */
  background-color: transparent;
  /* 2 */
  background-image: none;
  /* 2 */
}

/*
Use the modern Firefox focus style for all focusable elements.
*/

:-moz-focusring {
  outline: auto;
}

/*
Remove the additional `:invalid` styles in Firefox. (https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737)
*/

:-moz-ui-invalid {
  box-shadow: none;
}

/*
Add the correct vertical alignment in Chrome and Firefox.
*/

progress {
  vertical-align: baseline;
}

/*
Correct the cursor style of increment and decrement buttons in Safari.
*/

::-webkit-inner-spin-button,
::-webkit-outer-spin-button {
  height: auto;
}

/*
1. Correct the odd appearance in Chrome and Safari.
2. Correct the outline style in Safari.
*/

[type='search'] {
  -webkit-appearance: textfield;
  /* 1 */
  outline-offset: -2px;
  /* 2 */
}

/*
Remove the inner padding in Chrome and Safari on macOS.
*/

::-webkit-search-decoration {
  -webkit-appearance: none;
}

/*
1. Correct the inability to style clickable types in iOS and Safari.
2. Change font properties to `inherit` in Safari.
*/

::-webkit-file-upload-button {
  -webkit-appearance: button;
  /* 1 */
  font: inherit;
  /* 2 */
}

/*
Add the correct display in Chrome and Safari.
*/

summary {
  display: list-item;
}

/*
Removes the default spacing and border for appropriate elements.
*/

blockquote,
dl,
dd,
h1,
h2,
h3,
h4,
h5,
h6,
hr,
figure,
p,
pre {
  margin: 0;
}

fieldset {
  margin: 0;
  padding: 0;
}

legend {
  padding: 0;
}

ol,
ul,
menu {
  list-style: none;
  margin: 0;
  padding: 0;
}

/*
Prevent resizing textareas horizontally by default.
*/

textarea {
  resize: vertical;
}

/*
1. Reset the default placeholder opacity in Firefox. (https://github.com/tailwindlabs/tailwindcss/issues/3300)
2. Set the default placeholder color to the user's configured gray 400 color.
*/

input::-moz-placeholder, textarea::-moz-placeholder {
  opacity: 1;
  /* 1 */
  color: #8c959f;
  /* 2 */
}

input::placeholder,
textarea::placeholder {
  opacity: 1;
  /* 1 */
  color: #8c959f;
  /* 2 */
}

/*
Set the default cursor for buttons.
*/

button,
[role="button"] {
  cursor: pointer;
}

/*
Make sure disabled buttons don't get the pointer cursor.
*/

:disabled {
  cursor: default;
}

/*
1. Make replaced elements `display: block` by default. (https://github.com/mozdevs/cssremedy/issues/14)
2. Add `vertical-align: middle` to align replaced elements more sensibly by default. (https://github.com/jensimmons/cssremedy/issues/14#issuecomment-634934210)
   This can trigger a poorly considered lint error in some tools but is included by design.
*/

img,
svg,
video,
canvas,
audio,
iframe,
embed,
object {
  display: block;
  /* 1 */
  vertical-align: middle;
  /* 2 */
}

/*
Constrain images and videos to the parent width and preserve their intrinsic aspect ratio. (https://github.com/mozdevs/cssremedy/issues/14)
*/

img,
video {
  max-width: 100%;
  height: auto;
}

/* Make elements with the HTML hidden attribute stay hidden by default */

[hidden] {
  display: none;
}

*, ::before, ::after {
  --tw-border-spacing-x: 0;
  --tw-border-spacing-y: 0;
  --tw-translate-x: 0;
  --tw-translate-y: 0;
  --tw-rotate: 0;
  --tw-skew-x: 0;
  --tw-skew-y: 0;
  --tw-scale-x: 1;
  --tw-scale-y: 1;
  --tw-pan-x:  ;
  --tw-pan-y:  ;
  --tw-pinch-zoom:  ;
  --tw-scroll-snap-strictness: proximity;
  --tw-ordinal:  ;
  --tw-slashed-zero:  ;
  --tw-numeric-figure:  ;
  --tw-numeric-spacing:  ;
  --tw-numeric-fraction:  ;
  --tw-ring-inset:  ;
  --tw-ring-offset-width: 0px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: rgb(59 130 246 / 0.5);
  --tw-ring-offset-shadow: 0 0 #0000;
  --tw-ring-shadow: 0 0 #0000;
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  --tw-blur:  ;
  --tw-brightness:  ;
  --tw-contrast:  ;
  --tw-grayscale:  ;
  --tw-hue-rotate:  ;
  --tw-invert:  ;
  --tw-saturate:  ;
  --tw-sepia:  ;
  --tw-drop-shadow:  ;
  --tw-backdrop-blur:  ;
  --tw-backdrop-brightness:  ;
  --tw-backdrop-contrast:  ;
  --tw-backdrop-grayscale:  ;
  --tw-backdrop-hue-rotate:  ;
  --tw-backdrop-invert:  ;
  --tw-backdrop-opacity:  ;
  --tw-backdrop-saturate:  ;
  --tw-backdrop-sepia:  ;
}

::backdrop {
  --tw-border-spacing-x: 0;
  --tw-border-spacing-y: 0;
  --tw-translate-x: 0;
  --tw-translate-y: 0;
  --tw-rotate: 0;
  --tw-skew-x: 0;
  --tw-skew-y: 0;
  --tw-scale-x: 1;
  --tw-scale-y: 1;
  --tw-pan-x:  ;
  --tw-pan-y:  ;
  --tw-pinch-zoom:  ;
  --tw-scroll-snap-strictness: proximity;
  --tw-ordinal:  ;
  --tw-slashed-zero:  ;
  --tw-numeric-figure:  ;
  --tw-numeric-spacing:  ;
  --tw-numeric-fraction:  ;
  --tw-ring-inset:  ;
  --tw-ring-offset-width: 0px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: rgb(59 130 246 / 0.5);
  --tw-ring-offset-shadow: 0 0 #0000;
  --tw-ring-shadow: 0 0 #0000;
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  --tw-blur:  ;
  --tw-brightness:  ;
  --tw-contrast:  ;
  --tw-grayscale:  ;
  --tw-hue-rotate:  ;
  --tw-invert:  ;
  --tw-saturate:  ;
  --tw-sepia:  ;
  --tw-drop-shadow:  ;
  --tw-backdrop-blur:  ;
  --tw-backdrop-brightness:  ;
  --tw-backdrop-contrast:  ;
  --tw-backdrop-grayscale:  ;
  --tw-backdrop-hue-rotate:  ;
  --tw-backdrop-invert:  ;
  --tw-backdrop-opacity:  ;
  --tw-backdrop-saturate:  ;
  --tw-backdrop-sepia:  ;
}

.dark .text-black {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .text-black.nightwind-prevent {
  color: rgba(0, 0, 0, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-black {
  color: rgba(0, 0, 0, var(--tw-text-opacity));
}

.dark .hover\:text-black:hover {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .hover\:text-black:hover.nightwind-prevent {
  color: rgba(0, 0, 0, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-black:hover {
  color: rgba(0, 0, 0, var(--tw-text-opacity));
}

.dark .text-white {
  color: rgba(0, 0, 0, var(--tw-text-opacity));
}

.dark .text-white.nightwind-prevent {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-white {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .hover\:text-white:hover {
  color: rgba(0, 0, 0, var(--tw-text-opacity));
}

.dark .hover\:text-white:hover.nightwind-prevent {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-white:hover {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .bg-black {
  background-color: rgba(255, 255, 255, var(--tw-bg-opacity));
}

.dark .bg-black.nightwind-prevent {
  background-color: rgba(0, 0, 0, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-black {
  background-color: rgba(0, 0, 0, var(--tw-bg-opacity));
}

.dark .hover\:bg-black:hover {
  background-color: rgba(255, 255, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-black:hover.nightwind-prevent {
  background-color: rgba(0, 0, 0, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-black:hover {
  background-color: rgba(0, 0, 0, var(--tw-bg-opacity));
}

.dark .bg-white {
  background-color: rgba(0, 0, 0, var(--tw-bg-opacity));
}

.dark .bg-white.nightwind-prevent {
  background-color: rgba(255, 255, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-white {
  background-color: rgba(255, 255, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-white:hover {
  background-color: rgba(0, 0, 0, var(--tw-bg-opacity));
}

.dark .hover\:bg-white:hover.nightwind-prevent {
  background-color: rgba(255, 255, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-white:hover {
  background-color: rgba(255, 255, 255, var(--tw-bg-opacity));
}

.dark .border-black {
  border-color: rgba(255, 255, 255, var(--tw-border-opacity));
}

.dark .border-black.nightwind-prevent {
  border-color: rgba(0, 0, 0, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-black {
  border-color: rgba(0, 0, 0, var(--tw-border-opacity));
}

.dark .hover\:border-black:hover {
  border-color: rgba(255, 255, 255, var(--tw-border-opacity));
}

.dark .hover\:border-black:hover.nightwind-prevent {
  border-color: rgba(0, 0, 0, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-black:hover {
  border-color: rgba(0, 0, 0, var(--tw-border-opacity));
}

.dark .border-white {
  border-color: rgba(0, 0, 0, var(--tw-border-opacity));
}

.dark .border-white.nightwind-prevent {
  border-color: rgba(255, 255, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-white {
  border-color: rgba(255, 255, 255, var(--tw-border-opacity));
}

.dark .hover\:border-white:hover {
  border-color: rgba(0, 0, 0, var(--tw-border-opacity));
}

.dark .hover\:border-white:hover.nightwind-prevent {
  border-color: rgba(255, 255, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-white:hover {
  border-color: rgba(255, 255, 255, var(--tw-border-opacity));
}

.dark .text-inherit-50 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-50.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-50 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-50:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-50:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-50:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-100 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-100.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-100 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-100:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-100:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-100:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-200 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-200.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-200 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-200:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-200:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-200:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-300 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-300.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-300 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-300:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-300:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-300:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-400 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-400.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-400 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-400:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-400:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-400:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-500 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-500.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-500 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-500:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-500:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-500:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-600 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-600.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-600 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-600:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-600:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-600:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-700 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-700.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-700 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-700:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-700:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-700:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-800 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-800.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-800 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-800:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-800:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-800:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-900 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-inherit-900.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-inherit-900 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-900:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-inherit-900:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-inherit-900:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-slate-50 {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .text-slate-50.nightwind-prevent {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-50 {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .hover\:text-slate-50:hover {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .hover\:text-slate-50:hover.nightwind-prevent {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-50:hover {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .text-slate-100 {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .text-slate-100.nightwind-prevent {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-100 {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .hover\:text-slate-100:hover {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .hover\:text-slate-100:hover.nightwind-prevent {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-100:hover {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .text-slate-200 {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .text-slate-200.nightwind-prevent {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-200 {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .hover\:text-slate-200:hover {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .hover\:text-slate-200:hover.nightwind-prevent {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-200:hover {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .text-slate-300 {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .text-slate-300.nightwind-prevent {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-300 {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .hover\:text-slate-300:hover {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .hover\:text-slate-300:hover.nightwind-prevent {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-300:hover {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .text-slate-400 {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .text-slate-400.nightwind-prevent {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-400 {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .hover\:text-slate-400:hover {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .hover\:text-slate-400:hover.nightwind-prevent {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-400:hover {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .text-slate-500 {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .text-slate-500.nightwind-prevent {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-500 {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .hover\:text-slate-500:hover {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .hover\:text-slate-500:hover.nightwind-prevent {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-500:hover {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .text-slate-600 {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .text-slate-600.nightwind-prevent {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-600 {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .hover\:text-slate-600:hover {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .hover\:text-slate-600:hover.nightwind-prevent {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-600:hover {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .text-slate-700 {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .text-slate-700.nightwind-prevent {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-700 {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .hover\:text-slate-700:hover {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .hover\:text-slate-700:hover.nightwind-prevent {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-700:hover {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .text-slate-800 {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .text-slate-800.nightwind-prevent {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-800 {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .hover\:text-slate-800:hover {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .hover\:text-slate-800:hover.nightwind-prevent {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-800:hover {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .text-slate-900 {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .text-slate-900.nightwind-prevent {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-slate-900 {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .hover\:text-slate-900:hover {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .hover\:text-slate-900:hover.nightwind-prevent {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-slate-900:hover {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .text-gray-50 {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .text-gray-50.nightwind-prevent {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-50 {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .hover\:text-gray-50:hover {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .hover\:text-gray-50:hover.nightwind-prevent {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-50:hover {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .text-gray-100 {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .text-gray-100.nightwind-prevent {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-100 {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .hover\:text-gray-100:hover {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .hover\:text-gray-100:hover.nightwind-prevent {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-100:hover {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .text-gray-200 {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .text-gray-200.nightwind-prevent {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-200 {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .hover\:text-gray-200:hover {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .hover\:text-gray-200:hover.nightwind-prevent {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-200:hover {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .text-gray-300 {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .text-gray-300.nightwind-prevent {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-300 {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .hover\:text-gray-300:hover {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .hover\:text-gray-300:hover.nightwind-prevent {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-300:hover {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .text-gray-400 {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .text-gray-400.nightwind-prevent {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-400 {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .hover\:text-gray-400:hover {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .hover\:text-gray-400:hover.nightwind-prevent {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-400:hover {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .text-gray-500 {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .text-gray-500.nightwind-prevent {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-500 {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .hover\:text-gray-500:hover {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .hover\:text-gray-500:hover.nightwind-prevent {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-500:hover {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .text-gray-600 {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .text-gray-600.nightwind-prevent {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-600 {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .hover\:text-gray-600:hover {
  color: rgba(175, 184, 193, var(--tw-text-opacity));
}

.dark .hover\:text-gray-600:hover.nightwind-prevent {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-600:hover {
  color: rgba(87, 96, 106, var(--tw-text-opacity));
}

.dark .text-gray-700 {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .text-gray-700.nightwind-prevent {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-700 {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .hover\:text-gray-700:hover {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .hover\:text-gray-700:hover.nightwind-prevent {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-700:hover {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .text-gray-800 {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .text-gray-800.nightwind-prevent {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-800 {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .hover\:text-gray-800:hover {
  color: rgba(234, 238, 242, var(--tw-text-opacity));
}

.dark .hover\:text-gray-800:hover.nightwind-prevent {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-800:hover {
  color: rgba(50, 56, 63, var(--tw-text-opacity));
}

.dark .text-gray-900 {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .text-gray-900.nightwind-prevent {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-gray-900 {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .hover\:text-gray-900:hover {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .hover\:text-gray-900:hover.nightwind-prevent {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-900:hover {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .text-zinc-50 {
  color: rgba(24, 24, 27, var(--tw-text-opacity));
}

.dark .text-zinc-50.nightwind-prevent {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-50 {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-50:hover {
  color: rgba(24, 24, 27, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-50:hover.nightwind-prevent {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-50:hover {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .text-zinc-100 {
  color: rgba(39, 39, 42, var(--tw-text-opacity));
}

.dark .text-zinc-100.nightwind-prevent {
  color: rgba(244, 244, 245, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-100 {
  color: rgba(244, 244, 245, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-100:hover {
  color: rgba(39, 39, 42, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-100:hover.nightwind-prevent {
  color: rgba(244, 244, 245, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-100:hover {
  color: rgba(244, 244, 245, var(--tw-text-opacity));
}

.dark .text-zinc-200 {
  color: rgba(63, 63, 70, var(--tw-text-opacity));
}

.dark .text-zinc-200.nightwind-prevent {
  color: rgba(228, 228, 231, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-200 {
  color: rgba(228, 228, 231, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-200:hover {
  color: rgba(63, 63, 70, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-200:hover.nightwind-prevent {
  color: rgba(228, 228, 231, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-200:hover {
  color: rgba(228, 228, 231, var(--tw-text-opacity));
}

.dark .text-zinc-300 {
  color: rgba(82, 82, 91, var(--tw-text-opacity));
}

.dark .text-zinc-300.nightwind-prevent {
  color: rgba(212, 212, 216, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-300 {
  color: rgba(212, 212, 216, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-300:hover {
  color: rgba(82, 82, 91, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-300:hover.nightwind-prevent {
  color: rgba(212, 212, 216, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-300:hover {
  color: rgba(212, 212, 216, var(--tw-text-opacity));
}

.dark .text-zinc-400 {
  color: rgba(113, 113, 122, var(--tw-text-opacity));
}

.dark .text-zinc-400.nightwind-prevent {
  color: rgba(161, 161, 170, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-400 {
  color: rgba(161, 161, 170, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-400:hover {
  color: rgba(113, 113, 122, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-400:hover.nightwind-prevent {
  color: rgba(161, 161, 170, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-400:hover {
  color: rgba(161, 161, 170, var(--tw-text-opacity));
}

.dark .text-zinc-500 {
  color: rgba(161, 161, 170, var(--tw-text-opacity));
}

.dark .text-zinc-500.nightwind-prevent {
  color: rgba(113, 113, 122, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-500 {
  color: rgba(113, 113, 122, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-500:hover {
  color: rgba(161, 161, 170, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-500:hover.nightwind-prevent {
  color: rgba(113, 113, 122, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-500:hover {
  color: rgba(113, 113, 122, var(--tw-text-opacity));
}

.dark .text-zinc-600 {
  color: rgba(212, 212, 216, var(--tw-text-opacity));
}

.dark .text-zinc-600.nightwind-prevent {
  color: rgba(82, 82, 91, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-600 {
  color: rgba(82, 82, 91, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-600:hover {
  color: rgba(212, 212, 216, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-600:hover.nightwind-prevent {
  color: rgba(82, 82, 91, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-600:hover {
  color: rgba(82, 82, 91, var(--tw-text-opacity));
}

.dark .text-zinc-700 {
  color: rgba(228, 228, 231, var(--tw-text-opacity));
}

.dark .text-zinc-700.nightwind-prevent {
  color: rgba(63, 63, 70, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-700 {
  color: rgba(63, 63, 70, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-700:hover {
  color: rgba(228, 228, 231, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-700:hover.nightwind-prevent {
  color: rgba(63, 63, 70, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-700:hover {
  color: rgba(63, 63, 70, var(--tw-text-opacity));
}

.dark .text-zinc-800 {
  color: rgba(244, 244, 245, var(--tw-text-opacity));
}

.dark .text-zinc-800.nightwind-prevent {
  color: rgba(39, 39, 42, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-800 {
  color: rgba(39, 39, 42, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-800:hover {
  color: rgba(244, 244, 245, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-800:hover.nightwind-prevent {
  color: rgba(39, 39, 42, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-800:hover {
  color: rgba(39, 39, 42, var(--tw-text-opacity));
}

.dark .text-zinc-900 {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .text-zinc-900.nightwind-prevent {
  color: rgba(24, 24, 27, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-zinc-900 {
  color: rgba(24, 24, 27, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-900:hover {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .hover\:text-zinc-900:hover.nightwind-prevent {
  color: rgba(24, 24, 27, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-zinc-900:hover {
  color: rgba(24, 24, 27, var(--tw-text-opacity));
}

.dark .text-neutral-50 {
  color: rgba(23, 23, 23, var(--tw-text-opacity));
}

.dark .text-neutral-50.nightwind-prevent {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-50 {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-50:hover {
  color: rgba(23, 23, 23, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-50:hover.nightwind-prevent {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-50:hover {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .text-neutral-100 {
  color: rgba(38, 38, 38, var(--tw-text-opacity));
}

.dark .text-neutral-100.nightwind-prevent {
  color: rgba(245, 245, 245, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-100 {
  color: rgba(245, 245, 245, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-100:hover {
  color: rgba(38, 38, 38, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-100:hover.nightwind-prevent {
  color: rgba(245, 245, 245, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-100:hover {
  color: rgba(245, 245, 245, var(--tw-text-opacity));
}

.dark .text-neutral-200 {
  color: rgba(64, 64, 64, var(--tw-text-opacity));
}

.dark .text-neutral-200.nightwind-prevent {
  color: rgba(229, 229, 229, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-200 {
  color: rgba(229, 229, 229, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-200:hover {
  color: rgba(64, 64, 64, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-200:hover.nightwind-prevent {
  color: rgba(229, 229, 229, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-200:hover {
  color: rgba(229, 229, 229, var(--tw-text-opacity));
}

.dark .text-neutral-300 {
  color: rgba(82, 82, 82, var(--tw-text-opacity));
}

.dark .text-neutral-300.nightwind-prevent {
  color: rgba(212, 212, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-300 {
  color: rgba(212, 212, 212, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-300:hover {
  color: rgba(82, 82, 82, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-300:hover.nightwind-prevent {
  color: rgba(212, 212, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-300:hover {
  color: rgba(212, 212, 212, var(--tw-text-opacity));
}

.dark .text-neutral-400 {
  color: rgba(115, 115, 115, var(--tw-text-opacity));
}

.dark .text-neutral-400.nightwind-prevent {
  color: rgba(163, 163, 163, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-400 {
  color: rgba(163, 163, 163, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-400:hover {
  color: rgba(115, 115, 115, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-400:hover.nightwind-prevent {
  color: rgba(163, 163, 163, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-400:hover {
  color: rgba(163, 163, 163, var(--tw-text-opacity));
}

.dark .text-neutral-500 {
  color: rgba(163, 163, 163, var(--tw-text-opacity));
}

.dark .text-neutral-500.nightwind-prevent {
  color: rgba(115, 115, 115, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-500 {
  color: rgba(115, 115, 115, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-500:hover {
  color: rgba(163, 163, 163, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-500:hover.nightwind-prevent {
  color: rgba(115, 115, 115, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-500:hover {
  color: rgba(115, 115, 115, var(--tw-text-opacity));
}

.dark .text-neutral-600 {
  color: rgba(212, 212, 212, var(--tw-text-opacity));
}

.dark .text-neutral-600.nightwind-prevent {
  color: rgba(82, 82, 82, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-600 {
  color: rgba(82, 82, 82, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-600:hover {
  color: rgba(212, 212, 212, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-600:hover.nightwind-prevent {
  color: rgba(82, 82, 82, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-600:hover {
  color: rgba(82, 82, 82, var(--tw-text-opacity));
}

.dark .text-neutral-700 {
  color: rgba(229, 229, 229, var(--tw-text-opacity));
}

.dark .text-neutral-700.nightwind-prevent {
  color: rgba(64, 64, 64, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-700 {
  color: rgba(64, 64, 64, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-700:hover {
  color: rgba(229, 229, 229, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-700:hover.nightwind-prevent {
  color: rgba(64, 64, 64, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-700:hover {
  color: rgba(64, 64, 64, var(--tw-text-opacity));
}

.dark .text-neutral-800 {
  color: rgba(245, 245, 245, var(--tw-text-opacity));
}

.dark .text-neutral-800.nightwind-prevent {
  color: rgba(38, 38, 38, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-800 {
  color: rgba(38, 38, 38, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-800:hover {
  color: rgba(245, 245, 245, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-800:hover.nightwind-prevent {
  color: rgba(38, 38, 38, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-800:hover {
  color: rgba(38, 38, 38, var(--tw-text-opacity));
}

.dark .text-neutral-900 {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .text-neutral-900.nightwind-prevent {
  color: rgba(23, 23, 23, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-neutral-900 {
  color: rgba(23, 23, 23, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-900:hover {
  color: rgba(250, 250, 250, var(--tw-text-opacity));
}

.dark .hover\:text-neutral-900:hover.nightwind-prevent {
  color: rgba(23, 23, 23, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-neutral-900:hover {
  color: rgba(23, 23, 23, var(--tw-text-opacity));
}

.dark .text-stone-50 {
  color: rgba(28, 25, 23, var(--tw-text-opacity));
}

.dark .text-stone-50.nightwind-prevent {
  color: rgba(250, 250, 249, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-50 {
  color: rgba(250, 250, 249, var(--tw-text-opacity));
}

.dark .hover\:text-stone-50:hover {
  color: rgba(28, 25, 23, var(--tw-text-opacity));
}

.dark .hover\:text-stone-50:hover.nightwind-prevent {
  color: rgba(250, 250, 249, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-50:hover {
  color: rgba(250, 250, 249, var(--tw-text-opacity));
}

.dark .text-stone-100 {
  color: rgba(41, 37, 36, var(--tw-text-opacity));
}

.dark .text-stone-100.nightwind-prevent {
  color: rgba(245, 245, 244, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-100 {
  color: rgba(245, 245, 244, var(--tw-text-opacity));
}

.dark .hover\:text-stone-100:hover {
  color: rgba(41, 37, 36, var(--tw-text-opacity));
}

.dark .hover\:text-stone-100:hover.nightwind-prevent {
  color: rgba(245, 245, 244, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-100:hover {
  color: rgba(245, 245, 244, var(--tw-text-opacity));
}

.dark .text-stone-200 {
  color: rgba(68, 64, 60, var(--tw-text-opacity));
}

.dark .text-stone-200.nightwind-prevent {
  color: rgba(231, 229, 228, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-200 {
  color: rgba(231, 229, 228, var(--tw-text-opacity));
}

.dark .hover\:text-stone-200:hover {
  color: rgba(68, 64, 60, var(--tw-text-opacity));
}

.dark .hover\:text-stone-200:hover.nightwind-prevent {
  color: rgba(231, 229, 228, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-200:hover {
  color: rgba(231, 229, 228, var(--tw-text-opacity));
}

.dark .text-stone-300 {
  color: rgba(87, 83, 78, var(--tw-text-opacity));
}

.dark .text-stone-300.nightwind-prevent {
  color: rgba(214, 211, 209, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-300 {
  color: rgba(214, 211, 209, var(--tw-text-opacity));
}

.dark .hover\:text-stone-300:hover {
  color: rgba(87, 83, 78, var(--tw-text-opacity));
}

.dark .hover\:text-stone-300:hover.nightwind-prevent {
  color: rgba(214, 211, 209, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-300:hover {
  color: rgba(214, 211, 209, var(--tw-text-opacity));
}

.dark .text-stone-400 {
  color: rgba(120, 113, 108, var(--tw-text-opacity));
}

.dark .text-stone-400.nightwind-prevent {
  color: rgba(168, 162, 158, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-400 {
  color: rgba(168, 162, 158, var(--tw-text-opacity));
}

.dark .hover\:text-stone-400:hover {
  color: rgba(120, 113, 108, var(--tw-text-opacity));
}

.dark .hover\:text-stone-400:hover.nightwind-prevent {
  color: rgba(168, 162, 158, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-400:hover {
  color: rgba(168, 162, 158, var(--tw-text-opacity));
}

.dark .text-stone-500 {
  color: rgba(168, 162, 158, var(--tw-text-opacity));
}

.dark .text-stone-500.nightwind-prevent {
  color: rgba(120, 113, 108, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-500 {
  color: rgba(120, 113, 108, var(--tw-text-opacity));
}

.dark .hover\:text-stone-500:hover {
  color: rgba(168, 162, 158, var(--tw-text-opacity));
}

.dark .hover\:text-stone-500:hover.nightwind-prevent {
  color: rgba(120, 113, 108, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-500:hover {
  color: rgba(120, 113, 108, var(--tw-text-opacity));
}

.dark .text-stone-600 {
  color: rgba(214, 211, 209, var(--tw-text-opacity));
}

.dark .text-stone-600.nightwind-prevent {
  color: rgba(87, 83, 78, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-600 {
  color: rgba(87, 83, 78, var(--tw-text-opacity));
}

.dark .hover\:text-stone-600:hover {
  color: rgba(214, 211, 209, var(--tw-text-opacity));
}

.dark .hover\:text-stone-600:hover.nightwind-prevent {
  color: rgba(87, 83, 78, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-600:hover {
  color: rgba(87, 83, 78, var(--tw-text-opacity));
}

.dark .text-stone-700 {
  color: rgba(231, 229, 228, var(--tw-text-opacity));
}

.dark .text-stone-700.nightwind-prevent {
  color: rgba(68, 64, 60, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-700 {
  color: rgba(68, 64, 60, var(--tw-text-opacity));
}

.dark .hover\:text-stone-700:hover {
  color: rgba(231, 229, 228, var(--tw-text-opacity));
}

.dark .hover\:text-stone-700:hover.nightwind-prevent {
  color: rgba(68, 64, 60, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-700:hover {
  color: rgba(68, 64, 60, var(--tw-text-opacity));
}

.dark .text-stone-800 {
  color: rgba(245, 245, 244, var(--tw-text-opacity));
}

.dark .text-stone-800.nightwind-prevent {
  color: rgba(41, 37, 36, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-800 {
  color: rgba(41, 37, 36, var(--tw-text-opacity));
}

.dark .hover\:text-stone-800:hover {
  color: rgba(245, 245, 244, var(--tw-text-opacity));
}

.dark .hover\:text-stone-800:hover.nightwind-prevent {
  color: rgba(41, 37, 36, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-800:hover {
  color: rgba(41, 37, 36, var(--tw-text-opacity));
}

.dark .text-stone-900 {
  color: rgba(250, 250, 249, var(--tw-text-opacity));
}

.dark .text-stone-900.nightwind-prevent {
  color: rgba(28, 25, 23, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-stone-900 {
  color: rgba(28, 25, 23, var(--tw-text-opacity));
}

.dark .hover\:text-stone-900:hover {
  color: rgba(250, 250, 249, var(--tw-text-opacity));
}

.dark .hover\:text-stone-900:hover.nightwind-prevent {
  color: rgba(28, 25, 23, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-stone-900:hover {
  color: rgba(28, 25, 23, var(--tw-text-opacity));
}

.dark .text-red-50 {
  color: rgba(127, 29, 29, var(--tw-text-opacity));
}

.dark .text-red-50.nightwind-prevent {
  color: rgba(254, 242, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-50 {
  color: rgba(254, 242, 242, var(--tw-text-opacity));
}

.dark .hover\:text-red-50:hover {
  color: rgba(127, 29, 29, var(--tw-text-opacity));
}

.dark .hover\:text-red-50:hover.nightwind-prevent {
  color: rgba(254, 242, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-50:hover {
  color: rgba(254, 242, 242, var(--tw-text-opacity));
}

.dark .text-red-100 {
  color: rgba(153, 27, 27, var(--tw-text-opacity));
}

.dark .text-red-100.nightwind-prevent {
  color: rgba(254, 226, 226, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-100 {
  color: rgba(254, 226, 226, var(--tw-text-opacity));
}

.dark .hover\:text-red-100:hover {
  color: rgba(153, 27, 27, var(--tw-text-opacity));
}

.dark .hover\:text-red-100:hover.nightwind-prevent {
  color: rgba(254, 226, 226, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-100:hover {
  color: rgba(254, 226, 226, var(--tw-text-opacity));
}

.dark .text-red-200 {
  color: rgba(185, 28, 28, var(--tw-text-opacity));
}

.dark .text-red-200.nightwind-prevent {
  color: rgba(254, 202, 202, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-200 {
  color: rgba(254, 202, 202, var(--tw-text-opacity));
}

.dark .hover\:text-red-200:hover {
  color: rgba(185, 28, 28, var(--tw-text-opacity));
}

.dark .hover\:text-red-200:hover.nightwind-prevent {
  color: rgba(254, 202, 202, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-200:hover {
  color: rgba(254, 202, 202, var(--tw-text-opacity));
}

.dark .text-red-300 {
  color: rgba(220, 38, 38, var(--tw-text-opacity));
}

.dark .text-red-300.nightwind-prevent {
  color: rgba(252, 165, 165, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-300 {
  color: rgba(252, 165, 165, var(--tw-text-opacity));
}

.dark .hover\:text-red-300:hover {
  color: rgba(220, 38, 38, var(--tw-text-opacity));
}

.dark .hover\:text-red-300:hover.nightwind-prevent {
  color: rgba(252, 165, 165, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-300:hover {
  color: rgba(252, 165, 165, var(--tw-text-opacity));
}

.dark .text-red-400 {
  color: rgba(239, 68, 68, var(--tw-text-opacity));
}

.dark .text-red-400.nightwind-prevent {
  color: rgba(248, 113, 113, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-400 {
  color: rgba(248, 113, 113, var(--tw-text-opacity));
}

.dark .hover\:text-red-400:hover {
  color: rgba(239, 68, 68, var(--tw-text-opacity));
}

.dark .hover\:text-red-400:hover.nightwind-prevent {
  color: rgba(248, 113, 113, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-400:hover {
  color: rgba(248, 113, 113, var(--tw-text-opacity));
}

.dark .text-red-500 {
  color: rgba(248, 113, 113, var(--tw-text-opacity));
}

.dark .text-red-500.nightwind-prevent {
  color: rgba(239, 68, 68, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-500 {
  color: rgba(239, 68, 68, var(--tw-text-opacity));
}

.dark .hover\:text-red-500:hover {
  color: rgba(248, 113, 113, var(--tw-text-opacity));
}

.dark .hover\:text-red-500:hover.nightwind-prevent {
  color: rgba(239, 68, 68, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-500:hover {
  color: rgba(239, 68, 68, var(--tw-text-opacity));
}

.dark .text-red-600 {
  color: rgba(252, 165, 165, var(--tw-text-opacity));
}

.dark .text-red-600.nightwind-prevent {
  color: rgba(220, 38, 38, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-600 {
  color: rgba(220, 38, 38, var(--tw-text-opacity));
}

.dark .hover\:text-red-600:hover {
  color: rgba(252, 165, 165, var(--tw-text-opacity));
}

.dark .hover\:text-red-600:hover.nightwind-prevent {
  color: rgba(220, 38, 38, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-600:hover {
  color: rgba(220, 38, 38, var(--tw-text-opacity));
}

.dark .text-red-700 {
  color: rgba(254, 202, 202, var(--tw-text-opacity));
}

.dark .text-red-700.nightwind-prevent {
  color: rgba(185, 28, 28, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-700 {
  color: rgba(185, 28, 28, var(--tw-text-opacity));
}

.dark .hover\:text-red-700:hover {
  color: rgba(254, 202, 202, var(--tw-text-opacity));
}

.dark .hover\:text-red-700:hover.nightwind-prevent {
  color: rgba(185, 28, 28, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-700:hover {
  color: rgba(185, 28, 28, var(--tw-text-opacity));
}

.dark .text-red-800 {
  color: rgba(254, 226, 226, var(--tw-text-opacity));
}

.dark .text-red-800.nightwind-prevent {
  color: rgba(153, 27, 27, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-800 {
  color: rgba(153, 27, 27, var(--tw-text-opacity));
}

.dark .hover\:text-red-800:hover {
  color: rgba(254, 226, 226, var(--tw-text-opacity));
}

.dark .hover\:text-red-800:hover.nightwind-prevent {
  color: rgba(153, 27, 27, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-800:hover {
  color: rgba(153, 27, 27, var(--tw-text-opacity));
}

.dark .text-red-900 {
  color: rgba(254, 242, 242, var(--tw-text-opacity));
}

.dark .text-red-900.nightwind-prevent {
  color: rgba(127, 29, 29, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-red-900 {
  color: rgba(127, 29, 29, var(--tw-text-opacity));
}

.dark .hover\:text-red-900:hover {
  color: rgba(254, 242, 242, var(--tw-text-opacity));
}

.dark .hover\:text-red-900:hover.nightwind-prevent {
  color: rgba(127, 29, 29, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-red-900:hover {
  color: rgba(127, 29, 29, var(--tw-text-opacity));
}

.dark .text-orange-50 {
  color: rgba(124, 45, 18, var(--tw-text-opacity));
}

.dark .text-orange-50.nightwind-prevent {
  color: rgba(255, 247, 237, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-50 {
  color: rgba(255, 247, 237, var(--tw-text-opacity));
}

.dark .hover\:text-orange-50:hover {
  color: rgba(124, 45, 18, var(--tw-text-opacity));
}

.dark .hover\:text-orange-50:hover.nightwind-prevent {
  color: rgba(255, 247, 237, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-50:hover {
  color: rgba(255, 247, 237, var(--tw-text-opacity));
}

.dark .text-orange-100 {
  color: rgba(154, 52, 18, var(--tw-text-opacity));
}

.dark .text-orange-100.nightwind-prevent {
  color: rgba(255, 237, 213, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-100 {
  color: rgba(255, 237, 213, var(--tw-text-opacity));
}

.dark .hover\:text-orange-100:hover {
  color: rgba(154, 52, 18, var(--tw-text-opacity));
}

.dark .hover\:text-orange-100:hover.nightwind-prevent {
  color: rgba(255, 237, 213, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-100:hover {
  color: rgba(255, 237, 213, var(--tw-text-opacity));
}

.dark .text-orange-200 {
  color: rgba(194, 65, 12, var(--tw-text-opacity));
}

.dark .text-orange-200.nightwind-prevent {
  color: rgba(254, 215, 170, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-200 {
  color: rgba(254, 215, 170, var(--tw-text-opacity));
}

.dark .hover\:text-orange-200:hover {
  color: rgba(194, 65, 12, var(--tw-text-opacity));
}

.dark .hover\:text-orange-200:hover.nightwind-prevent {
  color: rgba(254, 215, 170, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-200:hover {
  color: rgba(254, 215, 170, var(--tw-text-opacity));
}

.dark .text-orange-300 {
  color: rgba(234, 88, 12, var(--tw-text-opacity));
}

.dark .text-orange-300.nightwind-prevent {
  color: rgba(253, 186, 116, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-300 {
  color: rgba(253, 186, 116, var(--tw-text-opacity));
}

.dark .hover\:text-orange-300:hover {
  color: rgba(234, 88, 12, var(--tw-text-opacity));
}

.dark .hover\:text-orange-300:hover.nightwind-prevent {
  color: rgba(253, 186, 116, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-300:hover {
  color: rgba(253, 186, 116, var(--tw-text-opacity));
}

.dark .text-orange-400 {
  color: rgba(249, 115, 22, var(--tw-text-opacity));
}

.dark .text-orange-400.nightwind-prevent {
  color: rgba(251, 146, 60, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-400 {
  color: rgba(251, 146, 60, var(--tw-text-opacity));
}

.dark .hover\:text-orange-400:hover {
  color: rgba(249, 115, 22, var(--tw-text-opacity));
}

.dark .hover\:text-orange-400:hover.nightwind-prevent {
  color: rgba(251, 146, 60, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-400:hover {
  color: rgba(251, 146, 60, var(--tw-text-opacity));
}

.dark .text-orange-500 {
  color: rgba(251, 146, 60, var(--tw-text-opacity));
}

.dark .text-orange-500.nightwind-prevent {
  color: rgba(249, 115, 22, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-500 {
  color: rgba(249, 115, 22, var(--tw-text-opacity));
}

.dark .hover\:text-orange-500:hover {
  color: rgba(251, 146, 60, var(--tw-text-opacity));
}

.dark .hover\:text-orange-500:hover.nightwind-prevent {
  color: rgba(249, 115, 22, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-500:hover {
  color: rgba(249, 115, 22, var(--tw-text-opacity));
}

.dark .text-orange-600 {
  color: rgba(253, 186, 116, var(--tw-text-opacity));
}

.dark .text-orange-600.nightwind-prevent {
  color: rgba(234, 88, 12, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-600 {
  color: rgba(234, 88, 12, var(--tw-text-opacity));
}

.dark .hover\:text-orange-600:hover {
  color: rgba(253, 186, 116, var(--tw-text-opacity));
}

.dark .hover\:text-orange-600:hover.nightwind-prevent {
  color: rgba(234, 88, 12, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-600:hover {
  color: rgba(234, 88, 12, var(--tw-text-opacity));
}

.dark .text-orange-700 {
  color: rgba(254, 215, 170, var(--tw-text-opacity));
}

.dark .text-orange-700.nightwind-prevent {
  color: rgba(194, 65, 12, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-700 {
  color: rgba(194, 65, 12, var(--tw-text-opacity));
}

.dark .hover\:text-orange-700:hover {
  color: rgba(254, 215, 170, var(--tw-text-opacity));
}

.dark .hover\:text-orange-700:hover.nightwind-prevent {
  color: rgba(194, 65, 12, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-700:hover {
  color: rgba(194, 65, 12, var(--tw-text-opacity));
}

.dark .text-orange-800 {
  color: rgba(255, 237, 213, var(--tw-text-opacity));
}

.dark .text-orange-800.nightwind-prevent {
  color: rgba(154, 52, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-800 {
  color: rgba(154, 52, 18, var(--tw-text-opacity));
}

.dark .hover\:text-orange-800:hover {
  color: rgba(255, 237, 213, var(--tw-text-opacity));
}

.dark .hover\:text-orange-800:hover.nightwind-prevent {
  color: rgba(154, 52, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-800:hover {
  color: rgba(154, 52, 18, var(--tw-text-opacity));
}

.dark .text-orange-900 {
  color: rgba(255, 247, 237, var(--tw-text-opacity));
}

.dark .text-orange-900.nightwind-prevent {
  color: rgba(124, 45, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-orange-900 {
  color: rgba(124, 45, 18, var(--tw-text-opacity));
}

.dark .hover\:text-orange-900:hover {
  color: rgba(255, 247, 237, var(--tw-text-opacity));
}

.dark .hover\:text-orange-900:hover.nightwind-prevent {
  color: rgba(124, 45, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-orange-900:hover {
  color: rgba(124, 45, 18, var(--tw-text-opacity));
}

.dark .text-amber-50 {
  color: rgba(120, 53, 15, var(--tw-text-opacity));
}

.dark .text-amber-50.nightwind-prevent {
  color: rgba(255, 251, 235, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-50 {
  color: rgba(255, 251, 235, var(--tw-text-opacity));
}

.dark .hover\:text-amber-50:hover {
  color: rgba(120, 53, 15, var(--tw-text-opacity));
}

.dark .hover\:text-amber-50:hover.nightwind-prevent {
  color: rgba(255, 251, 235, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-50:hover {
  color: rgba(255, 251, 235, var(--tw-text-opacity));
}

.dark .text-amber-100 {
  color: rgba(146, 64, 14, var(--tw-text-opacity));
}

.dark .text-amber-100.nightwind-prevent {
  color: rgba(254, 243, 199, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-100 {
  color: rgba(254, 243, 199, var(--tw-text-opacity));
}

.dark .hover\:text-amber-100:hover {
  color: rgba(146, 64, 14, var(--tw-text-opacity));
}

.dark .hover\:text-amber-100:hover.nightwind-prevent {
  color: rgba(254, 243, 199, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-100:hover {
  color: rgba(254, 243, 199, var(--tw-text-opacity));
}

.dark .text-amber-200 {
  color: rgba(180, 83, 9, var(--tw-text-opacity));
}

.dark .text-amber-200.nightwind-prevent {
  color: rgba(253, 230, 138, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-200 {
  color: rgba(253, 230, 138, var(--tw-text-opacity));
}

.dark .hover\:text-amber-200:hover {
  color: rgba(180, 83, 9, var(--tw-text-opacity));
}

.dark .hover\:text-amber-200:hover.nightwind-prevent {
  color: rgba(253, 230, 138, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-200:hover {
  color: rgba(253, 230, 138, var(--tw-text-opacity));
}

.dark .text-amber-300 {
  color: rgba(217, 119, 6, var(--tw-text-opacity));
}

.dark .text-amber-300.nightwind-prevent {
  color: rgba(252, 211, 77, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-300 {
  color: rgba(252, 211, 77, var(--tw-text-opacity));
}

.dark .hover\:text-amber-300:hover {
  color: rgba(217, 119, 6, var(--tw-text-opacity));
}

.dark .hover\:text-amber-300:hover.nightwind-prevent {
  color: rgba(252, 211, 77, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-300:hover {
  color: rgba(252, 211, 77, var(--tw-text-opacity));
}

.dark .text-amber-400 {
  color: rgba(245, 158, 11, var(--tw-text-opacity));
}

.dark .text-amber-400.nightwind-prevent {
  color: rgba(251, 191, 36, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-400 {
  color: rgba(251, 191, 36, var(--tw-text-opacity));
}

.dark .hover\:text-amber-400:hover {
  color: rgba(245, 158, 11, var(--tw-text-opacity));
}

.dark .hover\:text-amber-400:hover.nightwind-prevent {
  color: rgba(251, 191, 36, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-400:hover {
  color: rgba(251, 191, 36, var(--tw-text-opacity));
}

.dark .text-amber-500 {
  color: rgba(251, 191, 36, var(--tw-text-opacity));
}

.dark .text-amber-500.nightwind-prevent {
  color: rgba(245, 158, 11, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-500 {
  color: rgba(245, 158, 11, var(--tw-text-opacity));
}

.dark .hover\:text-amber-500:hover {
  color: rgba(251, 191, 36, var(--tw-text-opacity));
}

.dark .hover\:text-amber-500:hover.nightwind-prevent {
  color: rgba(245, 158, 11, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-500:hover {
  color: rgba(245, 158, 11, var(--tw-text-opacity));
}

.dark .text-amber-600 {
  color: rgba(252, 211, 77, var(--tw-text-opacity));
}

.dark .text-amber-600.nightwind-prevent {
  color: rgba(217, 119, 6, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-600 {
  color: rgba(217, 119, 6, var(--tw-text-opacity));
}

.dark .hover\:text-amber-600:hover {
  color: rgba(252, 211, 77, var(--tw-text-opacity));
}

.dark .hover\:text-amber-600:hover.nightwind-prevent {
  color: rgba(217, 119, 6, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-600:hover {
  color: rgba(217, 119, 6, var(--tw-text-opacity));
}

.dark .text-amber-700 {
  color: rgba(253, 230, 138, var(--tw-text-opacity));
}

.dark .text-amber-700.nightwind-prevent {
  color: rgba(180, 83, 9, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-700 {
  color: rgba(180, 83, 9, var(--tw-text-opacity));
}

.dark .hover\:text-amber-700:hover {
  color: rgba(253, 230, 138, var(--tw-text-opacity));
}

.dark .hover\:text-amber-700:hover.nightwind-prevent {
  color: rgba(180, 83, 9, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-700:hover {
  color: rgba(180, 83, 9, var(--tw-text-opacity));
}

.dark .text-amber-800 {
  color: rgba(254, 243, 199, var(--tw-text-opacity));
}

.dark .text-amber-800.nightwind-prevent {
  color: rgba(146, 64, 14, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-800 {
  color: rgba(146, 64, 14, var(--tw-text-opacity));
}

.dark .hover\:text-amber-800:hover {
  color: rgba(254, 243, 199, var(--tw-text-opacity));
}

.dark .hover\:text-amber-800:hover.nightwind-prevent {
  color: rgba(146, 64, 14, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-800:hover {
  color: rgba(146, 64, 14, var(--tw-text-opacity));
}

.dark .text-amber-900 {
  color: rgba(255, 251, 235, var(--tw-text-opacity));
}

.dark .text-amber-900.nightwind-prevent {
  color: rgba(120, 53, 15, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-amber-900 {
  color: rgba(120, 53, 15, var(--tw-text-opacity));
}

.dark .hover\:text-amber-900:hover {
  color: rgba(255, 251, 235, var(--tw-text-opacity));
}

.dark .hover\:text-amber-900:hover.nightwind-prevent {
  color: rgba(120, 53, 15, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-amber-900:hover {
  color: rgba(120, 53, 15, var(--tw-text-opacity));
}

.dark .text-yellow-50 {
  color: rgba(113, 63, 18, var(--tw-text-opacity));
}

.dark .text-yellow-50.nightwind-prevent {
  color: rgba(254, 252, 232, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-50 {
  color: rgba(254, 252, 232, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-50:hover {
  color: rgba(113, 63, 18, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-50:hover.nightwind-prevent {
  color: rgba(254, 252, 232, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-50:hover {
  color: rgba(254, 252, 232, var(--tw-text-opacity));
}

.dark .text-yellow-100 {
  color: rgba(133, 77, 14, var(--tw-text-opacity));
}

.dark .text-yellow-100.nightwind-prevent {
  color: rgba(254, 249, 195, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-100 {
  color: rgba(254, 249, 195, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-100:hover {
  color: rgba(133, 77, 14, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-100:hover.nightwind-prevent {
  color: rgba(254, 249, 195, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-100:hover {
  color: rgba(254, 249, 195, var(--tw-text-opacity));
}

.dark .text-yellow-200 {
  color: rgba(161, 98, 7, var(--tw-text-opacity));
}

.dark .text-yellow-200.nightwind-prevent {
  color: rgba(254, 240, 138, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-200 {
  color: rgba(254, 240, 138, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-200:hover {
  color: rgba(161, 98, 7, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-200:hover.nightwind-prevent {
  color: rgba(254, 240, 138, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-200:hover {
  color: rgba(254, 240, 138, var(--tw-text-opacity));
}

.dark .text-yellow-300 {
  color: rgba(202, 138, 4, var(--tw-text-opacity));
}

.dark .text-yellow-300.nightwind-prevent {
  color: rgba(253, 224, 71, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-300 {
  color: rgba(253, 224, 71, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-300:hover {
  color: rgba(202, 138, 4, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-300:hover.nightwind-prevent {
  color: rgba(253, 224, 71, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-300:hover {
  color: rgba(253, 224, 71, var(--tw-text-opacity));
}

.dark .text-yellow-400 {
  color: rgba(234, 179, 8, var(--tw-text-opacity));
}

.dark .text-yellow-400.nightwind-prevent {
  color: rgba(250, 204, 21, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-400 {
  color: rgba(250, 204, 21, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-400:hover {
  color: rgba(234, 179, 8, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-400:hover.nightwind-prevent {
  color: rgba(250, 204, 21, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-400:hover {
  color: rgba(250, 204, 21, var(--tw-text-opacity));
}

.dark .text-yellow-500 {
  color: rgba(250, 204, 21, var(--tw-text-opacity));
}

.dark .text-yellow-500.nightwind-prevent {
  color: rgba(234, 179, 8, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-500 {
  color: rgba(234, 179, 8, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-500:hover {
  color: rgba(250, 204, 21, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-500:hover.nightwind-prevent {
  color: rgba(234, 179, 8, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-500:hover {
  color: rgba(234, 179, 8, var(--tw-text-opacity));
}

.dark .text-yellow-600 {
  color: rgba(253, 224, 71, var(--tw-text-opacity));
}

.dark .text-yellow-600.nightwind-prevent {
  color: rgba(202, 138, 4, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-600 {
  color: rgba(202, 138, 4, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-600:hover {
  color: rgba(253, 224, 71, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-600:hover.nightwind-prevent {
  color: rgba(202, 138, 4, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-600:hover {
  color: rgba(202, 138, 4, var(--tw-text-opacity));
}

.dark .text-yellow-700 {
  color: rgba(254, 240, 138, var(--tw-text-opacity));
}

.dark .text-yellow-700.nightwind-prevent {
  color: rgba(161, 98, 7, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-700 {
  color: rgba(161, 98, 7, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-700:hover {
  color: rgba(254, 240, 138, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-700:hover.nightwind-prevent {
  color: rgba(161, 98, 7, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-700:hover {
  color: rgba(161, 98, 7, var(--tw-text-opacity));
}

.dark .text-yellow-800 {
  color: rgba(254, 249, 195, var(--tw-text-opacity));
}

.dark .text-yellow-800.nightwind-prevent {
  color: rgba(133, 77, 14, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-800 {
  color: rgba(133, 77, 14, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-800:hover {
  color: rgba(254, 249, 195, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-800:hover.nightwind-prevent {
  color: rgba(133, 77, 14, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-800:hover {
  color: rgba(133, 77, 14, var(--tw-text-opacity));
}

.dark .text-yellow-900 {
  color: rgba(254, 252, 232, var(--tw-text-opacity));
}

.dark .text-yellow-900.nightwind-prevent {
  color: rgba(113, 63, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-yellow-900 {
  color: rgba(113, 63, 18, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-900:hover {
  color: rgba(254, 252, 232, var(--tw-text-opacity));
}

.dark .hover\:text-yellow-900:hover.nightwind-prevent {
  color: rgba(113, 63, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-yellow-900:hover {
  color: rgba(113, 63, 18, var(--tw-text-opacity));
}

.dark .text-lime-50 {
  color: rgba(54, 83, 20, var(--tw-text-opacity));
}

.dark .text-lime-50.nightwind-prevent {
  color: rgba(247, 254, 231, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-50 {
  color: rgba(247, 254, 231, var(--tw-text-opacity));
}

.dark .hover\:text-lime-50:hover {
  color: rgba(54, 83, 20, var(--tw-text-opacity));
}

.dark .hover\:text-lime-50:hover.nightwind-prevent {
  color: rgba(247, 254, 231, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-50:hover {
  color: rgba(247, 254, 231, var(--tw-text-opacity));
}

.dark .text-lime-100 {
  color: rgba(63, 98, 18, var(--tw-text-opacity));
}

.dark .text-lime-100.nightwind-prevent {
  color: rgba(236, 252, 203, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-100 {
  color: rgba(236, 252, 203, var(--tw-text-opacity));
}

.dark .hover\:text-lime-100:hover {
  color: rgba(63, 98, 18, var(--tw-text-opacity));
}

.dark .hover\:text-lime-100:hover.nightwind-prevent {
  color: rgba(236, 252, 203, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-100:hover {
  color: rgba(236, 252, 203, var(--tw-text-opacity));
}

.dark .text-lime-200 {
  color: rgba(77, 124, 15, var(--tw-text-opacity));
}

.dark .text-lime-200.nightwind-prevent {
  color: rgba(217, 249, 157, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-200 {
  color: rgba(217, 249, 157, var(--tw-text-opacity));
}

.dark .hover\:text-lime-200:hover {
  color: rgba(77, 124, 15, var(--tw-text-opacity));
}

.dark .hover\:text-lime-200:hover.nightwind-prevent {
  color: rgba(217, 249, 157, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-200:hover {
  color: rgba(217, 249, 157, var(--tw-text-opacity));
}

.dark .text-lime-300 {
  color: rgba(101, 163, 13, var(--tw-text-opacity));
}

.dark .text-lime-300.nightwind-prevent {
  color: rgba(190, 242, 100, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-300 {
  color: rgba(190, 242, 100, var(--tw-text-opacity));
}

.dark .hover\:text-lime-300:hover {
  color: rgba(101, 163, 13, var(--tw-text-opacity));
}

.dark .hover\:text-lime-300:hover.nightwind-prevent {
  color: rgba(190, 242, 100, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-300:hover {
  color: rgba(190, 242, 100, var(--tw-text-opacity));
}

.dark .text-lime-400 {
  color: rgba(132, 204, 22, var(--tw-text-opacity));
}

.dark .text-lime-400.nightwind-prevent {
  color: rgba(163, 230, 53, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-400 {
  color: rgba(163, 230, 53, var(--tw-text-opacity));
}

.dark .hover\:text-lime-400:hover {
  color: rgba(132, 204, 22, var(--tw-text-opacity));
}

.dark .hover\:text-lime-400:hover.nightwind-prevent {
  color: rgba(163, 230, 53, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-400:hover {
  color: rgba(163, 230, 53, var(--tw-text-opacity));
}

.dark .text-lime-500 {
  color: rgba(163, 230, 53, var(--tw-text-opacity));
}

.dark .text-lime-500.nightwind-prevent {
  color: rgba(132, 204, 22, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-500 {
  color: rgba(132, 204, 22, var(--tw-text-opacity));
}

.dark .hover\:text-lime-500:hover {
  color: rgba(163, 230, 53, var(--tw-text-opacity));
}

.dark .hover\:text-lime-500:hover.nightwind-prevent {
  color: rgba(132, 204, 22, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-500:hover {
  color: rgba(132, 204, 22, var(--tw-text-opacity));
}

.dark .text-lime-600 {
  color: rgba(190, 242, 100, var(--tw-text-opacity));
}

.dark .text-lime-600.nightwind-prevent {
  color: rgba(101, 163, 13, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-600 {
  color: rgba(101, 163, 13, var(--tw-text-opacity));
}

.dark .hover\:text-lime-600:hover {
  color: rgba(190, 242, 100, var(--tw-text-opacity));
}

.dark .hover\:text-lime-600:hover.nightwind-prevent {
  color: rgba(101, 163, 13, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-600:hover {
  color: rgba(101, 163, 13, var(--tw-text-opacity));
}

.dark .text-lime-700 {
  color: rgba(217, 249, 157, var(--tw-text-opacity));
}

.dark .text-lime-700.nightwind-prevent {
  color: rgba(77, 124, 15, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-700 {
  color: rgba(77, 124, 15, var(--tw-text-opacity));
}

.dark .hover\:text-lime-700:hover {
  color: rgba(217, 249, 157, var(--tw-text-opacity));
}

.dark .hover\:text-lime-700:hover.nightwind-prevent {
  color: rgba(77, 124, 15, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-700:hover {
  color: rgba(77, 124, 15, var(--tw-text-opacity));
}

.dark .text-lime-800 {
  color: rgba(236, 252, 203, var(--tw-text-opacity));
}

.dark .text-lime-800.nightwind-prevent {
  color: rgba(63, 98, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-800 {
  color: rgba(63, 98, 18, var(--tw-text-opacity));
}

.dark .hover\:text-lime-800:hover {
  color: rgba(236, 252, 203, var(--tw-text-opacity));
}

.dark .hover\:text-lime-800:hover.nightwind-prevent {
  color: rgba(63, 98, 18, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-800:hover {
  color: rgba(63, 98, 18, var(--tw-text-opacity));
}

.dark .text-lime-900 {
  color: rgba(247, 254, 231, var(--tw-text-opacity));
}

.dark .text-lime-900.nightwind-prevent {
  color: rgba(54, 83, 20, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-lime-900 {
  color: rgba(54, 83, 20, var(--tw-text-opacity));
}

.dark .hover\:text-lime-900:hover {
  color: rgba(247, 254, 231, var(--tw-text-opacity));
}

.dark .hover\:text-lime-900:hover.nightwind-prevent {
  color: rgba(54, 83, 20, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-lime-900:hover {
  color: rgba(54, 83, 20, var(--tw-text-opacity));
}

.dark .text-green-50 {
  color: rgba(20, 83, 45, var(--tw-text-opacity));
}

.dark .text-green-50.nightwind-prevent {
  color: rgba(240, 253, 244, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-50 {
  color: rgba(240, 253, 244, var(--tw-text-opacity));
}

.dark .hover\:text-green-50:hover {
  color: rgba(20, 83, 45, var(--tw-text-opacity));
}

.dark .hover\:text-green-50:hover.nightwind-prevent {
  color: rgba(240, 253, 244, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-50:hover {
  color: rgba(240, 253, 244, var(--tw-text-opacity));
}

.dark .text-green-100 {
  color: rgba(22, 101, 52, var(--tw-text-opacity));
}

.dark .text-green-100.nightwind-prevent {
  color: rgba(220, 252, 231, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-100 {
  color: rgba(220, 252, 231, var(--tw-text-opacity));
}

.dark .hover\:text-green-100:hover {
  color: rgba(22, 101, 52, var(--tw-text-opacity));
}

.dark .hover\:text-green-100:hover.nightwind-prevent {
  color: rgba(220, 252, 231, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-100:hover {
  color: rgba(220, 252, 231, var(--tw-text-opacity));
}

.dark .text-green-200 {
  color: rgba(21, 128, 61, var(--tw-text-opacity));
}

.dark .text-green-200.nightwind-prevent {
  color: rgba(187, 247, 208, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-200 {
  color: rgba(187, 247, 208, var(--tw-text-opacity));
}

.dark .hover\:text-green-200:hover {
  color: rgba(21, 128, 61, var(--tw-text-opacity));
}

.dark .hover\:text-green-200:hover.nightwind-prevent {
  color: rgba(187, 247, 208, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-200:hover {
  color: rgba(187, 247, 208, var(--tw-text-opacity));
}

.dark .text-green-300 {
  color: rgba(22, 163, 74, var(--tw-text-opacity));
}

.dark .text-green-300.nightwind-prevent {
  color: rgba(134, 239, 172, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-300 {
  color: rgba(134, 239, 172, var(--tw-text-opacity));
}

.dark .hover\:text-green-300:hover {
  color: rgba(22, 163, 74, var(--tw-text-opacity));
}

.dark .hover\:text-green-300:hover.nightwind-prevent {
  color: rgba(134, 239, 172, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-300:hover {
  color: rgba(134, 239, 172, var(--tw-text-opacity));
}

.dark .text-green-400 {
  color: rgba(34, 197, 94, var(--tw-text-opacity));
}

.dark .text-green-400.nightwind-prevent {
  color: rgba(74, 222, 128, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-400 {
  color: rgba(74, 222, 128, var(--tw-text-opacity));
}

.dark .hover\:text-green-400:hover {
  color: rgba(34, 197, 94, var(--tw-text-opacity));
}

.dark .hover\:text-green-400:hover.nightwind-prevent {
  color: rgba(74, 222, 128, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-400:hover {
  color: rgba(74, 222, 128, var(--tw-text-opacity));
}

.dark .text-green-500 {
  color: rgba(74, 222, 128, var(--tw-text-opacity));
}

.dark .text-green-500.nightwind-prevent {
  color: rgba(34, 197, 94, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-500 {
  color: rgba(34, 197, 94, var(--tw-text-opacity));
}

.dark .hover\:text-green-500:hover {
  color: rgba(74, 222, 128, var(--tw-text-opacity));
}

.dark .hover\:text-green-500:hover.nightwind-prevent {
  color: rgba(34, 197, 94, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-500:hover {
  color: rgba(34, 197, 94, var(--tw-text-opacity));
}

.dark .text-green-600 {
  color: rgba(134, 239, 172, var(--tw-text-opacity));
}

.dark .text-green-600.nightwind-prevent {
  color: rgba(22, 163, 74, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-600 {
  color: rgba(22, 163, 74, var(--tw-text-opacity));
}

.dark .hover\:text-green-600:hover {
  color: rgba(134, 239, 172, var(--tw-text-opacity));
}

.dark .hover\:text-green-600:hover.nightwind-prevent {
  color: rgba(22, 163, 74, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-600:hover {
  color: rgba(22, 163, 74, var(--tw-text-opacity));
}

.dark .text-green-700 {
  color: rgba(187, 247, 208, var(--tw-text-opacity));
}

.dark .text-green-700.nightwind-prevent {
  color: rgba(21, 128, 61, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-700 {
  color: rgba(21, 128, 61, var(--tw-text-opacity));
}

.dark .hover\:text-green-700:hover {
  color: rgba(187, 247, 208, var(--tw-text-opacity));
}

.dark .hover\:text-green-700:hover.nightwind-prevent {
  color: rgba(21, 128, 61, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-700:hover {
  color: rgba(21, 128, 61, var(--tw-text-opacity));
}

.dark .text-green-800 {
  color: rgba(220, 252, 231, var(--tw-text-opacity));
}

.dark .text-green-800.nightwind-prevent {
  color: rgba(22, 101, 52, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-800 {
  color: rgba(22, 101, 52, var(--tw-text-opacity));
}

.dark .hover\:text-green-800:hover {
  color: rgba(220, 252, 231, var(--tw-text-opacity));
}

.dark .hover\:text-green-800:hover.nightwind-prevent {
  color: rgba(22, 101, 52, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-800:hover {
  color: rgba(22, 101, 52, var(--tw-text-opacity));
}

.dark .text-green-900 {
  color: rgba(240, 253, 244, var(--tw-text-opacity));
}

.dark .text-green-900.nightwind-prevent {
  color: rgba(20, 83, 45, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-green-900 {
  color: rgba(20, 83, 45, var(--tw-text-opacity));
}

.dark .hover\:text-green-900:hover {
  color: rgba(240, 253, 244, var(--tw-text-opacity));
}

.dark .hover\:text-green-900:hover.nightwind-prevent {
  color: rgba(20, 83, 45, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-green-900:hover {
  color: rgba(20, 83, 45, var(--tw-text-opacity));
}

.dark .text-emerald-50 {
  color: rgba(6, 78, 59, var(--tw-text-opacity));
}

.dark .text-emerald-50.nightwind-prevent {
  color: rgba(236, 253, 245, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-50 {
  color: rgba(236, 253, 245, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-50:hover {
  color: rgba(6, 78, 59, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-50:hover.nightwind-prevent {
  color: rgba(236, 253, 245, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-50:hover {
  color: rgba(236, 253, 245, var(--tw-text-opacity));
}

.dark .text-emerald-100 {
  color: rgba(6, 95, 70, var(--tw-text-opacity));
}

.dark .text-emerald-100.nightwind-prevent {
  color: rgba(209, 250, 229, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-100 {
  color: rgba(209, 250, 229, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-100:hover {
  color: rgba(6, 95, 70, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-100:hover.nightwind-prevent {
  color: rgba(209, 250, 229, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-100:hover {
  color: rgba(209, 250, 229, var(--tw-text-opacity));
}

.dark .text-emerald-200 {
  color: rgba(4, 120, 87, var(--tw-text-opacity));
}

.dark .text-emerald-200.nightwind-prevent {
  color: rgba(167, 243, 208, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-200 {
  color: rgba(167, 243, 208, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-200:hover {
  color: rgba(4, 120, 87, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-200:hover.nightwind-prevent {
  color: rgba(167, 243, 208, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-200:hover {
  color: rgba(167, 243, 208, var(--tw-text-opacity));
}

.dark .text-emerald-300 {
  color: rgba(5, 150, 105, var(--tw-text-opacity));
}

.dark .text-emerald-300.nightwind-prevent {
  color: rgba(110, 231, 183, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-300 {
  color: rgba(110, 231, 183, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-300:hover {
  color: rgba(5, 150, 105, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-300:hover.nightwind-prevent {
  color: rgba(110, 231, 183, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-300:hover {
  color: rgba(110, 231, 183, var(--tw-text-opacity));
}

.dark .text-emerald-400 {
  color: rgba(16, 185, 129, var(--tw-text-opacity));
}

.dark .text-emerald-400.nightwind-prevent {
  color: rgba(52, 211, 153, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-400 {
  color: rgba(52, 211, 153, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-400:hover {
  color: rgba(16, 185, 129, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-400:hover.nightwind-prevent {
  color: rgba(52, 211, 153, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-400:hover {
  color: rgba(52, 211, 153, var(--tw-text-opacity));
}

.dark .text-emerald-500 {
  color: rgba(52, 211, 153, var(--tw-text-opacity));
}

.dark .text-emerald-500.nightwind-prevent {
  color: rgba(16, 185, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-500 {
  color: rgba(16, 185, 129, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-500:hover {
  color: rgba(52, 211, 153, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-500:hover.nightwind-prevent {
  color: rgba(16, 185, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-500:hover {
  color: rgba(16, 185, 129, var(--tw-text-opacity));
}

.dark .text-emerald-600 {
  color: rgba(110, 231, 183, var(--tw-text-opacity));
}

.dark .text-emerald-600.nightwind-prevent {
  color: rgba(5, 150, 105, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-600 {
  color: rgba(5, 150, 105, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-600:hover {
  color: rgba(110, 231, 183, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-600:hover.nightwind-prevent {
  color: rgba(5, 150, 105, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-600:hover {
  color: rgba(5, 150, 105, var(--tw-text-opacity));
}

.dark .text-emerald-700 {
  color: rgba(167, 243, 208, var(--tw-text-opacity));
}

.dark .text-emerald-700.nightwind-prevent {
  color: rgba(4, 120, 87, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-700 {
  color: rgba(4, 120, 87, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-700:hover {
  color: rgba(167, 243, 208, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-700:hover.nightwind-prevent {
  color: rgba(4, 120, 87, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-700:hover {
  color: rgba(4, 120, 87, var(--tw-text-opacity));
}

.dark .text-emerald-800 {
  color: rgba(209, 250, 229, var(--tw-text-opacity));
}

.dark .text-emerald-800.nightwind-prevent {
  color: rgba(6, 95, 70, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-800 {
  color: rgba(6, 95, 70, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-800:hover {
  color: rgba(209, 250, 229, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-800:hover.nightwind-prevent {
  color: rgba(6, 95, 70, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-800:hover {
  color: rgba(6, 95, 70, var(--tw-text-opacity));
}

.dark .text-emerald-900 {
  color: rgba(236, 253, 245, var(--tw-text-opacity));
}

.dark .text-emerald-900.nightwind-prevent {
  color: rgba(6, 78, 59, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-emerald-900 {
  color: rgba(6, 78, 59, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-900:hover {
  color: rgba(236, 253, 245, var(--tw-text-opacity));
}

.dark .hover\:text-emerald-900:hover.nightwind-prevent {
  color: rgba(6, 78, 59, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-emerald-900:hover {
  color: rgba(6, 78, 59, var(--tw-text-opacity));
}

.dark .text-teal-50 {
  color: rgba(19, 78, 74, var(--tw-text-opacity));
}

.dark .text-teal-50.nightwind-prevent {
  color: rgba(240, 253, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-50 {
  color: rgba(240, 253, 250, var(--tw-text-opacity));
}

.dark .hover\:text-teal-50:hover {
  color: rgba(19, 78, 74, var(--tw-text-opacity));
}

.dark .hover\:text-teal-50:hover.nightwind-prevent {
  color: rgba(240, 253, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-50:hover {
  color: rgba(240, 253, 250, var(--tw-text-opacity));
}

.dark .text-teal-100 {
  color: rgba(17, 94, 89, var(--tw-text-opacity));
}

.dark .text-teal-100.nightwind-prevent {
  color: rgba(204, 251, 241, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-100 {
  color: rgba(204, 251, 241, var(--tw-text-opacity));
}

.dark .hover\:text-teal-100:hover {
  color: rgba(17, 94, 89, var(--tw-text-opacity));
}

.dark .hover\:text-teal-100:hover.nightwind-prevent {
  color: rgba(204, 251, 241, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-100:hover {
  color: rgba(204, 251, 241, var(--tw-text-opacity));
}

.dark .text-teal-200 {
  color: rgba(15, 118, 110, var(--tw-text-opacity));
}

.dark .text-teal-200.nightwind-prevent {
  color: rgba(153, 246, 228, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-200 {
  color: rgba(153, 246, 228, var(--tw-text-opacity));
}

.dark .hover\:text-teal-200:hover {
  color: rgba(15, 118, 110, var(--tw-text-opacity));
}

.dark .hover\:text-teal-200:hover.nightwind-prevent {
  color: rgba(153, 246, 228, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-200:hover {
  color: rgba(153, 246, 228, var(--tw-text-opacity));
}

.dark .text-teal-300 {
  color: rgba(13, 148, 136, var(--tw-text-opacity));
}

.dark .text-teal-300.nightwind-prevent {
  color: rgba(94, 234, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-300 {
  color: rgba(94, 234, 212, var(--tw-text-opacity));
}

.dark .hover\:text-teal-300:hover {
  color: rgba(13, 148, 136, var(--tw-text-opacity));
}

.dark .hover\:text-teal-300:hover.nightwind-prevent {
  color: rgba(94, 234, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-300:hover {
  color: rgba(94, 234, 212, var(--tw-text-opacity));
}

.dark .text-teal-400 {
  color: rgba(20, 184, 166, var(--tw-text-opacity));
}

.dark .text-teal-400.nightwind-prevent {
  color: rgba(45, 212, 191, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-400 {
  color: rgba(45, 212, 191, var(--tw-text-opacity));
}

.dark .hover\:text-teal-400:hover {
  color: rgba(20, 184, 166, var(--tw-text-opacity));
}

.dark .hover\:text-teal-400:hover.nightwind-prevent {
  color: rgba(45, 212, 191, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-400:hover {
  color: rgba(45, 212, 191, var(--tw-text-opacity));
}

.dark .text-teal-500 {
  color: rgba(45, 212, 191, var(--tw-text-opacity));
}

.dark .text-teal-500.nightwind-prevent {
  color: rgba(20, 184, 166, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-500 {
  color: rgba(20, 184, 166, var(--tw-text-opacity));
}

.dark .hover\:text-teal-500:hover {
  color: rgba(45, 212, 191, var(--tw-text-opacity));
}

.dark .hover\:text-teal-500:hover.nightwind-prevent {
  color: rgba(20, 184, 166, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-500:hover {
  color: rgba(20, 184, 166, var(--tw-text-opacity));
}

.dark .text-teal-600 {
  color: rgba(94, 234, 212, var(--tw-text-opacity));
}

.dark .text-teal-600.nightwind-prevent {
  color: rgba(13, 148, 136, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-600 {
  color: rgba(13, 148, 136, var(--tw-text-opacity));
}

.dark .hover\:text-teal-600:hover {
  color: rgba(94, 234, 212, var(--tw-text-opacity));
}

.dark .hover\:text-teal-600:hover.nightwind-prevent {
  color: rgba(13, 148, 136, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-600:hover {
  color: rgba(13, 148, 136, var(--tw-text-opacity));
}

.dark .text-teal-700 {
  color: rgba(153, 246, 228, var(--tw-text-opacity));
}

.dark .text-teal-700.nightwind-prevent {
  color: rgba(15, 118, 110, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-700 {
  color: rgba(15, 118, 110, var(--tw-text-opacity));
}

.dark .hover\:text-teal-700:hover {
  color: rgba(153, 246, 228, var(--tw-text-opacity));
}

.dark .hover\:text-teal-700:hover.nightwind-prevent {
  color: rgba(15, 118, 110, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-700:hover {
  color: rgba(15, 118, 110, var(--tw-text-opacity));
}

.dark .text-teal-800 {
  color: rgba(204, 251, 241, var(--tw-text-opacity));
}

.dark .text-teal-800.nightwind-prevent {
  color: rgba(17, 94, 89, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-800 {
  color: rgba(17, 94, 89, var(--tw-text-opacity));
}

.dark .hover\:text-teal-800:hover {
  color: rgba(204, 251, 241, var(--tw-text-opacity));
}

.dark .hover\:text-teal-800:hover.nightwind-prevent {
  color: rgba(17, 94, 89, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-800:hover {
  color: rgba(17, 94, 89, var(--tw-text-opacity));
}

.dark .text-teal-900 {
  color: rgba(240, 253, 250, var(--tw-text-opacity));
}

.dark .text-teal-900.nightwind-prevent {
  color: rgba(19, 78, 74, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-teal-900 {
  color: rgba(19, 78, 74, var(--tw-text-opacity));
}

.dark .hover\:text-teal-900:hover {
  color: rgba(240, 253, 250, var(--tw-text-opacity));
}

.dark .hover\:text-teal-900:hover.nightwind-prevent {
  color: rgba(19, 78, 74, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-teal-900:hover {
  color: rgba(19, 78, 74, var(--tw-text-opacity));
}

.dark .text-cyan-50 {
  color: rgba(22, 78, 99, var(--tw-text-opacity));
}

.dark .text-cyan-50.nightwind-prevent {
  color: rgba(236, 254, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-50 {
  color: rgba(236, 254, 255, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-50:hover {
  color: rgba(22, 78, 99, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-50:hover.nightwind-prevent {
  color: rgba(236, 254, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-50:hover {
  color: rgba(236, 254, 255, var(--tw-text-opacity));
}

.dark .text-cyan-100 {
  color: rgba(21, 94, 117, var(--tw-text-opacity));
}

.dark .text-cyan-100.nightwind-prevent {
  color: rgba(207, 250, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-100 {
  color: rgba(207, 250, 254, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-100:hover {
  color: rgba(21, 94, 117, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-100:hover.nightwind-prevent {
  color: rgba(207, 250, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-100:hover {
  color: rgba(207, 250, 254, var(--tw-text-opacity));
}

.dark .text-cyan-200 {
  color: rgba(14, 116, 144, var(--tw-text-opacity));
}

.dark .text-cyan-200.nightwind-prevent {
  color: rgba(165, 243, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-200 {
  color: rgba(165, 243, 252, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-200:hover {
  color: rgba(14, 116, 144, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-200:hover.nightwind-prevent {
  color: rgba(165, 243, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-200:hover {
  color: rgba(165, 243, 252, var(--tw-text-opacity));
}

.dark .text-cyan-300 {
  color: rgba(8, 145, 178, var(--tw-text-opacity));
}

.dark .text-cyan-300.nightwind-prevent {
  color: rgba(103, 232, 249, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-300 {
  color: rgba(103, 232, 249, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-300:hover {
  color: rgba(8, 145, 178, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-300:hover.nightwind-prevent {
  color: rgba(103, 232, 249, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-300:hover {
  color: rgba(103, 232, 249, var(--tw-text-opacity));
}

.dark .text-cyan-400 {
  color: rgba(6, 182, 212, var(--tw-text-opacity));
}

.dark .text-cyan-400.nightwind-prevent {
  color: rgba(34, 211, 238, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-400 {
  color: rgba(34, 211, 238, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-400:hover {
  color: rgba(6, 182, 212, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-400:hover.nightwind-prevent {
  color: rgba(34, 211, 238, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-400:hover {
  color: rgba(34, 211, 238, var(--tw-text-opacity));
}

.dark .text-cyan-500 {
  color: rgba(34, 211, 238, var(--tw-text-opacity));
}

.dark .text-cyan-500.nightwind-prevent {
  color: rgba(6, 182, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-500 {
  color: rgba(6, 182, 212, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-500:hover {
  color: rgba(34, 211, 238, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-500:hover.nightwind-prevent {
  color: rgba(6, 182, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-500:hover {
  color: rgba(6, 182, 212, var(--tw-text-opacity));
}

.dark .text-cyan-600 {
  color: rgba(103, 232, 249, var(--tw-text-opacity));
}

.dark .text-cyan-600.nightwind-prevent {
  color: rgba(8, 145, 178, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-600 {
  color: rgba(8, 145, 178, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-600:hover {
  color: rgba(103, 232, 249, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-600:hover.nightwind-prevent {
  color: rgba(8, 145, 178, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-600:hover {
  color: rgba(8, 145, 178, var(--tw-text-opacity));
}

.dark .text-cyan-700 {
  color: rgba(165, 243, 252, var(--tw-text-opacity));
}

.dark .text-cyan-700.nightwind-prevent {
  color: rgba(14, 116, 144, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-700 {
  color: rgba(14, 116, 144, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-700:hover {
  color: rgba(165, 243, 252, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-700:hover.nightwind-prevent {
  color: rgba(14, 116, 144, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-700:hover {
  color: rgba(14, 116, 144, var(--tw-text-opacity));
}

.dark .text-cyan-800 {
  color: rgba(207, 250, 254, var(--tw-text-opacity));
}

.dark .text-cyan-800.nightwind-prevent {
  color: rgba(21, 94, 117, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-800 {
  color: rgba(21, 94, 117, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-800:hover {
  color: rgba(207, 250, 254, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-800:hover.nightwind-prevent {
  color: rgba(21, 94, 117, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-800:hover {
  color: rgba(21, 94, 117, var(--tw-text-opacity));
}

.dark .text-cyan-900 {
  color: rgba(236, 254, 255, var(--tw-text-opacity));
}

.dark .text-cyan-900.nightwind-prevent {
  color: rgba(22, 78, 99, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-cyan-900 {
  color: rgba(22, 78, 99, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-900:hover {
  color: rgba(236, 254, 255, var(--tw-text-opacity));
}

.dark .hover\:text-cyan-900:hover.nightwind-prevent {
  color: rgba(22, 78, 99, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-cyan-900:hover {
  color: rgba(22, 78, 99, var(--tw-text-opacity));
}

.dark .text-sky-50 {
  color: rgba(12, 74, 110, var(--tw-text-opacity));
}

.dark .text-sky-50.nightwind-prevent {
  color: rgba(240, 249, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-50 {
  color: rgba(240, 249, 255, var(--tw-text-opacity));
}

.dark .hover\:text-sky-50:hover {
  color: rgba(12, 74, 110, var(--tw-text-opacity));
}

.dark .hover\:text-sky-50:hover.nightwind-prevent {
  color: rgba(240, 249, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-50:hover {
  color: rgba(240, 249, 255, var(--tw-text-opacity));
}

.dark .text-sky-100 {
  color: rgba(7, 89, 133, var(--tw-text-opacity));
}

.dark .text-sky-100.nightwind-prevent {
  color: rgba(224, 242, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-100 {
  color: rgba(224, 242, 254, var(--tw-text-opacity));
}

.dark .hover\:text-sky-100:hover {
  color: rgba(7, 89, 133, var(--tw-text-opacity));
}

.dark .hover\:text-sky-100:hover.nightwind-prevent {
  color: rgba(224, 242, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-100:hover {
  color: rgba(224, 242, 254, var(--tw-text-opacity));
}

.dark .text-sky-200 {
  color: rgba(3, 105, 161, var(--tw-text-opacity));
}

.dark .text-sky-200.nightwind-prevent {
  color: rgba(186, 230, 253, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-200 {
  color: rgba(186, 230, 253, var(--tw-text-opacity));
}

.dark .hover\:text-sky-200:hover {
  color: rgba(3, 105, 161, var(--tw-text-opacity));
}

.dark .hover\:text-sky-200:hover.nightwind-prevent {
  color: rgba(186, 230, 253, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-200:hover {
  color: rgba(186, 230, 253, var(--tw-text-opacity));
}

.dark .text-sky-300 {
  color: rgba(2, 132, 199, var(--tw-text-opacity));
}

.dark .text-sky-300.nightwind-prevent {
  color: rgba(125, 211, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-300 {
  color: rgba(125, 211, 252, var(--tw-text-opacity));
}

.dark .hover\:text-sky-300:hover {
  color: rgba(2, 132, 199, var(--tw-text-opacity));
}

.dark .hover\:text-sky-300:hover.nightwind-prevent {
  color: rgba(125, 211, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-300:hover {
  color: rgba(125, 211, 252, var(--tw-text-opacity));
}

.dark .text-sky-400 {
  color: rgba(14, 165, 233, var(--tw-text-opacity));
}

.dark .text-sky-400.nightwind-prevent {
  color: rgba(56, 189, 248, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-400 {
  color: rgba(56, 189, 248, var(--tw-text-opacity));
}

.dark .hover\:text-sky-400:hover {
  color: rgba(14, 165, 233, var(--tw-text-opacity));
}

.dark .hover\:text-sky-400:hover.nightwind-prevent {
  color: rgba(56, 189, 248, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-400:hover {
  color: rgba(56, 189, 248, var(--tw-text-opacity));
}

.dark .text-sky-500 {
  color: rgba(56, 189, 248, var(--tw-text-opacity));
}

.dark .text-sky-500.nightwind-prevent {
  color: rgba(14, 165, 233, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-500 {
  color: rgba(14, 165, 233, var(--tw-text-opacity));
}

.dark .hover\:text-sky-500:hover {
  color: rgba(56, 189, 248, var(--tw-text-opacity));
}

.dark .hover\:text-sky-500:hover.nightwind-prevent {
  color: rgba(14, 165, 233, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-500:hover {
  color: rgba(14, 165, 233, var(--tw-text-opacity));
}

.dark .text-sky-600 {
  color: rgba(125, 211, 252, var(--tw-text-opacity));
}

.dark .text-sky-600.nightwind-prevent {
  color: rgba(2, 132, 199, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-600 {
  color: rgba(2, 132, 199, var(--tw-text-opacity));
}

.dark .hover\:text-sky-600:hover {
  color: rgba(125, 211, 252, var(--tw-text-opacity));
}

.dark .hover\:text-sky-600:hover.nightwind-prevent {
  color: rgba(2, 132, 199, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-600:hover {
  color: rgba(2, 132, 199, var(--tw-text-opacity));
}

.dark .text-sky-700 {
  color: rgba(186, 230, 253, var(--tw-text-opacity));
}

.dark .text-sky-700.nightwind-prevent {
  color: rgba(3, 105, 161, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-700 {
  color: rgba(3, 105, 161, var(--tw-text-opacity));
}

.dark .hover\:text-sky-700:hover {
  color: rgba(186, 230, 253, var(--tw-text-opacity));
}

.dark .hover\:text-sky-700:hover.nightwind-prevent {
  color: rgba(3, 105, 161, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-700:hover {
  color: rgba(3, 105, 161, var(--tw-text-opacity));
}

.dark .text-sky-800 {
  color: rgba(224, 242, 254, var(--tw-text-opacity));
}

.dark .text-sky-800.nightwind-prevent {
  color: rgba(7, 89, 133, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-800 {
  color: rgba(7, 89, 133, var(--tw-text-opacity));
}

.dark .hover\:text-sky-800:hover {
  color: rgba(224, 242, 254, var(--tw-text-opacity));
}

.dark .hover\:text-sky-800:hover.nightwind-prevent {
  color: rgba(7, 89, 133, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-800:hover {
  color: rgba(7, 89, 133, var(--tw-text-opacity));
}

.dark .text-sky-900 {
  color: rgba(240, 249, 255, var(--tw-text-opacity));
}

.dark .text-sky-900.nightwind-prevent {
  color: rgba(12, 74, 110, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-sky-900 {
  color: rgba(12, 74, 110, var(--tw-text-opacity));
}

.dark .hover\:text-sky-900:hover {
  color: rgba(240, 249, 255, var(--tw-text-opacity));
}

.dark .hover\:text-sky-900:hover.nightwind-prevent {
  color: rgba(12, 74, 110, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-sky-900:hover {
  color: rgba(12, 74, 110, var(--tw-text-opacity));
}

.dark .text-blue-50 {
  color: rgba(30, 58, 138, var(--tw-text-opacity));
}

.dark .text-blue-50.nightwind-prevent {
  color: rgba(239, 246, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-50 {
  color: rgba(239, 246, 255, var(--tw-text-opacity));
}

.dark .hover\:text-blue-50:hover {
  color: rgba(30, 58, 138, var(--tw-text-opacity));
}

.dark .hover\:text-blue-50:hover.nightwind-prevent {
  color: rgba(239, 246, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-50:hover {
  color: rgba(239, 246, 255, var(--tw-text-opacity));
}

.dark .text-blue-100 {
  color: rgba(30, 64, 175, var(--tw-text-opacity));
}

.dark .text-blue-100.nightwind-prevent {
  color: rgba(219, 234, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-100 {
  color: rgba(219, 234, 254, var(--tw-text-opacity));
}

.dark .hover\:text-blue-100:hover {
  color: rgba(30, 64, 175, var(--tw-text-opacity));
}

.dark .hover\:text-blue-100:hover.nightwind-prevent {
  color: rgba(219, 234, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-100:hover {
  color: rgba(219, 234, 254, var(--tw-text-opacity));
}

.dark .text-blue-200 {
  color: rgba(29, 78, 216, var(--tw-text-opacity));
}

.dark .text-blue-200.nightwind-prevent {
  color: rgba(191, 219, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-200 {
  color: rgba(191, 219, 254, var(--tw-text-opacity));
}

.dark .hover\:text-blue-200:hover {
  color: rgba(29, 78, 216, var(--tw-text-opacity));
}

.dark .hover\:text-blue-200:hover.nightwind-prevent {
  color: rgba(191, 219, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-200:hover {
  color: rgba(191, 219, 254, var(--tw-text-opacity));
}

.dark .text-blue-300 {
  color: rgba(37, 99, 235, var(--tw-text-opacity));
}

.dark .text-blue-300.nightwind-prevent {
  color: rgba(147, 197, 253, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-300 {
  color: rgba(147, 197, 253, var(--tw-text-opacity));
}

.dark .hover\:text-blue-300:hover {
  color: rgba(37, 99, 235, var(--tw-text-opacity));
}

.dark .hover\:text-blue-300:hover.nightwind-prevent {
  color: rgba(147, 197, 253, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-300:hover {
  color: rgba(147, 197, 253, var(--tw-text-opacity));
}

.dark .text-blue-400 {
  color: rgba(59, 130, 246, var(--tw-text-opacity));
}

.dark .text-blue-400.nightwind-prevent {
  color: rgba(96, 165, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-400 {
  color: rgba(96, 165, 250, var(--tw-text-opacity));
}

.dark .hover\:text-blue-400:hover {
  color: rgba(59, 130, 246, var(--tw-text-opacity));
}

.dark .hover\:text-blue-400:hover.nightwind-prevent {
  color: rgba(96, 165, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-400:hover {
  color: rgba(96, 165, 250, var(--tw-text-opacity));
}

.dark .text-blue-500 {
  color: rgba(96, 165, 250, var(--tw-text-opacity));
}

.dark .text-blue-500.nightwind-prevent {
  color: rgba(59, 130, 246, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-500 {
  color: rgba(59, 130, 246, var(--tw-text-opacity));
}

.dark .hover\:text-blue-500:hover {
  color: rgba(96, 165, 250, var(--tw-text-opacity));
}

.dark .hover\:text-blue-500:hover.nightwind-prevent {
  color: rgba(59, 130, 246, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-500:hover {
  color: rgba(59, 130, 246, var(--tw-text-opacity));
}

.dark .text-blue-600 {
  color: rgba(147, 197, 253, var(--tw-text-opacity));
}

.dark .text-blue-600.nightwind-prevent {
  color: rgba(37, 99, 235, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-600 {
  color: rgba(37, 99, 235, var(--tw-text-opacity));
}

.dark .hover\:text-blue-600:hover {
  color: rgba(147, 197, 253, var(--tw-text-opacity));
}

.dark .hover\:text-blue-600:hover.nightwind-prevent {
  color: rgba(37, 99, 235, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-600:hover {
  color: rgba(37, 99, 235, var(--tw-text-opacity));
}

.dark .text-blue-700 {
  color: rgba(191, 219, 254, var(--tw-text-opacity));
}

.dark .text-blue-700.nightwind-prevent {
  color: rgba(29, 78, 216, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-700 {
  color: rgba(29, 78, 216, var(--tw-text-opacity));
}

.dark .hover\:text-blue-700:hover {
  color: rgba(191, 219, 254, var(--tw-text-opacity));
}

.dark .hover\:text-blue-700:hover.nightwind-prevent {
  color: rgba(29, 78, 216, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-700:hover {
  color: rgba(29, 78, 216, var(--tw-text-opacity));
}

.dark .text-blue-800 {
  color: rgba(219, 234, 254, var(--tw-text-opacity));
}

.dark .text-blue-800.nightwind-prevent {
  color: rgba(30, 64, 175, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-800 {
  color: rgba(30, 64, 175, var(--tw-text-opacity));
}

.dark .hover\:text-blue-800:hover {
  color: rgba(219, 234, 254, var(--tw-text-opacity));
}

.dark .hover\:text-blue-800:hover.nightwind-prevent {
  color: rgba(30, 64, 175, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-800:hover {
  color: rgba(30, 64, 175, var(--tw-text-opacity));
}

.dark .text-blue-900 {
  color: rgba(239, 246, 255, var(--tw-text-opacity));
}

.dark .text-blue-900.nightwind-prevent {
  color: rgba(30, 58, 138, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-blue-900 {
  color: rgba(30, 58, 138, var(--tw-text-opacity));
}

.dark .hover\:text-blue-900:hover {
  color: rgba(239, 246, 255, var(--tw-text-opacity));
}

.dark .hover\:text-blue-900:hover.nightwind-prevent {
  color: rgba(30, 58, 138, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-blue-900:hover {
  color: rgba(30, 58, 138, var(--tw-text-opacity));
}

.dark .text-indigo-50 {
  color: rgba(49, 46, 129, var(--tw-text-opacity));
}

.dark .text-indigo-50.nightwind-prevent {
  color: rgba(238, 242, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-50 {
  color: rgba(238, 242, 255, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-50:hover {
  color: rgba(49, 46, 129, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-50:hover.nightwind-prevent {
  color: rgba(238, 242, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-50:hover {
  color: rgba(238, 242, 255, var(--tw-text-opacity));
}

.dark .text-indigo-100 {
  color: rgba(55, 48, 163, var(--tw-text-opacity));
}

.dark .text-indigo-100.nightwind-prevent {
  color: rgba(224, 231, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-100 {
  color: rgba(224, 231, 255, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-100:hover {
  color: rgba(55, 48, 163, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-100:hover.nightwind-prevent {
  color: rgba(224, 231, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-100:hover {
  color: rgba(224, 231, 255, var(--tw-text-opacity));
}

.dark .text-indigo-200 {
  color: rgba(67, 56, 202, var(--tw-text-opacity));
}

.dark .text-indigo-200.nightwind-prevent {
  color: rgba(199, 210, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-200 {
  color: rgba(199, 210, 254, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-200:hover {
  color: rgba(67, 56, 202, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-200:hover.nightwind-prevent {
  color: rgba(199, 210, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-200:hover {
  color: rgba(199, 210, 254, var(--tw-text-opacity));
}

.dark .text-indigo-300 {
  color: rgba(79, 70, 229, var(--tw-text-opacity));
}

.dark .text-indigo-300.nightwind-prevent {
  color: rgba(165, 180, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-300 {
  color: rgba(165, 180, 252, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-300:hover {
  color: rgba(79, 70, 229, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-300:hover.nightwind-prevent {
  color: rgba(165, 180, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-300:hover {
  color: rgba(165, 180, 252, var(--tw-text-opacity));
}

.dark .text-indigo-400 {
  color: rgba(99, 102, 241, var(--tw-text-opacity));
}

.dark .text-indigo-400.nightwind-prevent {
  color: rgba(129, 140, 248, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-400 {
  color: rgba(129, 140, 248, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-400:hover {
  color: rgba(99, 102, 241, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-400:hover.nightwind-prevent {
  color: rgba(129, 140, 248, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-400:hover {
  color: rgba(129, 140, 248, var(--tw-text-opacity));
}

.dark .text-indigo-500 {
  color: rgba(129, 140, 248, var(--tw-text-opacity));
}

.dark .text-indigo-500.nightwind-prevent {
  color: rgba(99, 102, 241, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-500 {
  color: rgba(99, 102, 241, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-500:hover {
  color: rgba(129, 140, 248, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-500:hover.nightwind-prevent {
  color: rgba(99, 102, 241, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-500:hover {
  color: rgba(99, 102, 241, var(--tw-text-opacity));
}

.dark .text-indigo-600 {
  color: rgba(165, 180, 252, var(--tw-text-opacity));
}

.dark .text-indigo-600.nightwind-prevent {
  color: rgba(79, 70, 229, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-600 {
  color: rgba(79, 70, 229, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-600:hover {
  color: rgba(165, 180, 252, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-600:hover.nightwind-prevent {
  color: rgba(79, 70, 229, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-600:hover {
  color: rgba(79, 70, 229, var(--tw-text-opacity));
}

.dark .text-indigo-700 {
  color: rgba(199, 210, 254, var(--tw-text-opacity));
}

.dark .text-indigo-700.nightwind-prevent {
  color: rgba(67, 56, 202, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-700 {
  color: rgba(67, 56, 202, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-700:hover {
  color: rgba(199, 210, 254, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-700:hover.nightwind-prevent {
  color: rgba(67, 56, 202, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-700:hover {
  color: rgba(67, 56, 202, var(--tw-text-opacity));
}

.dark .text-indigo-800 {
  color: rgba(224, 231, 255, var(--tw-text-opacity));
}

.dark .text-indigo-800.nightwind-prevent {
  color: rgba(55, 48, 163, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-800 {
  color: rgba(55, 48, 163, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-800:hover {
  color: rgba(224, 231, 255, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-800:hover.nightwind-prevent {
  color: rgba(55, 48, 163, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-800:hover {
  color: rgba(55, 48, 163, var(--tw-text-opacity));
}

.dark .text-indigo-900 {
  color: rgba(238, 242, 255, var(--tw-text-opacity));
}

.dark .text-indigo-900.nightwind-prevent {
  color: rgba(49, 46, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-indigo-900 {
  color: rgba(49, 46, 129, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-900:hover {
  color: rgba(238, 242, 255, var(--tw-text-opacity));
}

.dark .hover\:text-indigo-900:hover.nightwind-prevent {
  color: rgba(49, 46, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-indigo-900:hover {
  color: rgba(49, 46, 129, var(--tw-text-opacity));
}

.dark .text-violet-50 {
  color: rgba(76, 29, 149, var(--tw-text-opacity));
}

.dark .text-violet-50.nightwind-prevent {
  color: rgba(245, 243, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-50 {
  color: rgba(245, 243, 255, var(--tw-text-opacity));
}

.dark .hover\:text-violet-50:hover {
  color: rgba(76, 29, 149, var(--tw-text-opacity));
}

.dark .hover\:text-violet-50:hover.nightwind-prevent {
  color: rgba(245, 243, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-50:hover {
  color: rgba(245, 243, 255, var(--tw-text-opacity));
}

.dark .text-violet-100 {
  color: rgba(91, 33, 182, var(--tw-text-opacity));
}

.dark .text-violet-100.nightwind-prevent {
  color: rgba(237, 233, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-100 {
  color: rgba(237, 233, 254, var(--tw-text-opacity));
}

.dark .hover\:text-violet-100:hover {
  color: rgba(91, 33, 182, var(--tw-text-opacity));
}

.dark .hover\:text-violet-100:hover.nightwind-prevent {
  color: rgba(237, 233, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-100:hover {
  color: rgba(237, 233, 254, var(--tw-text-opacity));
}

.dark .text-violet-200 {
  color: rgba(109, 40, 217, var(--tw-text-opacity));
}

.dark .text-violet-200.nightwind-prevent {
  color: rgba(221, 214, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-200 {
  color: rgba(221, 214, 254, var(--tw-text-opacity));
}

.dark .hover\:text-violet-200:hover {
  color: rgba(109, 40, 217, var(--tw-text-opacity));
}

.dark .hover\:text-violet-200:hover.nightwind-prevent {
  color: rgba(221, 214, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-200:hover {
  color: rgba(221, 214, 254, var(--tw-text-opacity));
}

.dark .text-violet-300 {
  color: rgba(124, 58, 237, var(--tw-text-opacity));
}

.dark .text-violet-300.nightwind-prevent {
  color: rgba(196, 181, 253, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-300 {
  color: rgba(196, 181, 253, var(--tw-text-opacity));
}

.dark .hover\:text-violet-300:hover {
  color: rgba(124, 58, 237, var(--tw-text-opacity));
}

.dark .hover\:text-violet-300:hover.nightwind-prevent {
  color: rgba(196, 181, 253, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-300:hover {
  color: rgba(196, 181, 253, var(--tw-text-opacity));
}

.dark .text-violet-400 {
  color: rgba(139, 92, 246, var(--tw-text-opacity));
}

.dark .text-violet-400.nightwind-prevent {
  color: rgba(167, 139, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-400 {
  color: rgba(167, 139, 250, var(--tw-text-opacity));
}

.dark .hover\:text-violet-400:hover {
  color: rgba(139, 92, 246, var(--tw-text-opacity));
}

.dark .hover\:text-violet-400:hover.nightwind-prevent {
  color: rgba(167, 139, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-400:hover {
  color: rgba(167, 139, 250, var(--tw-text-opacity));
}

.dark .text-violet-500 {
  color: rgba(167, 139, 250, var(--tw-text-opacity));
}

.dark .text-violet-500.nightwind-prevent {
  color: rgba(139, 92, 246, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-500 {
  color: rgba(139, 92, 246, var(--tw-text-opacity));
}

.dark .hover\:text-violet-500:hover {
  color: rgba(167, 139, 250, var(--tw-text-opacity));
}

.dark .hover\:text-violet-500:hover.nightwind-prevent {
  color: rgba(139, 92, 246, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-500:hover {
  color: rgba(139, 92, 246, var(--tw-text-opacity));
}

.dark .text-violet-600 {
  color: rgba(196, 181, 253, var(--tw-text-opacity));
}

.dark .text-violet-600.nightwind-prevent {
  color: rgba(124, 58, 237, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-600 {
  color: rgba(124, 58, 237, var(--tw-text-opacity));
}

.dark .hover\:text-violet-600:hover {
  color: rgba(196, 181, 253, var(--tw-text-opacity));
}

.dark .hover\:text-violet-600:hover.nightwind-prevent {
  color: rgba(124, 58, 237, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-600:hover {
  color: rgba(124, 58, 237, var(--tw-text-opacity));
}

.dark .text-violet-700 {
  color: rgba(221, 214, 254, var(--tw-text-opacity));
}

.dark .text-violet-700.nightwind-prevent {
  color: rgba(109, 40, 217, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-700 {
  color: rgba(109, 40, 217, var(--tw-text-opacity));
}

.dark .hover\:text-violet-700:hover {
  color: rgba(221, 214, 254, var(--tw-text-opacity));
}

.dark .hover\:text-violet-700:hover.nightwind-prevent {
  color: rgba(109, 40, 217, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-700:hover {
  color: rgba(109, 40, 217, var(--tw-text-opacity));
}

.dark .text-violet-800 {
  color: rgba(237, 233, 254, var(--tw-text-opacity));
}

.dark .text-violet-800.nightwind-prevent {
  color: rgba(91, 33, 182, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-800 {
  color: rgba(91, 33, 182, var(--tw-text-opacity));
}

.dark .hover\:text-violet-800:hover {
  color: rgba(237, 233, 254, var(--tw-text-opacity));
}

.dark .hover\:text-violet-800:hover.nightwind-prevent {
  color: rgba(91, 33, 182, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-800:hover {
  color: rgba(91, 33, 182, var(--tw-text-opacity));
}

.dark .text-violet-900 {
  color: rgba(245, 243, 255, var(--tw-text-opacity));
}

.dark .text-violet-900.nightwind-prevent {
  color: rgba(76, 29, 149, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-violet-900 {
  color: rgba(76, 29, 149, var(--tw-text-opacity));
}

.dark .hover\:text-violet-900:hover {
  color: rgba(245, 243, 255, var(--tw-text-opacity));
}

.dark .hover\:text-violet-900:hover.nightwind-prevent {
  color: rgba(76, 29, 149, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-violet-900:hover {
  color: rgba(76, 29, 149, var(--tw-text-opacity));
}

.dark .text-purple-50 {
  color: rgba(88, 28, 135, var(--tw-text-opacity));
}

.dark .text-purple-50.nightwind-prevent {
  color: rgba(250, 245, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-50 {
  color: rgba(250, 245, 255, var(--tw-text-opacity));
}

.dark .hover\:text-purple-50:hover {
  color: rgba(88, 28, 135, var(--tw-text-opacity));
}

.dark .hover\:text-purple-50:hover.nightwind-prevent {
  color: rgba(250, 245, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-50:hover {
  color: rgba(250, 245, 255, var(--tw-text-opacity));
}

.dark .text-purple-100 {
  color: rgba(107, 33, 168, var(--tw-text-opacity));
}

.dark .text-purple-100.nightwind-prevent {
  color: rgba(243, 232, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-100 {
  color: rgba(243, 232, 255, var(--tw-text-opacity));
}

.dark .hover\:text-purple-100:hover {
  color: rgba(107, 33, 168, var(--tw-text-opacity));
}

.dark .hover\:text-purple-100:hover.nightwind-prevent {
  color: rgba(243, 232, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-100:hover {
  color: rgba(243, 232, 255, var(--tw-text-opacity));
}

.dark .text-purple-200 {
  color: rgba(126, 34, 206, var(--tw-text-opacity));
}

.dark .text-purple-200.nightwind-prevent {
  color: rgba(233, 213, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-200 {
  color: rgba(233, 213, 255, var(--tw-text-opacity));
}

.dark .hover\:text-purple-200:hover {
  color: rgba(126, 34, 206, var(--tw-text-opacity));
}

.dark .hover\:text-purple-200:hover.nightwind-prevent {
  color: rgba(233, 213, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-200:hover {
  color: rgba(233, 213, 255, var(--tw-text-opacity));
}

.dark .text-purple-300 {
  color: rgba(147, 51, 234, var(--tw-text-opacity));
}

.dark .text-purple-300.nightwind-prevent {
  color: rgba(216, 180, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-300 {
  color: rgba(216, 180, 254, var(--tw-text-opacity));
}

.dark .hover\:text-purple-300:hover {
  color: rgba(147, 51, 234, var(--tw-text-opacity));
}

.dark .hover\:text-purple-300:hover.nightwind-prevent {
  color: rgba(216, 180, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-300:hover {
  color: rgba(216, 180, 254, var(--tw-text-opacity));
}

.dark .text-purple-400 {
  color: rgba(168, 85, 247, var(--tw-text-opacity));
}

.dark .text-purple-400.nightwind-prevent {
  color: rgba(192, 132, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-400 {
  color: rgba(192, 132, 252, var(--tw-text-opacity));
}

.dark .hover\:text-purple-400:hover {
  color: rgba(168, 85, 247, var(--tw-text-opacity));
}

.dark .hover\:text-purple-400:hover.nightwind-prevent {
  color: rgba(192, 132, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-400:hover {
  color: rgba(192, 132, 252, var(--tw-text-opacity));
}

.dark .text-purple-500 {
  color: rgba(192, 132, 252, var(--tw-text-opacity));
}

.dark .text-purple-500.nightwind-prevent {
  color: rgba(168, 85, 247, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-500 {
  color: rgba(168, 85, 247, var(--tw-text-opacity));
}

.dark .hover\:text-purple-500:hover {
  color: rgba(192, 132, 252, var(--tw-text-opacity));
}

.dark .hover\:text-purple-500:hover.nightwind-prevent {
  color: rgba(168, 85, 247, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-500:hover {
  color: rgba(168, 85, 247, var(--tw-text-opacity));
}

.dark .text-purple-600 {
  color: rgba(216, 180, 254, var(--tw-text-opacity));
}

.dark .text-purple-600.nightwind-prevent {
  color: rgba(147, 51, 234, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-600 {
  color: rgba(147, 51, 234, var(--tw-text-opacity));
}

.dark .hover\:text-purple-600:hover {
  color: rgba(216, 180, 254, var(--tw-text-opacity));
}

.dark .hover\:text-purple-600:hover.nightwind-prevent {
  color: rgba(147, 51, 234, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-600:hover {
  color: rgba(147, 51, 234, var(--tw-text-opacity));
}

.dark .text-purple-700 {
  color: rgba(233, 213, 255, var(--tw-text-opacity));
}

.dark .text-purple-700.nightwind-prevent {
  color: rgba(126, 34, 206, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-700 {
  color: rgba(126, 34, 206, var(--tw-text-opacity));
}

.dark .hover\:text-purple-700:hover {
  color: rgba(233, 213, 255, var(--tw-text-opacity));
}

.dark .hover\:text-purple-700:hover.nightwind-prevent {
  color: rgba(126, 34, 206, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-700:hover {
  color: rgba(126, 34, 206, var(--tw-text-opacity));
}

.dark .text-purple-800 {
  color: rgba(243, 232, 255, var(--tw-text-opacity));
}

.dark .text-purple-800.nightwind-prevent {
  color: rgba(107, 33, 168, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-800 {
  color: rgba(107, 33, 168, var(--tw-text-opacity));
}

.dark .hover\:text-purple-800:hover {
  color: rgba(243, 232, 255, var(--tw-text-opacity));
}

.dark .hover\:text-purple-800:hover.nightwind-prevent {
  color: rgba(107, 33, 168, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-800:hover {
  color: rgba(107, 33, 168, var(--tw-text-opacity));
}

.dark .text-purple-900 {
  color: rgba(250, 245, 255, var(--tw-text-opacity));
}

.dark .text-purple-900.nightwind-prevent {
  color: rgba(88, 28, 135, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-purple-900 {
  color: rgba(88, 28, 135, var(--tw-text-opacity));
}

.dark .hover\:text-purple-900:hover {
  color: rgba(250, 245, 255, var(--tw-text-opacity));
}

.dark .hover\:text-purple-900:hover.nightwind-prevent {
  color: rgba(88, 28, 135, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-purple-900:hover {
  color: rgba(88, 28, 135, var(--tw-text-opacity));
}

.dark .text-fuchsia-50 {
  color: rgba(112, 26, 117, var(--tw-text-opacity));
}

.dark .text-fuchsia-50.nightwind-prevent {
  color: rgba(253, 244, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-50 {
  color: rgba(253, 244, 255, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-50:hover {
  color: rgba(112, 26, 117, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-50:hover.nightwind-prevent {
  color: rgba(253, 244, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-50:hover {
  color: rgba(253, 244, 255, var(--tw-text-opacity));
}

.dark .text-fuchsia-100 {
  color: rgba(134, 25, 143, var(--tw-text-opacity));
}

.dark .text-fuchsia-100.nightwind-prevent {
  color: rgba(250, 232, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-100 {
  color: rgba(250, 232, 255, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-100:hover {
  color: rgba(134, 25, 143, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-100:hover.nightwind-prevent {
  color: rgba(250, 232, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-100:hover {
  color: rgba(250, 232, 255, var(--tw-text-opacity));
}

.dark .text-fuchsia-200 {
  color: rgba(162, 28, 175, var(--tw-text-opacity));
}

.dark .text-fuchsia-200.nightwind-prevent {
  color: rgba(245, 208, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-200 {
  color: rgba(245, 208, 254, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-200:hover {
  color: rgba(162, 28, 175, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-200:hover.nightwind-prevent {
  color: rgba(245, 208, 254, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-200:hover {
  color: rgba(245, 208, 254, var(--tw-text-opacity));
}

.dark .text-fuchsia-300 {
  color: rgba(192, 38, 211, var(--tw-text-opacity));
}

.dark .text-fuchsia-300.nightwind-prevent {
  color: rgba(240, 171, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-300 {
  color: rgba(240, 171, 252, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-300:hover {
  color: rgba(192, 38, 211, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-300:hover.nightwind-prevent {
  color: rgba(240, 171, 252, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-300:hover {
  color: rgba(240, 171, 252, var(--tw-text-opacity));
}

.dark .text-fuchsia-400 {
  color: rgba(217, 70, 239, var(--tw-text-opacity));
}

.dark .text-fuchsia-400.nightwind-prevent {
  color: rgba(232, 121, 249, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-400 {
  color: rgba(232, 121, 249, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-400:hover {
  color: rgba(217, 70, 239, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-400:hover.nightwind-prevent {
  color: rgba(232, 121, 249, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-400:hover {
  color: rgba(232, 121, 249, var(--tw-text-opacity));
}

.dark .text-fuchsia-500 {
  color: rgba(232, 121, 249, var(--tw-text-opacity));
}

.dark .text-fuchsia-500.nightwind-prevent {
  color: rgba(217, 70, 239, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-500 {
  color: rgba(217, 70, 239, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-500:hover {
  color: rgba(232, 121, 249, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-500:hover.nightwind-prevent {
  color: rgba(217, 70, 239, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-500:hover {
  color: rgba(217, 70, 239, var(--tw-text-opacity));
}

.dark .text-fuchsia-600 {
  color: rgba(240, 171, 252, var(--tw-text-opacity));
}

.dark .text-fuchsia-600.nightwind-prevent {
  color: rgba(192, 38, 211, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-600 {
  color: rgba(192, 38, 211, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-600:hover {
  color: rgba(240, 171, 252, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-600:hover.nightwind-prevent {
  color: rgba(192, 38, 211, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-600:hover {
  color: rgba(192, 38, 211, var(--tw-text-opacity));
}

.dark .text-fuchsia-700 {
  color: rgba(245, 208, 254, var(--tw-text-opacity));
}

.dark .text-fuchsia-700.nightwind-prevent {
  color: rgba(162, 28, 175, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-700 {
  color: rgba(162, 28, 175, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-700:hover {
  color: rgba(245, 208, 254, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-700:hover.nightwind-prevent {
  color: rgba(162, 28, 175, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-700:hover {
  color: rgba(162, 28, 175, var(--tw-text-opacity));
}

.dark .text-fuchsia-800 {
  color: rgba(250, 232, 255, var(--tw-text-opacity));
}

.dark .text-fuchsia-800.nightwind-prevent {
  color: rgba(134, 25, 143, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-800 {
  color: rgba(134, 25, 143, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-800:hover {
  color: rgba(250, 232, 255, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-800:hover.nightwind-prevent {
  color: rgba(134, 25, 143, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-800:hover {
  color: rgba(134, 25, 143, var(--tw-text-opacity));
}

.dark .text-fuchsia-900 {
  color: rgba(253, 244, 255, var(--tw-text-opacity));
}

.dark .text-fuchsia-900.nightwind-prevent {
  color: rgba(112, 26, 117, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-fuchsia-900 {
  color: rgba(112, 26, 117, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-900:hover {
  color: rgba(253, 244, 255, var(--tw-text-opacity));
}

.dark .hover\:text-fuchsia-900:hover.nightwind-prevent {
  color: rgba(112, 26, 117, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-fuchsia-900:hover {
  color: rgba(112, 26, 117, var(--tw-text-opacity));
}

.dark .text-pink-50 {
  color: rgba(131, 24, 67, var(--tw-text-opacity));
}

.dark .text-pink-50.nightwind-prevent {
  color: rgba(253, 242, 248, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-50 {
  color: rgba(253, 242, 248, var(--tw-text-opacity));
}

.dark .hover\:text-pink-50:hover {
  color: rgba(131, 24, 67, var(--tw-text-opacity));
}

.dark .hover\:text-pink-50:hover.nightwind-prevent {
  color: rgba(253, 242, 248, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-50:hover {
  color: rgba(253, 242, 248, var(--tw-text-opacity));
}

.dark .text-pink-100 {
  color: rgba(157, 23, 77, var(--tw-text-opacity));
}

.dark .text-pink-100.nightwind-prevent {
  color: rgba(252, 231, 243, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-100 {
  color: rgba(252, 231, 243, var(--tw-text-opacity));
}

.dark .hover\:text-pink-100:hover {
  color: rgba(157, 23, 77, var(--tw-text-opacity));
}

.dark .hover\:text-pink-100:hover.nightwind-prevent {
  color: rgba(252, 231, 243, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-100:hover {
  color: rgba(252, 231, 243, var(--tw-text-opacity));
}

.dark .text-pink-200 {
  color: rgba(190, 24, 93, var(--tw-text-opacity));
}

.dark .text-pink-200.nightwind-prevent {
  color: rgba(251, 207, 232, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-200 {
  color: rgba(251, 207, 232, var(--tw-text-opacity));
}

.dark .hover\:text-pink-200:hover {
  color: rgba(190, 24, 93, var(--tw-text-opacity));
}

.dark .hover\:text-pink-200:hover.nightwind-prevent {
  color: rgba(251, 207, 232, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-200:hover {
  color: rgba(251, 207, 232, var(--tw-text-opacity));
}

.dark .text-pink-300 {
  color: rgba(219, 39, 119, var(--tw-text-opacity));
}

.dark .text-pink-300.nightwind-prevent {
  color: rgba(249, 168, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-300 {
  color: rgba(249, 168, 212, var(--tw-text-opacity));
}

.dark .hover\:text-pink-300:hover {
  color: rgba(219, 39, 119, var(--tw-text-opacity));
}

.dark .hover\:text-pink-300:hover.nightwind-prevent {
  color: rgba(249, 168, 212, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-300:hover {
  color: rgba(249, 168, 212, var(--tw-text-opacity));
}

.dark .text-pink-400 {
  color: rgba(236, 72, 153, var(--tw-text-opacity));
}

.dark .text-pink-400.nightwind-prevent {
  color: rgba(244, 114, 182, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-400 {
  color: rgba(244, 114, 182, var(--tw-text-opacity));
}

.dark .hover\:text-pink-400:hover {
  color: rgba(236, 72, 153, var(--tw-text-opacity));
}

.dark .hover\:text-pink-400:hover.nightwind-prevent {
  color: rgba(244, 114, 182, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-400:hover {
  color: rgba(244, 114, 182, var(--tw-text-opacity));
}

.dark .text-pink-500 {
  color: rgba(244, 114, 182, var(--tw-text-opacity));
}

.dark .text-pink-500.nightwind-prevent {
  color: rgba(236, 72, 153, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-500 {
  color: rgba(236, 72, 153, var(--tw-text-opacity));
}

.dark .hover\:text-pink-500:hover {
  color: rgba(244, 114, 182, var(--tw-text-opacity));
}

.dark .hover\:text-pink-500:hover.nightwind-prevent {
  color: rgba(236, 72, 153, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-500:hover {
  color: rgba(236, 72, 153, var(--tw-text-opacity));
}

.dark .text-pink-600 {
  color: rgba(249, 168, 212, var(--tw-text-opacity));
}

.dark .text-pink-600.nightwind-prevent {
  color: rgba(219, 39, 119, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-600 {
  color: rgba(219, 39, 119, var(--tw-text-opacity));
}

.dark .hover\:text-pink-600:hover {
  color: rgba(249, 168, 212, var(--tw-text-opacity));
}

.dark .hover\:text-pink-600:hover.nightwind-prevent {
  color: rgba(219, 39, 119, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-600:hover {
  color: rgba(219, 39, 119, var(--tw-text-opacity));
}

.dark .text-pink-700 {
  color: rgba(251, 207, 232, var(--tw-text-opacity));
}

.dark .text-pink-700.nightwind-prevent {
  color: rgba(190, 24, 93, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-700 {
  color: rgba(190, 24, 93, var(--tw-text-opacity));
}

.dark .hover\:text-pink-700:hover {
  color: rgba(251, 207, 232, var(--tw-text-opacity));
}

.dark .hover\:text-pink-700:hover.nightwind-prevent {
  color: rgba(190, 24, 93, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-700:hover {
  color: rgba(190, 24, 93, var(--tw-text-opacity));
}

.dark .text-pink-800 {
  color: rgba(252, 231, 243, var(--tw-text-opacity));
}

.dark .text-pink-800.nightwind-prevent {
  color: rgba(157, 23, 77, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-800 {
  color: rgba(157, 23, 77, var(--tw-text-opacity));
}

.dark .hover\:text-pink-800:hover {
  color: rgba(252, 231, 243, var(--tw-text-opacity));
}

.dark .hover\:text-pink-800:hover.nightwind-prevent {
  color: rgba(157, 23, 77, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-800:hover {
  color: rgba(157, 23, 77, var(--tw-text-opacity));
}

.dark .text-pink-900 {
  color: rgba(253, 242, 248, var(--tw-text-opacity));
}

.dark .text-pink-900.nightwind-prevent {
  color: rgba(131, 24, 67, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-pink-900 {
  color: rgba(131, 24, 67, var(--tw-text-opacity));
}

.dark .hover\:text-pink-900:hover {
  color: rgba(253, 242, 248, var(--tw-text-opacity));
}

.dark .hover\:text-pink-900:hover.nightwind-prevent {
  color: rgba(131, 24, 67, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-pink-900:hover {
  color: rgba(131, 24, 67, var(--tw-text-opacity));
}

.dark .text-rose-50 {
  color: rgba(136, 19, 55, var(--tw-text-opacity));
}

.dark .text-rose-50.nightwind-prevent {
  color: rgba(255, 241, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-50 {
  color: rgba(255, 241, 242, var(--tw-text-opacity));
}

.dark .hover\:text-rose-50:hover {
  color: rgba(136, 19, 55, var(--tw-text-opacity));
}

.dark .hover\:text-rose-50:hover.nightwind-prevent {
  color: rgba(255, 241, 242, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-50:hover {
  color: rgba(255, 241, 242, var(--tw-text-opacity));
}

.dark .text-rose-100 {
  color: rgba(159, 18, 57, var(--tw-text-opacity));
}

.dark .text-rose-100.nightwind-prevent {
  color: rgba(255, 228, 230, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-100 {
  color: rgba(255, 228, 230, var(--tw-text-opacity));
}

.dark .hover\:text-rose-100:hover {
  color: rgba(159, 18, 57, var(--tw-text-opacity));
}

.dark .hover\:text-rose-100:hover.nightwind-prevent {
  color: rgba(255, 228, 230, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-100:hover {
  color: rgba(255, 228, 230, var(--tw-text-opacity));
}

.dark .text-rose-200 {
  color: rgba(190, 18, 60, var(--tw-text-opacity));
}

.dark .text-rose-200.nightwind-prevent {
  color: rgba(254, 205, 211, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-200 {
  color: rgba(254, 205, 211, var(--tw-text-opacity));
}

.dark .hover\:text-rose-200:hover {
  color: rgba(190, 18, 60, var(--tw-text-opacity));
}

.dark .hover\:text-rose-200:hover.nightwind-prevent {
  color: rgba(254, 205, 211, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-200:hover {
  color: rgba(254, 205, 211, var(--tw-text-opacity));
}

.dark .text-rose-300 {
  color: rgba(225, 29, 72, var(--tw-text-opacity));
}

.dark .text-rose-300.nightwind-prevent {
  color: rgba(253, 164, 175, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-300 {
  color: rgba(253, 164, 175, var(--tw-text-opacity));
}

.dark .hover\:text-rose-300:hover {
  color: rgba(225, 29, 72, var(--tw-text-opacity));
}

.dark .hover\:text-rose-300:hover.nightwind-prevent {
  color: rgba(253, 164, 175, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-300:hover {
  color: rgba(253, 164, 175, var(--tw-text-opacity));
}

.dark .text-rose-400 {
  color: rgba(244, 63, 94, var(--tw-text-opacity));
}

.dark .text-rose-400.nightwind-prevent {
  color: rgba(251, 113, 133, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-400 {
  color: rgba(251, 113, 133, var(--tw-text-opacity));
}

.dark .hover\:text-rose-400:hover {
  color: rgba(244, 63, 94, var(--tw-text-opacity));
}

.dark .hover\:text-rose-400:hover.nightwind-prevent {
  color: rgba(251, 113, 133, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-400:hover {
  color: rgba(251, 113, 133, var(--tw-text-opacity));
}

.dark .text-rose-500 {
  color: rgba(251, 113, 133, var(--tw-text-opacity));
}

.dark .text-rose-500.nightwind-prevent {
  color: rgba(244, 63, 94, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-500 {
  color: rgba(244, 63, 94, var(--tw-text-opacity));
}

.dark .hover\:text-rose-500:hover {
  color: rgba(251, 113, 133, var(--tw-text-opacity));
}

.dark .hover\:text-rose-500:hover.nightwind-prevent {
  color: rgba(244, 63, 94, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-500:hover {
  color: rgba(244, 63, 94, var(--tw-text-opacity));
}

.dark .text-rose-600 {
  color: rgba(253, 164, 175, var(--tw-text-opacity));
}

.dark .text-rose-600.nightwind-prevent {
  color: rgba(225, 29, 72, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-600 {
  color: rgba(225, 29, 72, var(--tw-text-opacity));
}

.dark .hover\:text-rose-600:hover {
  color: rgba(253, 164, 175, var(--tw-text-opacity));
}

.dark .hover\:text-rose-600:hover.nightwind-prevent {
  color: rgba(225, 29, 72, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-600:hover {
  color: rgba(225, 29, 72, var(--tw-text-opacity));
}

.dark .text-rose-700 {
  color: rgba(254, 205, 211, var(--tw-text-opacity));
}

.dark .text-rose-700.nightwind-prevent {
  color: rgba(190, 18, 60, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-700 {
  color: rgba(190, 18, 60, var(--tw-text-opacity));
}

.dark .hover\:text-rose-700:hover {
  color: rgba(254, 205, 211, var(--tw-text-opacity));
}

.dark .hover\:text-rose-700:hover.nightwind-prevent {
  color: rgba(190, 18, 60, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-700:hover {
  color: rgba(190, 18, 60, var(--tw-text-opacity));
}

.dark .text-rose-800 {
  color: rgba(255, 228, 230, var(--tw-text-opacity));
}

.dark .text-rose-800.nightwind-prevent {
  color: rgba(159, 18, 57, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-800 {
  color: rgba(159, 18, 57, var(--tw-text-opacity));
}

.dark .hover\:text-rose-800:hover {
  color: rgba(255, 228, 230, var(--tw-text-opacity));
}

.dark .hover\:text-rose-800:hover.nightwind-prevent {
  color: rgba(159, 18, 57, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-800:hover {
  color: rgba(159, 18, 57, var(--tw-text-opacity));
}

.dark .text-rose-900 {
  color: rgba(255, 241, 242, var(--tw-text-opacity));
}

.dark .text-rose-900.nightwind-prevent {
  color: rgba(136, 19, 55, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-rose-900 {
  color: rgba(136, 19, 55, var(--tw-text-opacity));
}

.dark .hover\:text-rose-900:hover {
  color: rgba(255, 241, 242, var(--tw-text-opacity));
}

.dark .hover\:text-rose-900:hover.nightwind-prevent {
  color: rgba(136, 19, 55, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-rose-900:hover {
  color: rgba(136, 19, 55, var(--tw-text-opacity));
}

.dark .text-background-50 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-50.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-50 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-50:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-50:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-50:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-100 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-100.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-100 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-100:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-100:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-100:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-200 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-200.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-200 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-200:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-200:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-200:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-300 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-300.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-300 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-300:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-300:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-300:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-400 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-400.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-400 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-400:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-400:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-400:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-500 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-500.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-500 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-500:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-500:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-500:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-600 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-600.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-600 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-600:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-600:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-600:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-700 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-700.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-700 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-700:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-700:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-700:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-800 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-800.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-800 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-800:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-800:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-800:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-900 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-background-900.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-background-900 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-900:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-background-900:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-background-900:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-50 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-50.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-50 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-50:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-50:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-50:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-100 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-100.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-100 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-100:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-100:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-100:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-200 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-200.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-200 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-200:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-200:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-200:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-300 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-300.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-300 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-300:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-300:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-300:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-400 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-400.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-400 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-400:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-400:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-400:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-500 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-500.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-500 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-500:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-500:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-500:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-600 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-600.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-600 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-600:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-600:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-600:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-700 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-700.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-700 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-700:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-700:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-700:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-800 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-800.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-800 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-800:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-800:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-800:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-900 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .text-foreground-900.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .text-foreground-900 {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-900:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .hover\:text-foreground-900:hover.nightwind-prevent {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-foreground-900:hover {
  color: rgba(undefined, undefined, undefined, var(--tw-text-opacity));
}

.dark .bg-inherit-50 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-50.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-50 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-50:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-50:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-50:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-100 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-100.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-100 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-100:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-100:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-100:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-200 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-200.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-200 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-200:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-200:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-200:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-300 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-300.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-300 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-300:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-300:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-300:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-400 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-400.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-400 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-400:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-400:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-400:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-500 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-500.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-500 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-500:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-500:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-500:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-600 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-600.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-600 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-600:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-600:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-600:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-700 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-700.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-700 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-700:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-700:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-700:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-800 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-800.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-800 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-800:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-800:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-800:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-900 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-inherit-900.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-inherit-900 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-900:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-inherit-900:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-inherit-900:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-slate-50 {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .bg-slate-50.nightwind-prevent {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-50 {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-50:hover {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-50:hover.nightwind-prevent {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-50:hover {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .bg-slate-100 {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .bg-slate-100.nightwind-prevent {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-100 {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-100:hover {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-100:hover.nightwind-prevent {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-100:hover {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .bg-slate-200 {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .bg-slate-200.nightwind-prevent {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-200 {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-200:hover {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-200:hover.nightwind-prevent {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-200:hover {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .bg-slate-300 {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .bg-slate-300.nightwind-prevent {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-300 {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-300:hover {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-300:hover.nightwind-prevent {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-300:hover {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .bg-slate-400 {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .bg-slate-400.nightwind-prevent {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-400 {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-400:hover {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-400:hover.nightwind-prevent {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-400:hover {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .bg-slate-500 {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .bg-slate-500.nightwind-prevent {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-500 {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-500:hover {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-500:hover.nightwind-prevent {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-500:hover {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .bg-slate-600 {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .bg-slate-600.nightwind-prevent {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-600 {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-600:hover {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-600:hover.nightwind-prevent {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-600:hover {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .bg-slate-700 {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .bg-slate-700.nightwind-prevent {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-700 {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-700:hover {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-700:hover.nightwind-prevent {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-700:hover {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .bg-slate-800 {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .bg-slate-800.nightwind-prevent {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-800 {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-800:hover {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-800:hover.nightwind-prevent {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-800:hover {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .bg-slate-900 {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .bg-slate-900.nightwind-prevent {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-slate-900 {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-900:hover {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-slate-900:hover.nightwind-prevent {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-slate-900:hover {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .bg-gray-50 {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .bg-gray-50.nightwind-prevent {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-50 {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-50:hover {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-50:hover.nightwind-prevent {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-50:hover {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .bg-gray-100 {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .bg-gray-100.nightwind-prevent {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-100 {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-100:hover {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-100:hover.nightwind-prevent {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-100:hover {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .bg-gray-200 {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .bg-gray-200.nightwind-prevent {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-200 {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-200:hover {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-200:hover.nightwind-prevent {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-200:hover {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .bg-gray-300 {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .bg-gray-300.nightwind-prevent {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-300 {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-300:hover {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-300:hover.nightwind-prevent {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-300:hover {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .bg-gray-400 {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .bg-gray-400.nightwind-prevent {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-400 {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-400:hover {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-400:hover.nightwind-prevent {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-400:hover {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .bg-gray-500 {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .bg-gray-500.nightwind-prevent {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-500 {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-500:hover {
  background-color: rgba(140, 149, 159, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-500:hover.nightwind-prevent {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-500:hover {
  background-color: rgba(110, 119, 129, var(--tw-bg-opacity));
}

.dark .bg-gray-600 {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .bg-gray-600.nightwind-prevent {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-600 {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-600:hover {
  background-color: rgba(175, 184, 193, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-600:hover.nightwind-prevent {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-600:hover {
  background-color: rgba(87, 96, 106, var(--tw-bg-opacity));
}

.dark .bg-gray-700 {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .bg-gray-700.nightwind-prevent {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-700 {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-700:hover {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-700:hover.nightwind-prevent {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-700:hover {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .bg-gray-800 {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .bg-gray-800.nightwind-prevent {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-800 {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-800:hover {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-800:hover.nightwind-prevent {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-800:hover {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .bg-gray-900 {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .bg-gray-900.nightwind-prevent {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-gray-900 {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-900:hover {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-900:hover.nightwind-prevent {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-900:hover {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .bg-zinc-50 {
  background-color: rgba(24, 24, 27, var(--tw-bg-opacity));
}

.dark .bg-zinc-50.nightwind-prevent {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-50 {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-50:hover {
  background-color: rgba(24, 24, 27, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-50:hover.nightwind-prevent {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-50:hover {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .bg-zinc-100 {
  background-color: rgba(39, 39, 42, var(--tw-bg-opacity));
}

.dark .bg-zinc-100.nightwind-prevent {
  background-color: rgba(244, 244, 245, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-100 {
  background-color: rgba(244, 244, 245, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-100:hover {
  background-color: rgba(39, 39, 42, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-100:hover.nightwind-prevent {
  background-color: rgba(244, 244, 245, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-100:hover {
  background-color: rgba(244, 244, 245, var(--tw-bg-opacity));
}

.dark .bg-zinc-200 {
  background-color: rgba(63, 63, 70, var(--tw-bg-opacity));
}

.dark .bg-zinc-200.nightwind-prevent {
  background-color: rgba(228, 228, 231, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-200 {
  background-color: rgba(228, 228, 231, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-200:hover {
  background-color: rgba(63, 63, 70, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-200:hover.nightwind-prevent {
  background-color: rgba(228, 228, 231, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-200:hover {
  background-color: rgba(228, 228, 231, var(--tw-bg-opacity));
}

.dark .bg-zinc-300 {
  background-color: rgba(82, 82, 91, var(--tw-bg-opacity));
}

.dark .bg-zinc-300.nightwind-prevent {
  background-color: rgba(212, 212, 216, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-300 {
  background-color: rgba(212, 212, 216, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-300:hover {
  background-color: rgba(82, 82, 91, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-300:hover.nightwind-prevent {
  background-color: rgba(212, 212, 216, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-300:hover {
  background-color: rgba(212, 212, 216, var(--tw-bg-opacity));
}

.dark .bg-zinc-400 {
  background-color: rgba(113, 113, 122, var(--tw-bg-opacity));
}

.dark .bg-zinc-400.nightwind-prevent {
  background-color: rgba(161, 161, 170, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-400 {
  background-color: rgba(161, 161, 170, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-400:hover {
  background-color: rgba(113, 113, 122, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-400:hover.nightwind-prevent {
  background-color: rgba(161, 161, 170, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-400:hover {
  background-color: rgba(161, 161, 170, var(--tw-bg-opacity));
}

.dark .bg-zinc-500 {
  background-color: rgba(161, 161, 170, var(--tw-bg-opacity));
}

.dark .bg-zinc-500.nightwind-prevent {
  background-color: rgba(113, 113, 122, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-500 {
  background-color: rgba(113, 113, 122, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-500:hover {
  background-color: rgba(161, 161, 170, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-500:hover.nightwind-prevent {
  background-color: rgba(113, 113, 122, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-500:hover {
  background-color: rgba(113, 113, 122, var(--tw-bg-opacity));
}

.dark .bg-zinc-600 {
  background-color: rgba(212, 212, 216, var(--tw-bg-opacity));
}

.dark .bg-zinc-600.nightwind-prevent {
  background-color: rgba(82, 82, 91, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-600 {
  background-color: rgba(82, 82, 91, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-600:hover {
  background-color: rgba(212, 212, 216, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-600:hover.nightwind-prevent {
  background-color: rgba(82, 82, 91, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-600:hover {
  background-color: rgba(82, 82, 91, var(--tw-bg-opacity));
}

.dark .bg-zinc-700 {
  background-color: rgba(228, 228, 231, var(--tw-bg-opacity));
}

.dark .bg-zinc-700.nightwind-prevent {
  background-color: rgba(63, 63, 70, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-700 {
  background-color: rgba(63, 63, 70, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-700:hover {
  background-color: rgba(228, 228, 231, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-700:hover.nightwind-prevent {
  background-color: rgba(63, 63, 70, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-700:hover {
  background-color: rgba(63, 63, 70, var(--tw-bg-opacity));
}

.dark .bg-zinc-800 {
  background-color: rgba(244, 244, 245, var(--tw-bg-opacity));
}

.dark .bg-zinc-800.nightwind-prevent {
  background-color: rgba(39, 39, 42, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-800 {
  background-color: rgba(39, 39, 42, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-800:hover {
  background-color: rgba(244, 244, 245, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-800:hover.nightwind-prevent {
  background-color: rgba(39, 39, 42, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-800:hover {
  background-color: rgba(39, 39, 42, var(--tw-bg-opacity));
}

.dark .bg-zinc-900 {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .bg-zinc-900.nightwind-prevent {
  background-color: rgba(24, 24, 27, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-zinc-900 {
  background-color: rgba(24, 24, 27, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-900:hover {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-zinc-900:hover.nightwind-prevent {
  background-color: rgba(24, 24, 27, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-zinc-900:hover {
  background-color: rgba(24, 24, 27, var(--tw-bg-opacity));
}

.dark .bg-neutral-50 {
  background-color: rgba(23, 23, 23, var(--tw-bg-opacity));
}

.dark .bg-neutral-50.nightwind-prevent {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-50 {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-50:hover {
  background-color: rgba(23, 23, 23, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-50:hover.nightwind-prevent {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-50:hover {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .bg-neutral-100 {
  background-color: rgba(38, 38, 38, var(--tw-bg-opacity));
}

.dark .bg-neutral-100.nightwind-prevent {
  background-color: rgba(245, 245, 245, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-100 {
  background-color: rgba(245, 245, 245, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-100:hover {
  background-color: rgba(38, 38, 38, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-100:hover.nightwind-prevent {
  background-color: rgba(245, 245, 245, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-100:hover {
  background-color: rgba(245, 245, 245, var(--tw-bg-opacity));
}

.dark .bg-neutral-200 {
  background-color: rgba(64, 64, 64, var(--tw-bg-opacity));
}

.dark .bg-neutral-200.nightwind-prevent {
  background-color: rgba(229, 229, 229, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-200 {
  background-color: rgba(229, 229, 229, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-200:hover {
  background-color: rgba(64, 64, 64, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-200:hover.nightwind-prevent {
  background-color: rgba(229, 229, 229, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-200:hover {
  background-color: rgba(229, 229, 229, var(--tw-bg-opacity));
}

.dark .bg-neutral-300 {
  background-color: rgba(82, 82, 82, var(--tw-bg-opacity));
}

.dark .bg-neutral-300.nightwind-prevent {
  background-color: rgba(212, 212, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-300 {
  background-color: rgba(212, 212, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-300:hover {
  background-color: rgba(82, 82, 82, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-300:hover.nightwind-prevent {
  background-color: rgba(212, 212, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-300:hover {
  background-color: rgba(212, 212, 212, var(--tw-bg-opacity));
}

.dark .bg-neutral-400 {
  background-color: rgba(115, 115, 115, var(--tw-bg-opacity));
}

.dark .bg-neutral-400.nightwind-prevent {
  background-color: rgba(163, 163, 163, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-400 {
  background-color: rgba(163, 163, 163, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-400:hover {
  background-color: rgba(115, 115, 115, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-400:hover.nightwind-prevent {
  background-color: rgba(163, 163, 163, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-400:hover {
  background-color: rgba(163, 163, 163, var(--tw-bg-opacity));
}

.dark .bg-neutral-500 {
  background-color: rgba(163, 163, 163, var(--tw-bg-opacity));
}

.dark .bg-neutral-500.nightwind-prevent {
  background-color: rgba(115, 115, 115, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-500 {
  background-color: rgba(115, 115, 115, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-500:hover {
  background-color: rgba(163, 163, 163, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-500:hover.nightwind-prevent {
  background-color: rgba(115, 115, 115, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-500:hover {
  background-color: rgba(115, 115, 115, var(--tw-bg-opacity));
}

.dark .bg-neutral-600 {
  background-color: rgba(212, 212, 212, var(--tw-bg-opacity));
}

.dark .bg-neutral-600.nightwind-prevent {
  background-color: rgba(82, 82, 82, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-600 {
  background-color: rgba(82, 82, 82, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-600:hover {
  background-color: rgba(212, 212, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-600:hover.nightwind-prevent {
  background-color: rgba(82, 82, 82, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-600:hover {
  background-color: rgba(82, 82, 82, var(--tw-bg-opacity));
}

.dark .bg-neutral-700 {
  background-color: rgba(229, 229, 229, var(--tw-bg-opacity));
}

.dark .bg-neutral-700.nightwind-prevent {
  background-color: rgba(64, 64, 64, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-700 {
  background-color: rgba(64, 64, 64, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-700:hover {
  background-color: rgba(229, 229, 229, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-700:hover.nightwind-prevent {
  background-color: rgba(64, 64, 64, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-700:hover {
  background-color: rgba(64, 64, 64, var(--tw-bg-opacity));
}

.dark .bg-neutral-800 {
  background-color: rgba(245, 245, 245, var(--tw-bg-opacity));
}

.dark .bg-neutral-800.nightwind-prevent {
  background-color: rgba(38, 38, 38, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-800 {
  background-color: rgba(38, 38, 38, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-800:hover {
  background-color: rgba(245, 245, 245, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-800:hover.nightwind-prevent {
  background-color: rgba(38, 38, 38, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-800:hover {
  background-color: rgba(38, 38, 38, var(--tw-bg-opacity));
}

.dark .bg-neutral-900 {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .bg-neutral-900.nightwind-prevent {
  background-color: rgba(23, 23, 23, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-neutral-900 {
  background-color: rgba(23, 23, 23, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-900:hover {
  background-color: rgba(250, 250, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-neutral-900:hover.nightwind-prevent {
  background-color: rgba(23, 23, 23, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-neutral-900:hover {
  background-color: rgba(23, 23, 23, var(--tw-bg-opacity));
}

.dark .bg-stone-50 {
  background-color: rgba(28, 25, 23, var(--tw-bg-opacity));
}

.dark .bg-stone-50.nightwind-prevent {
  background-color: rgba(250, 250, 249, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-50 {
  background-color: rgba(250, 250, 249, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-50:hover {
  background-color: rgba(28, 25, 23, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-50:hover.nightwind-prevent {
  background-color: rgba(250, 250, 249, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-50:hover {
  background-color: rgba(250, 250, 249, var(--tw-bg-opacity));
}

.dark .bg-stone-100 {
  background-color: rgba(41, 37, 36, var(--tw-bg-opacity));
}

.dark .bg-stone-100.nightwind-prevent {
  background-color: rgba(245, 245, 244, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-100 {
  background-color: rgba(245, 245, 244, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-100:hover {
  background-color: rgba(41, 37, 36, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-100:hover.nightwind-prevent {
  background-color: rgba(245, 245, 244, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-100:hover {
  background-color: rgba(245, 245, 244, var(--tw-bg-opacity));
}

.dark .bg-stone-200 {
  background-color: rgba(68, 64, 60, var(--tw-bg-opacity));
}

.dark .bg-stone-200.nightwind-prevent {
  background-color: rgba(231, 229, 228, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-200 {
  background-color: rgba(231, 229, 228, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-200:hover {
  background-color: rgba(68, 64, 60, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-200:hover.nightwind-prevent {
  background-color: rgba(231, 229, 228, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-200:hover {
  background-color: rgba(231, 229, 228, var(--tw-bg-opacity));
}

.dark .bg-stone-300 {
  background-color: rgba(87, 83, 78, var(--tw-bg-opacity));
}

.dark .bg-stone-300.nightwind-prevent {
  background-color: rgba(214, 211, 209, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-300 {
  background-color: rgba(214, 211, 209, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-300:hover {
  background-color: rgba(87, 83, 78, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-300:hover.nightwind-prevent {
  background-color: rgba(214, 211, 209, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-300:hover {
  background-color: rgba(214, 211, 209, var(--tw-bg-opacity));
}

.dark .bg-stone-400 {
  background-color: rgba(120, 113, 108, var(--tw-bg-opacity));
}

.dark .bg-stone-400.nightwind-prevent {
  background-color: rgba(168, 162, 158, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-400 {
  background-color: rgba(168, 162, 158, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-400:hover {
  background-color: rgba(120, 113, 108, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-400:hover.nightwind-prevent {
  background-color: rgba(168, 162, 158, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-400:hover {
  background-color: rgba(168, 162, 158, var(--tw-bg-opacity));
}

.dark .bg-stone-500 {
  background-color: rgba(168, 162, 158, var(--tw-bg-opacity));
}

.dark .bg-stone-500.nightwind-prevent {
  background-color: rgba(120, 113, 108, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-500 {
  background-color: rgba(120, 113, 108, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-500:hover {
  background-color: rgba(168, 162, 158, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-500:hover.nightwind-prevent {
  background-color: rgba(120, 113, 108, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-500:hover {
  background-color: rgba(120, 113, 108, var(--tw-bg-opacity));
}

.dark .bg-stone-600 {
  background-color: rgba(214, 211, 209, var(--tw-bg-opacity));
}

.dark .bg-stone-600.nightwind-prevent {
  background-color: rgba(87, 83, 78, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-600 {
  background-color: rgba(87, 83, 78, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-600:hover {
  background-color: rgba(214, 211, 209, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-600:hover.nightwind-prevent {
  background-color: rgba(87, 83, 78, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-600:hover {
  background-color: rgba(87, 83, 78, var(--tw-bg-opacity));
}

.dark .bg-stone-700 {
  background-color: rgba(231, 229, 228, var(--tw-bg-opacity));
}

.dark .bg-stone-700.nightwind-prevent {
  background-color: rgba(68, 64, 60, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-700 {
  background-color: rgba(68, 64, 60, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-700:hover {
  background-color: rgba(231, 229, 228, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-700:hover.nightwind-prevent {
  background-color: rgba(68, 64, 60, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-700:hover {
  background-color: rgba(68, 64, 60, var(--tw-bg-opacity));
}

.dark .bg-stone-800 {
  background-color: rgba(245, 245, 244, var(--tw-bg-opacity));
}

.dark .bg-stone-800.nightwind-prevent {
  background-color: rgba(41, 37, 36, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-800 {
  background-color: rgba(41, 37, 36, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-800:hover {
  background-color: rgba(245, 245, 244, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-800:hover.nightwind-prevent {
  background-color: rgba(41, 37, 36, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-800:hover {
  background-color: rgba(41, 37, 36, var(--tw-bg-opacity));
}

.dark .bg-stone-900 {
  background-color: rgba(250, 250, 249, var(--tw-bg-opacity));
}

.dark .bg-stone-900.nightwind-prevent {
  background-color: rgba(28, 25, 23, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-stone-900 {
  background-color: rgba(28, 25, 23, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-900:hover {
  background-color: rgba(250, 250, 249, var(--tw-bg-opacity));
}

.dark .hover\:bg-stone-900:hover.nightwind-prevent {
  background-color: rgba(28, 25, 23, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-stone-900:hover {
  background-color: rgba(28, 25, 23, var(--tw-bg-opacity));
}

.dark .bg-red-50 {
  background-color: rgba(127, 29, 29, var(--tw-bg-opacity));
}

.dark .bg-red-50.nightwind-prevent {
  background-color: rgba(254, 242, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-50 {
  background-color: rgba(254, 242, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-50:hover {
  background-color: rgba(127, 29, 29, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-50:hover.nightwind-prevent {
  background-color: rgba(254, 242, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-50:hover {
  background-color: rgba(254, 242, 242, var(--tw-bg-opacity));
}

.dark .bg-red-100 {
  background-color: rgba(153, 27, 27, var(--tw-bg-opacity));
}

.dark .bg-red-100.nightwind-prevent {
  background-color: rgba(254, 226, 226, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-100 {
  background-color: rgba(254, 226, 226, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-100:hover {
  background-color: rgba(153, 27, 27, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-100:hover.nightwind-prevent {
  background-color: rgba(254, 226, 226, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-100:hover {
  background-color: rgba(254, 226, 226, var(--tw-bg-opacity));
}

.dark .bg-red-200 {
  background-color: rgba(185, 28, 28, var(--tw-bg-opacity));
}

.dark .bg-red-200.nightwind-prevent {
  background-color: rgba(254, 202, 202, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-200 {
  background-color: rgba(254, 202, 202, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-200:hover {
  background-color: rgba(185, 28, 28, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-200:hover.nightwind-prevent {
  background-color: rgba(254, 202, 202, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-200:hover {
  background-color: rgba(254, 202, 202, var(--tw-bg-opacity));
}

.dark .bg-red-300 {
  background-color: rgba(220, 38, 38, var(--tw-bg-opacity));
}

.dark .bg-red-300.nightwind-prevent {
  background-color: rgba(252, 165, 165, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-300 {
  background-color: rgba(252, 165, 165, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-300:hover {
  background-color: rgba(220, 38, 38, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-300:hover.nightwind-prevent {
  background-color: rgba(252, 165, 165, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-300:hover {
  background-color: rgba(252, 165, 165, var(--tw-bg-opacity));
}

.dark .bg-red-400 {
  background-color: rgba(239, 68, 68, var(--tw-bg-opacity));
}

.dark .bg-red-400.nightwind-prevent {
  background-color: rgba(248, 113, 113, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-400 {
  background-color: rgba(248, 113, 113, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-400:hover {
  background-color: rgba(239, 68, 68, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-400:hover.nightwind-prevent {
  background-color: rgba(248, 113, 113, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-400:hover {
  background-color: rgba(248, 113, 113, var(--tw-bg-opacity));
}

.dark .bg-red-500 {
  background-color: rgba(248, 113, 113, var(--tw-bg-opacity));
}

.dark .bg-red-500.nightwind-prevent {
  background-color: rgba(239, 68, 68, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-500 {
  background-color: rgba(239, 68, 68, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-500:hover {
  background-color: rgba(248, 113, 113, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-500:hover.nightwind-prevent {
  background-color: rgba(239, 68, 68, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-500:hover {
  background-color: rgba(239, 68, 68, var(--tw-bg-opacity));
}

.dark .bg-red-600 {
  background-color: rgba(252, 165, 165, var(--tw-bg-opacity));
}

.dark .bg-red-600.nightwind-prevent {
  background-color: rgba(220, 38, 38, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-600 {
  background-color: rgba(220, 38, 38, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-600:hover {
  background-color: rgba(252, 165, 165, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-600:hover.nightwind-prevent {
  background-color: rgba(220, 38, 38, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-600:hover {
  background-color: rgba(220, 38, 38, var(--tw-bg-opacity));
}

.dark .bg-red-700 {
  background-color: rgba(254, 202, 202, var(--tw-bg-opacity));
}

.dark .bg-red-700.nightwind-prevent {
  background-color: rgba(185, 28, 28, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-700 {
  background-color: rgba(185, 28, 28, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-700:hover {
  background-color: rgba(254, 202, 202, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-700:hover.nightwind-prevent {
  background-color: rgba(185, 28, 28, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-700:hover {
  background-color: rgba(185, 28, 28, var(--tw-bg-opacity));
}

.dark .bg-red-800 {
  background-color: rgba(254, 226, 226, var(--tw-bg-opacity));
}

.dark .bg-red-800.nightwind-prevent {
  background-color: rgba(153, 27, 27, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-800 {
  background-color: rgba(153, 27, 27, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-800:hover {
  background-color: rgba(254, 226, 226, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-800:hover.nightwind-prevent {
  background-color: rgba(153, 27, 27, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-800:hover {
  background-color: rgba(153, 27, 27, var(--tw-bg-opacity));
}

.dark .bg-red-900 {
  background-color: rgba(254, 242, 242, var(--tw-bg-opacity));
}

.dark .bg-red-900.nightwind-prevent {
  background-color: rgba(127, 29, 29, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-red-900 {
  background-color: rgba(127, 29, 29, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-900:hover {
  background-color: rgba(254, 242, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-red-900:hover.nightwind-prevent {
  background-color: rgba(127, 29, 29, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-red-900:hover {
  background-color: rgba(127, 29, 29, var(--tw-bg-opacity));
}

.dark .bg-orange-50 {
  background-color: rgba(124, 45, 18, var(--tw-bg-opacity));
}

.dark .bg-orange-50.nightwind-prevent {
  background-color: rgba(255, 247, 237, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-50 {
  background-color: rgba(255, 247, 237, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-50:hover {
  background-color: rgba(124, 45, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-50:hover.nightwind-prevent {
  background-color: rgba(255, 247, 237, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-50:hover {
  background-color: rgba(255, 247, 237, var(--tw-bg-opacity));
}

.dark .bg-orange-100 {
  background-color: rgba(154, 52, 18, var(--tw-bg-opacity));
}

.dark .bg-orange-100.nightwind-prevent {
  background-color: rgba(255, 237, 213, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-100 {
  background-color: rgba(255, 237, 213, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-100:hover {
  background-color: rgba(154, 52, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-100:hover.nightwind-prevent {
  background-color: rgba(255, 237, 213, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-100:hover {
  background-color: rgba(255, 237, 213, var(--tw-bg-opacity));
}

.dark .bg-orange-200 {
  background-color: rgba(194, 65, 12, var(--tw-bg-opacity));
}

.dark .bg-orange-200.nightwind-prevent {
  background-color: rgba(254, 215, 170, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-200 {
  background-color: rgba(254, 215, 170, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-200:hover {
  background-color: rgba(194, 65, 12, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-200:hover.nightwind-prevent {
  background-color: rgba(254, 215, 170, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-200:hover {
  background-color: rgba(254, 215, 170, var(--tw-bg-opacity));
}

.dark .bg-orange-300 {
  background-color: rgba(234, 88, 12, var(--tw-bg-opacity));
}

.dark .bg-orange-300.nightwind-prevent {
  background-color: rgba(253, 186, 116, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-300 {
  background-color: rgba(253, 186, 116, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-300:hover {
  background-color: rgba(234, 88, 12, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-300:hover.nightwind-prevent {
  background-color: rgba(253, 186, 116, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-300:hover {
  background-color: rgba(253, 186, 116, var(--tw-bg-opacity));
}

.dark .bg-orange-400 {
  background-color: rgba(249, 115, 22, var(--tw-bg-opacity));
}

.dark .bg-orange-400.nightwind-prevent {
  background-color: rgba(251, 146, 60, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-400 {
  background-color: rgba(251, 146, 60, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-400:hover {
  background-color: rgba(249, 115, 22, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-400:hover.nightwind-prevent {
  background-color: rgba(251, 146, 60, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-400:hover {
  background-color: rgba(251, 146, 60, var(--tw-bg-opacity));
}

.dark .bg-orange-500 {
  background-color: rgba(251, 146, 60, var(--tw-bg-opacity));
}

.dark .bg-orange-500.nightwind-prevent {
  background-color: rgba(249, 115, 22, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-500 {
  background-color: rgba(249, 115, 22, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-500:hover {
  background-color: rgba(251, 146, 60, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-500:hover.nightwind-prevent {
  background-color: rgba(249, 115, 22, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-500:hover {
  background-color: rgba(249, 115, 22, var(--tw-bg-opacity));
}

.dark .bg-orange-600 {
  background-color: rgba(253, 186, 116, var(--tw-bg-opacity));
}

.dark .bg-orange-600.nightwind-prevent {
  background-color: rgba(234, 88, 12, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-600 {
  background-color: rgba(234, 88, 12, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-600:hover {
  background-color: rgba(253, 186, 116, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-600:hover.nightwind-prevent {
  background-color: rgba(234, 88, 12, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-600:hover {
  background-color: rgba(234, 88, 12, var(--tw-bg-opacity));
}

.dark .bg-orange-700 {
  background-color: rgba(254, 215, 170, var(--tw-bg-opacity));
}

.dark .bg-orange-700.nightwind-prevent {
  background-color: rgba(194, 65, 12, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-700 {
  background-color: rgba(194, 65, 12, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-700:hover {
  background-color: rgba(254, 215, 170, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-700:hover.nightwind-prevent {
  background-color: rgba(194, 65, 12, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-700:hover {
  background-color: rgba(194, 65, 12, var(--tw-bg-opacity));
}

.dark .bg-orange-800 {
  background-color: rgba(255, 237, 213, var(--tw-bg-opacity));
}

.dark .bg-orange-800.nightwind-prevent {
  background-color: rgba(154, 52, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-800 {
  background-color: rgba(154, 52, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-800:hover {
  background-color: rgba(255, 237, 213, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-800:hover.nightwind-prevent {
  background-color: rgba(154, 52, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-800:hover {
  background-color: rgba(154, 52, 18, var(--tw-bg-opacity));
}

.dark .bg-orange-900 {
  background-color: rgba(255, 247, 237, var(--tw-bg-opacity));
}

.dark .bg-orange-900.nightwind-prevent {
  background-color: rgba(124, 45, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-orange-900 {
  background-color: rgba(124, 45, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-900:hover {
  background-color: rgba(255, 247, 237, var(--tw-bg-opacity));
}

.dark .hover\:bg-orange-900:hover.nightwind-prevent {
  background-color: rgba(124, 45, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-orange-900:hover {
  background-color: rgba(124, 45, 18, var(--tw-bg-opacity));
}

.dark .bg-amber-50 {
  background-color: rgba(120, 53, 15, var(--tw-bg-opacity));
}

.dark .bg-amber-50.nightwind-prevent {
  background-color: rgba(255, 251, 235, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-50 {
  background-color: rgba(255, 251, 235, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-50:hover {
  background-color: rgba(120, 53, 15, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-50:hover.nightwind-prevent {
  background-color: rgba(255, 251, 235, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-50:hover {
  background-color: rgba(255, 251, 235, var(--tw-bg-opacity));
}

.dark .bg-amber-100 {
  background-color: rgba(146, 64, 14, var(--tw-bg-opacity));
}

.dark .bg-amber-100.nightwind-prevent {
  background-color: rgba(254, 243, 199, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-100 {
  background-color: rgba(254, 243, 199, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-100:hover {
  background-color: rgba(146, 64, 14, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-100:hover.nightwind-prevent {
  background-color: rgba(254, 243, 199, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-100:hover {
  background-color: rgba(254, 243, 199, var(--tw-bg-opacity));
}

.dark .bg-amber-200 {
  background-color: rgba(180, 83, 9, var(--tw-bg-opacity));
}

.dark .bg-amber-200.nightwind-prevent {
  background-color: rgba(253, 230, 138, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-200 {
  background-color: rgba(253, 230, 138, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-200:hover {
  background-color: rgba(180, 83, 9, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-200:hover.nightwind-prevent {
  background-color: rgba(253, 230, 138, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-200:hover {
  background-color: rgba(253, 230, 138, var(--tw-bg-opacity));
}

.dark .bg-amber-300 {
  background-color: rgba(217, 119, 6, var(--tw-bg-opacity));
}

.dark .bg-amber-300.nightwind-prevent {
  background-color: rgba(252, 211, 77, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-300 {
  background-color: rgba(252, 211, 77, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-300:hover {
  background-color: rgba(217, 119, 6, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-300:hover.nightwind-prevent {
  background-color: rgba(252, 211, 77, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-300:hover {
  background-color: rgba(252, 211, 77, var(--tw-bg-opacity));
}

.dark .bg-amber-400 {
  background-color: rgba(245, 158, 11, var(--tw-bg-opacity));
}

.dark .bg-amber-400.nightwind-prevent {
  background-color: rgba(251, 191, 36, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-400 {
  background-color: rgba(251, 191, 36, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-400:hover {
  background-color: rgba(245, 158, 11, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-400:hover.nightwind-prevent {
  background-color: rgba(251, 191, 36, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-400:hover {
  background-color: rgba(251, 191, 36, var(--tw-bg-opacity));
}

.dark .bg-amber-500 {
  background-color: rgba(251, 191, 36, var(--tw-bg-opacity));
}

.dark .bg-amber-500.nightwind-prevent {
  background-color: rgba(245, 158, 11, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-500 {
  background-color: rgba(245, 158, 11, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-500:hover {
  background-color: rgba(251, 191, 36, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-500:hover.nightwind-prevent {
  background-color: rgba(245, 158, 11, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-500:hover {
  background-color: rgba(245, 158, 11, var(--tw-bg-opacity));
}

.dark .bg-amber-600 {
  background-color: rgba(252, 211, 77, var(--tw-bg-opacity));
}

.dark .bg-amber-600.nightwind-prevent {
  background-color: rgba(217, 119, 6, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-600 {
  background-color: rgba(217, 119, 6, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-600:hover {
  background-color: rgba(252, 211, 77, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-600:hover.nightwind-prevent {
  background-color: rgba(217, 119, 6, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-600:hover {
  background-color: rgba(217, 119, 6, var(--tw-bg-opacity));
}

.dark .bg-amber-700 {
  background-color: rgba(253, 230, 138, var(--tw-bg-opacity));
}

.dark .bg-amber-700.nightwind-prevent {
  background-color: rgba(180, 83, 9, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-700 {
  background-color: rgba(180, 83, 9, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-700:hover {
  background-color: rgba(253, 230, 138, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-700:hover.nightwind-prevent {
  background-color: rgba(180, 83, 9, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-700:hover {
  background-color: rgba(180, 83, 9, var(--tw-bg-opacity));
}

.dark .bg-amber-800 {
  background-color: rgba(254, 243, 199, var(--tw-bg-opacity));
}

.dark .bg-amber-800.nightwind-prevent {
  background-color: rgba(146, 64, 14, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-800 {
  background-color: rgba(146, 64, 14, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-800:hover {
  background-color: rgba(254, 243, 199, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-800:hover.nightwind-prevent {
  background-color: rgba(146, 64, 14, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-800:hover {
  background-color: rgba(146, 64, 14, var(--tw-bg-opacity));
}

.dark .bg-amber-900 {
  background-color: rgba(255, 251, 235, var(--tw-bg-opacity));
}

.dark .bg-amber-900.nightwind-prevent {
  background-color: rgba(120, 53, 15, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-amber-900 {
  background-color: rgba(120, 53, 15, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-900:hover {
  background-color: rgba(255, 251, 235, var(--tw-bg-opacity));
}

.dark .hover\:bg-amber-900:hover.nightwind-prevent {
  background-color: rgba(120, 53, 15, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-amber-900:hover {
  background-color: rgba(120, 53, 15, var(--tw-bg-opacity));
}

.dark .bg-yellow-50 {
  background-color: rgba(113, 63, 18, var(--tw-bg-opacity));
}

.dark .bg-yellow-50.nightwind-prevent {
  background-color: rgba(254, 252, 232, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-50 {
  background-color: rgba(254, 252, 232, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-50:hover {
  background-color: rgba(113, 63, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-50:hover.nightwind-prevent {
  background-color: rgba(254, 252, 232, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-50:hover {
  background-color: rgba(254, 252, 232, var(--tw-bg-opacity));
}

.dark .bg-yellow-100 {
  background-color: rgba(133, 77, 14, var(--tw-bg-opacity));
}

.dark .bg-yellow-100.nightwind-prevent {
  background-color: rgba(254, 249, 195, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-100 {
  background-color: rgba(254, 249, 195, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-100:hover {
  background-color: rgba(133, 77, 14, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-100:hover.nightwind-prevent {
  background-color: rgba(254, 249, 195, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-100:hover {
  background-color: rgba(254, 249, 195, var(--tw-bg-opacity));
}

.dark .bg-yellow-200 {
  background-color: rgba(161, 98, 7, var(--tw-bg-opacity));
}

.dark .bg-yellow-200.nightwind-prevent {
  background-color: rgba(254, 240, 138, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-200 {
  background-color: rgba(254, 240, 138, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-200:hover {
  background-color: rgba(161, 98, 7, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-200:hover.nightwind-prevent {
  background-color: rgba(254, 240, 138, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-200:hover {
  background-color: rgba(254, 240, 138, var(--tw-bg-opacity));
}

.dark .bg-yellow-300 {
  background-color: rgba(202, 138, 4, var(--tw-bg-opacity));
}

.dark .bg-yellow-300.nightwind-prevent {
  background-color: rgba(253, 224, 71, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-300 {
  background-color: rgba(253, 224, 71, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-300:hover {
  background-color: rgba(202, 138, 4, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-300:hover.nightwind-prevent {
  background-color: rgba(253, 224, 71, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-300:hover {
  background-color: rgba(253, 224, 71, var(--tw-bg-opacity));
}

.dark .bg-yellow-400 {
  background-color: rgba(234, 179, 8, var(--tw-bg-opacity));
}

.dark .bg-yellow-400.nightwind-prevent {
  background-color: rgba(250, 204, 21, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-400 {
  background-color: rgba(250, 204, 21, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-400:hover {
  background-color: rgba(234, 179, 8, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-400:hover.nightwind-prevent {
  background-color: rgba(250, 204, 21, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-400:hover {
  background-color: rgba(250, 204, 21, var(--tw-bg-opacity));
}

.dark .bg-yellow-500 {
  background-color: rgba(250, 204, 21, var(--tw-bg-opacity));
}

.dark .bg-yellow-500.nightwind-prevent {
  background-color: rgba(234, 179, 8, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-500 {
  background-color: rgba(234, 179, 8, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-500:hover {
  background-color: rgba(250, 204, 21, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-500:hover.nightwind-prevent {
  background-color: rgba(234, 179, 8, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-500:hover {
  background-color: rgba(234, 179, 8, var(--tw-bg-opacity));
}

.dark .bg-yellow-600 {
  background-color: rgba(253, 224, 71, var(--tw-bg-opacity));
}

.dark .bg-yellow-600.nightwind-prevent {
  background-color: rgba(202, 138, 4, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-600 {
  background-color: rgba(202, 138, 4, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-600:hover {
  background-color: rgba(253, 224, 71, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-600:hover.nightwind-prevent {
  background-color: rgba(202, 138, 4, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-600:hover {
  background-color: rgba(202, 138, 4, var(--tw-bg-opacity));
}

.dark .bg-yellow-700 {
  background-color: rgba(254, 240, 138, var(--tw-bg-opacity));
}

.dark .bg-yellow-700.nightwind-prevent {
  background-color: rgba(161, 98, 7, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-700 {
  background-color: rgba(161, 98, 7, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-700:hover {
  background-color: rgba(254, 240, 138, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-700:hover.nightwind-prevent {
  background-color: rgba(161, 98, 7, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-700:hover {
  background-color: rgba(161, 98, 7, var(--tw-bg-opacity));
}

.dark .bg-yellow-800 {
  background-color: rgba(254, 249, 195, var(--tw-bg-opacity));
}

.dark .bg-yellow-800.nightwind-prevent {
  background-color: rgba(133, 77, 14, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-800 {
  background-color: rgba(133, 77, 14, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-800:hover {
  background-color: rgba(254, 249, 195, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-800:hover.nightwind-prevent {
  background-color: rgba(133, 77, 14, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-800:hover {
  background-color: rgba(133, 77, 14, var(--tw-bg-opacity));
}

.dark .bg-yellow-900 {
  background-color: rgba(254, 252, 232, var(--tw-bg-opacity));
}

.dark .bg-yellow-900.nightwind-prevent {
  background-color: rgba(113, 63, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-yellow-900 {
  background-color: rgba(113, 63, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-900:hover {
  background-color: rgba(254, 252, 232, var(--tw-bg-opacity));
}

.dark .hover\:bg-yellow-900:hover.nightwind-prevent {
  background-color: rgba(113, 63, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-yellow-900:hover {
  background-color: rgba(113, 63, 18, var(--tw-bg-opacity));
}

.dark .bg-lime-50 {
  background-color: rgba(54, 83, 20, var(--tw-bg-opacity));
}

.dark .bg-lime-50.nightwind-prevent {
  background-color: rgba(247, 254, 231, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-50 {
  background-color: rgba(247, 254, 231, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-50:hover {
  background-color: rgba(54, 83, 20, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-50:hover.nightwind-prevent {
  background-color: rgba(247, 254, 231, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-50:hover {
  background-color: rgba(247, 254, 231, var(--tw-bg-opacity));
}

.dark .bg-lime-100 {
  background-color: rgba(63, 98, 18, var(--tw-bg-opacity));
}

.dark .bg-lime-100.nightwind-prevent {
  background-color: rgba(236, 252, 203, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-100 {
  background-color: rgba(236, 252, 203, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-100:hover {
  background-color: rgba(63, 98, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-100:hover.nightwind-prevent {
  background-color: rgba(236, 252, 203, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-100:hover {
  background-color: rgba(236, 252, 203, var(--tw-bg-opacity));
}

.dark .bg-lime-200 {
  background-color: rgba(77, 124, 15, var(--tw-bg-opacity));
}

.dark .bg-lime-200.nightwind-prevent {
  background-color: rgba(217, 249, 157, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-200 {
  background-color: rgba(217, 249, 157, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-200:hover {
  background-color: rgba(77, 124, 15, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-200:hover.nightwind-prevent {
  background-color: rgba(217, 249, 157, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-200:hover {
  background-color: rgba(217, 249, 157, var(--tw-bg-opacity));
}

.dark .bg-lime-300 {
  background-color: rgba(101, 163, 13, var(--tw-bg-opacity));
}

.dark .bg-lime-300.nightwind-prevent {
  background-color: rgba(190, 242, 100, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-300 {
  background-color: rgba(190, 242, 100, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-300:hover {
  background-color: rgba(101, 163, 13, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-300:hover.nightwind-prevent {
  background-color: rgba(190, 242, 100, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-300:hover {
  background-color: rgba(190, 242, 100, var(--tw-bg-opacity));
}

.dark .bg-lime-400 {
  background-color: rgba(132, 204, 22, var(--tw-bg-opacity));
}

.dark .bg-lime-400.nightwind-prevent {
  background-color: rgba(163, 230, 53, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-400 {
  background-color: rgba(163, 230, 53, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-400:hover {
  background-color: rgba(132, 204, 22, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-400:hover.nightwind-prevent {
  background-color: rgba(163, 230, 53, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-400:hover {
  background-color: rgba(163, 230, 53, var(--tw-bg-opacity));
}

.dark .bg-lime-500 {
  background-color: rgba(163, 230, 53, var(--tw-bg-opacity));
}

.dark .bg-lime-500.nightwind-prevent {
  background-color: rgba(132, 204, 22, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-500 {
  background-color: rgba(132, 204, 22, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-500:hover {
  background-color: rgba(163, 230, 53, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-500:hover.nightwind-prevent {
  background-color: rgba(132, 204, 22, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-500:hover {
  background-color: rgba(132, 204, 22, var(--tw-bg-opacity));
}

.dark .bg-lime-600 {
  background-color: rgba(190, 242, 100, var(--tw-bg-opacity));
}

.dark .bg-lime-600.nightwind-prevent {
  background-color: rgba(101, 163, 13, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-600 {
  background-color: rgba(101, 163, 13, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-600:hover {
  background-color: rgba(190, 242, 100, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-600:hover.nightwind-prevent {
  background-color: rgba(101, 163, 13, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-600:hover {
  background-color: rgba(101, 163, 13, var(--tw-bg-opacity));
}

.dark .bg-lime-700 {
  background-color: rgba(217, 249, 157, var(--tw-bg-opacity));
}

.dark .bg-lime-700.nightwind-prevent {
  background-color: rgba(77, 124, 15, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-700 {
  background-color: rgba(77, 124, 15, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-700:hover {
  background-color: rgba(217, 249, 157, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-700:hover.nightwind-prevent {
  background-color: rgba(77, 124, 15, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-700:hover {
  background-color: rgba(77, 124, 15, var(--tw-bg-opacity));
}

.dark .bg-lime-800 {
  background-color: rgba(236, 252, 203, var(--tw-bg-opacity));
}

.dark .bg-lime-800.nightwind-prevent {
  background-color: rgba(63, 98, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-800 {
  background-color: rgba(63, 98, 18, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-800:hover {
  background-color: rgba(236, 252, 203, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-800:hover.nightwind-prevent {
  background-color: rgba(63, 98, 18, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-800:hover {
  background-color: rgba(63, 98, 18, var(--tw-bg-opacity));
}

.dark .bg-lime-900 {
  background-color: rgba(247, 254, 231, var(--tw-bg-opacity));
}

.dark .bg-lime-900.nightwind-prevent {
  background-color: rgba(54, 83, 20, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-lime-900 {
  background-color: rgba(54, 83, 20, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-900:hover {
  background-color: rgba(247, 254, 231, var(--tw-bg-opacity));
}

.dark .hover\:bg-lime-900:hover.nightwind-prevent {
  background-color: rgba(54, 83, 20, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-lime-900:hover {
  background-color: rgba(54, 83, 20, var(--tw-bg-opacity));
}

.dark .bg-green-50 {
  background-color: rgba(20, 83, 45, var(--tw-bg-opacity));
}

.dark .bg-green-50.nightwind-prevent {
  background-color: rgba(240, 253, 244, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-50 {
  background-color: rgba(240, 253, 244, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-50:hover {
  background-color: rgba(20, 83, 45, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-50:hover.nightwind-prevent {
  background-color: rgba(240, 253, 244, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-50:hover {
  background-color: rgba(240, 253, 244, var(--tw-bg-opacity));
}

.dark .bg-green-100 {
  background-color: rgba(22, 101, 52, var(--tw-bg-opacity));
}

.dark .bg-green-100.nightwind-prevent {
  background-color: rgba(220, 252, 231, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-100 {
  background-color: rgba(220, 252, 231, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-100:hover {
  background-color: rgba(22, 101, 52, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-100:hover.nightwind-prevent {
  background-color: rgba(220, 252, 231, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-100:hover {
  background-color: rgba(220, 252, 231, var(--tw-bg-opacity));
}

.dark .bg-green-200 {
  background-color: rgba(21, 128, 61, var(--tw-bg-opacity));
}

.dark .bg-green-200.nightwind-prevent {
  background-color: rgba(187, 247, 208, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-200 {
  background-color: rgba(187, 247, 208, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-200:hover {
  background-color: rgba(21, 128, 61, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-200:hover.nightwind-prevent {
  background-color: rgba(187, 247, 208, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-200:hover {
  background-color: rgba(187, 247, 208, var(--tw-bg-opacity));
}

.dark .bg-green-300 {
  background-color: rgba(22, 163, 74, var(--tw-bg-opacity));
}

.dark .bg-green-300.nightwind-prevent {
  background-color: rgba(134, 239, 172, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-300 {
  background-color: rgba(134, 239, 172, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-300:hover {
  background-color: rgba(22, 163, 74, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-300:hover.nightwind-prevent {
  background-color: rgba(134, 239, 172, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-300:hover {
  background-color: rgba(134, 239, 172, var(--tw-bg-opacity));
}

.dark .bg-green-400 {
  background-color: rgba(34, 197, 94, var(--tw-bg-opacity));
}

.dark .bg-green-400.nightwind-prevent {
  background-color: rgba(74, 222, 128, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-400 {
  background-color: rgba(74, 222, 128, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-400:hover {
  background-color: rgba(34, 197, 94, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-400:hover.nightwind-prevent {
  background-color: rgba(74, 222, 128, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-400:hover {
  background-color: rgba(74, 222, 128, var(--tw-bg-opacity));
}

.dark .bg-green-500 {
  background-color: rgba(74, 222, 128, var(--tw-bg-opacity));
}

.dark .bg-green-500.nightwind-prevent {
  background-color: rgba(34, 197, 94, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-500 {
  background-color: rgba(34, 197, 94, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-500:hover {
  background-color: rgba(74, 222, 128, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-500:hover.nightwind-prevent {
  background-color: rgba(34, 197, 94, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-500:hover {
  background-color: rgba(34, 197, 94, var(--tw-bg-opacity));
}

.dark .bg-green-600 {
  background-color: rgba(134, 239, 172, var(--tw-bg-opacity));
}

.dark .bg-green-600.nightwind-prevent {
  background-color: rgba(22, 163, 74, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-600 {
  background-color: rgba(22, 163, 74, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-600:hover {
  background-color: rgba(134, 239, 172, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-600:hover.nightwind-prevent {
  background-color: rgba(22, 163, 74, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-600:hover {
  background-color: rgba(22, 163, 74, var(--tw-bg-opacity));
}

.dark .bg-green-700 {
  background-color: rgba(187, 247, 208, var(--tw-bg-opacity));
}

.dark .bg-green-700.nightwind-prevent {
  background-color: rgba(21, 128, 61, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-700 {
  background-color: rgba(21, 128, 61, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-700:hover {
  background-color: rgba(187, 247, 208, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-700:hover.nightwind-prevent {
  background-color: rgba(21, 128, 61, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-700:hover {
  background-color: rgba(21, 128, 61, var(--tw-bg-opacity));
}

.dark .bg-green-800 {
  background-color: rgba(220, 252, 231, var(--tw-bg-opacity));
}

.dark .bg-green-800.nightwind-prevent {
  background-color: rgba(22, 101, 52, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-800 {
  background-color: rgba(22, 101, 52, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-800:hover {
  background-color: rgba(220, 252, 231, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-800:hover.nightwind-prevent {
  background-color: rgba(22, 101, 52, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-800:hover {
  background-color: rgba(22, 101, 52, var(--tw-bg-opacity));
}

.dark .bg-green-900 {
  background-color: rgba(240, 253, 244, var(--tw-bg-opacity));
}

.dark .bg-green-900.nightwind-prevent {
  background-color: rgba(20, 83, 45, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-green-900 {
  background-color: rgba(20, 83, 45, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-900:hover {
  background-color: rgba(240, 253, 244, var(--tw-bg-opacity));
}

.dark .hover\:bg-green-900:hover.nightwind-prevent {
  background-color: rgba(20, 83, 45, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-green-900:hover {
  background-color: rgba(20, 83, 45, var(--tw-bg-opacity));
}

.dark .bg-emerald-50 {
  background-color: rgba(6, 78, 59, var(--tw-bg-opacity));
}

.dark .bg-emerald-50.nightwind-prevent {
  background-color: rgba(236, 253, 245, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-50 {
  background-color: rgba(236, 253, 245, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-50:hover {
  background-color: rgba(6, 78, 59, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-50:hover.nightwind-prevent {
  background-color: rgba(236, 253, 245, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-50:hover {
  background-color: rgba(236, 253, 245, var(--tw-bg-opacity));
}

.dark .bg-emerald-100 {
  background-color: rgba(6, 95, 70, var(--tw-bg-opacity));
}

.dark .bg-emerald-100.nightwind-prevent {
  background-color: rgba(209, 250, 229, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-100 {
  background-color: rgba(209, 250, 229, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-100:hover {
  background-color: rgba(6, 95, 70, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-100:hover.nightwind-prevent {
  background-color: rgba(209, 250, 229, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-100:hover {
  background-color: rgba(209, 250, 229, var(--tw-bg-opacity));
}

.dark .bg-emerald-200 {
  background-color: rgba(4, 120, 87, var(--tw-bg-opacity));
}

.dark .bg-emerald-200.nightwind-prevent {
  background-color: rgba(167, 243, 208, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-200 {
  background-color: rgba(167, 243, 208, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-200:hover {
  background-color: rgba(4, 120, 87, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-200:hover.nightwind-prevent {
  background-color: rgba(167, 243, 208, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-200:hover {
  background-color: rgba(167, 243, 208, var(--tw-bg-opacity));
}

.dark .bg-emerald-300 {
  background-color: rgba(5, 150, 105, var(--tw-bg-opacity));
}

.dark .bg-emerald-300.nightwind-prevent {
  background-color: rgba(110, 231, 183, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-300 {
  background-color: rgba(110, 231, 183, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-300:hover {
  background-color: rgba(5, 150, 105, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-300:hover.nightwind-prevent {
  background-color: rgba(110, 231, 183, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-300:hover {
  background-color: rgba(110, 231, 183, var(--tw-bg-opacity));
}

.dark .bg-emerald-400 {
  background-color: rgba(16, 185, 129, var(--tw-bg-opacity));
}

.dark .bg-emerald-400.nightwind-prevent {
  background-color: rgba(52, 211, 153, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-400 {
  background-color: rgba(52, 211, 153, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-400:hover {
  background-color: rgba(16, 185, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-400:hover.nightwind-prevent {
  background-color: rgba(52, 211, 153, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-400:hover {
  background-color: rgba(52, 211, 153, var(--tw-bg-opacity));
}

.dark .bg-emerald-500 {
  background-color: rgba(52, 211, 153, var(--tw-bg-opacity));
}

.dark .bg-emerald-500.nightwind-prevent {
  background-color: rgba(16, 185, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-500 {
  background-color: rgba(16, 185, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-500:hover {
  background-color: rgba(52, 211, 153, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-500:hover.nightwind-prevent {
  background-color: rgba(16, 185, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-500:hover {
  background-color: rgba(16, 185, 129, var(--tw-bg-opacity));
}

.dark .bg-emerald-600 {
  background-color: rgba(110, 231, 183, var(--tw-bg-opacity));
}

.dark .bg-emerald-600.nightwind-prevent {
  background-color: rgba(5, 150, 105, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-600 {
  background-color: rgba(5, 150, 105, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-600:hover {
  background-color: rgba(110, 231, 183, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-600:hover.nightwind-prevent {
  background-color: rgba(5, 150, 105, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-600:hover {
  background-color: rgba(5, 150, 105, var(--tw-bg-opacity));
}

.dark .bg-emerald-700 {
  background-color: rgba(167, 243, 208, var(--tw-bg-opacity));
}

.dark .bg-emerald-700.nightwind-prevent {
  background-color: rgba(4, 120, 87, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-700 {
  background-color: rgba(4, 120, 87, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-700:hover {
  background-color: rgba(167, 243, 208, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-700:hover.nightwind-prevent {
  background-color: rgba(4, 120, 87, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-700:hover {
  background-color: rgba(4, 120, 87, var(--tw-bg-opacity));
}

.dark .bg-emerald-800 {
  background-color: rgba(209, 250, 229, var(--tw-bg-opacity));
}

.dark .bg-emerald-800.nightwind-prevent {
  background-color: rgba(6, 95, 70, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-800 {
  background-color: rgba(6, 95, 70, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-800:hover {
  background-color: rgba(209, 250, 229, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-800:hover.nightwind-prevent {
  background-color: rgba(6, 95, 70, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-800:hover {
  background-color: rgba(6, 95, 70, var(--tw-bg-opacity));
}

.dark .bg-emerald-900 {
  background-color: rgba(236, 253, 245, var(--tw-bg-opacity));
}

.dark .bg-emerald-900.nightwind-prevent {
  background-color: rgba(6, 78, 59, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-emerald-900 {
  background-color: rgba(6, 78, 59, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-900:hover {
  background-color: rgba(236, 253, 245, var(--tw-bg-opacity));
}

.dark .hover\:bg-emerald-900:hover.nightwind-prevent {
  background-color: rgba(6, 78, 59, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-emerald-900:hover {
  background-color: rgba(6, 78, 59, var(--tw-bg-opacity));
}

.dark .bg-teal-50 {
  background-color: rgba(19, 78, 74, var(--tw-bg-opacity));
}

.dark .bg-teal-50.nightwind-prevent {
  background-color: rgba(240, 253, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-50 {
  background-color: rgba(240, 253, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-50:hover {
  background-color: rgba(19, 78, 74, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-50:hover.nightwind-prevent {
  background-color: rgba(240, 253, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-50:hover {
  background-color: rgba(240, 253, 250, var(--tw-bg-opacity));
}

.dark .bg-teal-100 {
  background-color: rgba(17, 94, 89, var(--tw-bg-opacity));
}

.dark .bg-teal-100.nightwind-prevent {
  background-color: rgba(204, 251, 241, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-100 {
  background-color: rgba(204, 251, 241, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-100:hover {
  background-color: rgba(17, 94, 89, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-100:hover.nightwind-prevent {
  background-color: rgba(204, 251, 241, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-100:hover {
  background-color: rgba(204, 251, 241, var(--tw-bg-opacity));
}

.dark .bg-teal-200 {
  background-color: rgba(15, 118, 110, var(--tw-bg-opacity));
}

.dark .bg-teal-200.nightwind-prevent {
  background-color: rgba(153, 246, 228, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-200 {
  background-color: rgba(153, 246, 228, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-200:hover {
  background-color: rgba(15, 118, 110, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-200:hover.nightwind-prevent {
  background-color: rgba(153, 246, 228, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-200:hover {
  background-color: rgba(153, 246, 228, var(--tw-bg-opacity));
}

.dark .bg-teal-300 {
  background-color: rgba(13, 148, 136, var(--tw-bg-opacity));
}

.dark .bg-teal-300.nightwind-prevent {
  background-color: rgba(94, 234, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-300 {
  background-color: rgba(94, 234, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-300:hover {
  background-color: rgba(13, 148, 136, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-300:hover.nightwind-prevent {
  background-color: rgba(94, 234, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-300:hover {
  background-color: rgba(94, 234, 212, var(--tw-bg-opacity));
}

.dark .bg-teal-400 {
  background-color: rgba(20, 184, 166, var(--tw-bg-opacity));
}

.dark .bg-teal-400.nightwind-prevent {
  background-color: rgba(45, 212, 191, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-400 {
  background-color: rgba(45, 212, 191, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-400:hover {
  background-color: rgba(20, 184, 166, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-400:hover.nightwind-prevent {
  background-color: rgba(45, 212, 191, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-400:hover {
  background-color: rgba(45, 212, 191, var(--tw-bg-opacity));
}

.dark .bg-teal-500 {
  background-color: rgba(45, 212, 191, var(--tw-bg-opacity));
}

.dark .bg-teal-500.nightwind-prevent {
  background-color: rgba(20, 184, 166, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-500 {
  background-color: rgba(20, 184, 166, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-500:hover {
  background-color: rgba(45, 212, 191, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-500:hover.nightwind-prevent {
  background-color: rgba(20, 184, 166, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-500:hover {
  background-color: rgba(20, 184, 166, var(--tw-bg-opacity));
}

.dark .bg-teal-600 {
  background-color: rgba(94, 234, 212, var(--tw-bg-opacity));
}

.dark .bg-teal-600.nightwind-prevent {
  background-color: rgba(13, 148, 136, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-600 {
  background-color: rgba(13, 148, 136, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-600:hover {
  background-color: rgba(94, 234, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-600:hover.nightwind-prevent {
  background-color: rgba(13, 148, 136, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-600:hover {
  background-color: rgba(13, 148, 136, var(--tw-bg-opacity));
}

.dark .bg-teal-700 {
  background-color: rgba(153, 246, 228, var(--tw-bg-opacity));
}

.dark .bg-teal-700.nightwind-prevent {
  background-color: rgba(15, 118, 110, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-700 {
  background-color: rgba(15, 118, 110, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-700:hover {
  background-color: rgba(153, 246, 228, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-700:hover.nightwind-prevent {
  background-color: rgba(15, 118, 110, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-700:hover {
  background-color: rgba(15, 118, 110, var(--tw-bg-opacity));
}

.dark .bg-teal-800 {
  background-color: rgba(204, 251, 241, var(--tw-bg-opacity));
}

.dark .bg-teal-800.nightwind-prevent {
  background-color: rgba(17, 94, 89, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-800 {
  background-color: rgba(17, 94, 89, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-800:hover {
  background-color: rgba(204, 251, 241, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-800:hover.nightwind-prevent {
  background-color: rgba(17, 94, 89, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-800:hover {
  background-color: rgba(17, 94, 89, var(--tw-bg-opacity));
}

.dark .bg-teal-900 {
  background-color: rgba(240, 253, 250, var(--tw-bg-opacity));
}

.dark .bg-teal-900.nightwind-prevent {
  background-color: rgba(19, 78, 74, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-teal-900 {
  background-color: rgba(19, 78, 74, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-900:hover {
  background-color: rgba(240, 253, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-teal-900:hover.nightwind-prevent {
  background-color: rgba(19, 78, 74, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-teal-900:hover {
  background-color: rgba(19, 78, 74, var(--tw-bg-opacity));
}

.dark .bg-cyan-50 {
  background-color: rgba(22, 78, 99, var(--tw-bg-opacity));
}

.dark .bg-cyan-50.nightwind-prevent {
  background-color: rgba(236, 254, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-50 {
  background-color: rgba(236, 254, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-50:hover {
  background-color: rgba(22, 78, 99, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-50:hover.nightwind-prevent {
  background-color: rgba(236, 254, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-50:hover {
  background-color: rgba(236, 254, 255, var(--tw-bg-opacity));
}

.dark .bg-cyan-100 {
  background-color: rgba(21, 94, 117, var(--tw-bg-opacity));
}

.dark .bg-cyan-100.nightwind-prevent {
  background-color: rgba(207, 250, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-100 {
  background-color: rgba(207, 250, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-100:hover {
  background-color: rgba(21, 94, 117, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-100:hover.nightwind-prevent {
  background-color: rgba(207, 250, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-100:hover {
  background-color: rgba(207, 250, 254, var(--tw-bg-opacity));
}

.dark .bg-cyan-200 {
  background-color: rgba(14, 116, 144, var(--tw-bg-opacity));
}

.dark .bg-cyan-200.nightwind-prevent {
  background-color: rgba(165, 243, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-200 {
  background-color: rgba(165, 243, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-200:hover {
  background-color: rgba(14, 116, 144, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-200:hover.nightwind-prevent {
  background-color: rgba(165, 243, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-200:hover {
  background-color: rgba(165, 243, 252, var(--tw-bg-opacity));
}

.dark .bg-cyan-300 {
  background-color: rgba(8, 145, 178, var(--tw-bg-opacity));
}

.dark .bg-cyan-300.nightwind-prevent {
  background-color: rgba(103, 232, 249, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-300 {
  background-color: rgba(103, 232, 249, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-300:hover {
  background-color: rgba(8, 145, 178, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-300:hover.nightwind-prevent {
  background-color: rgba(103, 232, 249, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-300:hover {
  background-color: rgba(103, 232, 249, var(--tw-bg-opacity));
}

.dark .bg-cyan-400 {
  background-color: rgba(6, 182, 212, var(--tw-bg-opacity));
}

.dark .bg-cyan-400.nightwind-prevent {
  background-color: rgba(34, 211, 238, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-400 {
  background-color: rgba(34, 211, 238, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-400:hover {
  background-color: rgba(6, 182, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-400:hover.nightwind-prevent {
  background-color: rgba(34, 211, 238, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-400:hover {
  background-color: rgba(34, 211, 238, var(--tw-bg-opacity));
}

.dark .bg-cyan-500 {
  background-color: rgba(34, 211, 238, var(--tw-bg-opacity));
}

.dark .bg-cyan-500.nightwind-prevent {
  background-color: rgba(6, 182, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-500 {
  background-color: rgba(6, 182, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-500:hover {
  background-color: rgba(34, 211, 238, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-500:hover.nightwind-prevent {
  background-color: rgba(6, 182, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-500:hover {
  background-color: rgba(6, 182, 212, var(--tw-bg-opacity));
}

.dark .bg-cyan-600 {
  background-color: rgba(103, 232, 249, var(--tw-bg-opacity));
}

.dark .bg-cyan-600.nightwind-prevent {
  background-color: rgba(8, 145, 178, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-600 {
  background-color: rgba(8, 145, 178, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-600:hover {
  background-color: rgba(103, 232, 249, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-600:hover.nightwind-prevent {
  background-color: rgba(8, 145, 178, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-600:hover {
  background-color: rgba(8, 145, 178, var(--tw-bg-opacity));
}

.dark .bg-cyan-700 {
  background-color: rgba(165, 243, 252, var(--tw-bg-opacity));
}

.dark .bg-cyan-700.nightwind-prevent {
  background-color: rgba(14, 116, 144, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-700 {
  background-color: rgba(14, 116, 144, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-700:hover {
  background-color: rgba(165, 243, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-700:hover.nightwind-prevent {
  background-color: rgba(14, 116, 144, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-700:hover {
  background-color: rgba(14, 116, 144, var(--tw-bg-opacity));
}

.dark .bg-cyan-800 {
  background-color: rgba(207, 250, 254, var(--tw-bg-opacity));
}

.dark .bg-cyan-800.nightwind-prevent {
  background-color: rgba(21, 94, 117, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-800 {
  background-color: rgba(21, 94, 117, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-800:hover {
  background-color: rgba(207, 250, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-800:hover.nightwind-prevent {
  background-color: rgba(21, 94, 117, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-800:hover {
  background-color: rgba(21, 94, 117, var(--tw-bg-opacity));
}

.dark .bg-cyan-900 {
  background-color: rgba(236, 254, 255, var(--tw-bg-opacity));
}

.dark .bg-cyan-900.nightwind-prevent {
  background-color: rgba(22, 78, 99, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-cyan-900 {
  background-color: rgba(22, 78, 99, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-900:hover {
  background-color: rgba(236, 254, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-cyan-900:hover.nightwind-prevent {
  background-color: rgba(22, 78, 99, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-cyan-900:hover {
  background-color: rgba(22, 78, 99, var(--tw-bg-opacity));
}

.dark .bg-sky-50 {
  background-color: rgba(12, 74, 110, var(--tw-bg-opacity));
}

.dark .bg-sky-50.nightwind-prevent {
  background-color: rgba(240, 249, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-50 {
  background-color: rgba(240, 249, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-50:hover {
  background-color: rgba(12, 74, 110, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-50:hover.nightwind-prevent {
  background-color: rgba(240, 249, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-50:hover {
  background-color: rgba(240, 249, 255, var(--tw-bg-opacity));
}

.dark .bg-sky-100 {
  background-color: rgba(7, 89, 133, var(--tw-bg-opacity));
}

.dark .bg-sky-100.nightwind-prevent {
  background-color: rgba(224, 242, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-100 {
  background-color: rgba(224, 242, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-100:hover {
  background-color: rgba(7, 89, 133, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-100:hover.nightwind-prevent {
  background-color: rgba(224, 242, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-100:hover {
  background-color: rgba(224, 242, 254, var(--tw-bg-opacity));
}

.dark .bg-sky-200 {
  background-color: rgba(3, 105, 161, var(--tw-bg-opacity));
}

.dark .bg-sky-200.nightwind-prevent {
  background-color: rgba(186, 230, 253, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-200 {
  background-color: rgba(186, 230, 253, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-200:hover {
  background-color: rgba(3, 105, 161, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-200:hover.nightwind-prevent {
  background-color: rgba(186, 230, 253, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-200:hover {
  background-color: rgba(186, 230, 253, var(--tw-bg-opacity));
}

.dark .bg-sky-300 {
  background-color: rgba(2, 132, 199, var(--tw-bg-opacity));
}

.dark .bg-sky-300.nightwind-prevent {
  background-color: rgba(125, 211, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-300 {
  background-color: rgba(125, 211, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-300:hover {
  background-color: rgba(2, 132, 199, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-300:hover.nightwind-prevent {
  background-color: rgba(125, 211, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-300:hover {
  background-color: rgba(125, 211, 252, var(--tw-bg-opacity));
}

.dark .bg-sky-400 {
  background-color: rgba(14, 165, 233, var(--tw-bg-opacity));
}

.dark .bg-sky-400.nightwind-prevent {
  background-color: rgba(56, 189, 248, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-400 {
  background-color: rgba(56, 189, 248, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-400:hover {
  background-color: rgba(14, 165, 233, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-400:hover.nightwind-prevent {
  background-color: rgba(56, 189, 248, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-400:hover {
  background-color: rgba(56, 189, 248, var(--tw-bg-opacity));
}

.dark .bg-sky-500 {
  background-color: rgba(56, 189, 248, var(--tw-bg-opacity));
}

.dark .bg-sky-500.nightwind-prevent {
  background-color: rgba(14, 165, 233, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-500 {
  background-color: rgba(14, 165, 233, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-500:hover {
  background-color: rgba(56, 189, 248, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-500:hover.nightwind-prevent {
  background-color: rgba(14, 165, 233, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-500:hover {
  background-color: rgba(14, 165, 233, var(--tw-bg-opacity));
}

.dark .bg-sky-600 {
  background-color: rgba(125, 211, 252, var(--tw-bg-opacity));
}

.dark .bg-sky-600.nightwind-prevent {
  background-color: rgba(2, 132, 199, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-600 {
  background-color: rgba(2, 132, 199, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-600:hover {
  background-color: rgba(125, 211, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-600:hover.nightwind-prevent {
  background-color: rgba(2, 132, 199, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-600:hover {
  background-color: rgba(2, 132, 199, var(--tw-bg-opacity));
}

.dark .bg-sky-700 {
  background-color: rgba(186, 230, 253, var(--tw-bg-opacity));
}

.dark .bg-sky-700.nightwind-prevent {
  background-color: rgba(3, 105, 161, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-700 {
  background-color: rgba(3, 105, 161, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-700:hover {
  background-color: rgba(186, 230, 253, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-700:hover.nightwind-prevent {
  background-color: rgba(3, 105, 161, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-700:hover {
  background-color: rgba(3, 105, 161, var(--tw-bg-opacity));
}

.dark .bg-sky-800 {
  background-color: rgba(224, 242, 254, var(--tw-bg-opacity));
}

.dark .bg-sky-800.nightwind-prevent {
  background-color: rgba(7, 89, 133, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-800 {
  background-color: rgba(7, 89, 133, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-800:hover {
  background-color: rgba(224, 242, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-800:hover.nightwind-prevent {
  background-color: rgba(7, 89, 133, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-800:hover {
  background-color: rgba(7, 89, 133, var(--tw-bg-opacity));
}

.dark .bg-sky-900 {
  background-color: rgba(240, 249, 255, var(--tw-bg-opacity));
}

.dark .bg-sky-900.nightwind-prevent {
  background-color: rgba(12, 74, 110, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-sky-900 {
  background-color: rgba(12, 74, 110, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-900:hover {
  background-color: rgba(240, 249, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-sky-900:hover.nightwind-prevent {
  background-color: rgba(12, 74, 110, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-sky-900:hover {
  background-color: rgba(12, 74, 110, var(--tw-bg-opacity));
}

.dark .bg-blue-50 {
  background-color: rgba(30, 58, 138, var(--tw-bg-opacity));
}

.dark .bg-blue-50.nightwind-prevent {
  background-color: rgba(239, 246, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-50 {
  background-color: rgba(239, 246, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-50:hover {
  background-color: rgba(30, 58, 138, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-50:hover.nightwind-prevent {
  background-color: rgba(239, 246, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-50:hover {
  background-color: rgba(239, 246, 255, var(--tw-bg-opacity));
}

.dark .bg-blue-100 {
  background-color: rgba(30, 64, 175, var(--tw-bg-opacity));
}

.dark .bg-blue-100.nightwind-prevent {
  background-color: rgba(219, 234, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-100 {
  background-color: rgba(219, 234, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-100:hover {
  background-color: rgba(30, 64, 175, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-100:hover.nightwind-prevent {
  background-color: rgba(219, 234, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-100:hover {
  background-color: rgba(219, 234, 254, var(--tw-bg-opacity));
}

.dark .bg-blue-200 {
  background-color: rgba(29, 78, 216, var(--tw-bg-opacity));
}

.dark .bg-blue-200.nightwind-prevent {
  background-color: rgba(191, 219, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-200 {
  background-color: rgba(191, 219, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-200:hover {
  background-color: rgba(29, 78, 216, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-200:hover.nightwind-prevent {
  background-color: rgba(191, 219, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-200:hover {
  background-color: rgba(191, 219, 254, var(--tw-bg-opacity));
}

.dark .bg-blue-300 {
  background-color: rgba(37, 99, 235, var(--tw-bg-opacity));
}

.dark .bg-blue-300.nightwind-prevent {
  background-color: rgba(147, 197, 253, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-300 {
  background-color: rgba(147, 197, 253, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-300:hover {
  background-color: rgba(37, 99, 235, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-300:hover.nightwind-prevent {
  background-color: rgba(147, 197, 253, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-300:hover {
  background-color: rgba(147, 197, 253, var(--tw-bg-opacity));
}

.dark .bg-blue-400 {
  background-color: rgba(59, 130, 246, var(--tw-bg-opacity));
}

.dark .bg-blue-400.nightwind-prevent {
  background-color: rgba(96, 165, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-400 {
  background-color: rgba(96, 165, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-400:hover {
  background-color: rgba(59, 130, 246, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-400:hover.nightwind-prevent {
  background-color: rgba(96, 165, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-400:hover {
  background-color: rgba(96, 165, 250, var(--tw-bg-opacity));
}

.dark .bg-blue-500 {
  background-color: rgba(96, 165, 250, var(--tw-bg-opacity));
}

.dark .bg-blue-500.nightwind-prevent {
  background-color: rgba(59, 130, 246, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-500 {
  background-color: rgba(59, 130, 246, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-500:hover {
  background-color: rgba(96, 165, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-500:hover.nightwind-prevent {
  background-color: rgba(59, 130, 246, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-500:hover {
  background-color: rgba(59, 130, 246, var(--tw-bg-opacity));
}

.dark .bg-blue-600 {
  background-color: rgba(147, 197, 253, var(--tw-bg-opacity));
}

.dark .bg-blue-600.nightwind-prevent {
  background-color: rgba(37, 99, 235, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-600 {
  background-color: rgba(37, 99, 235, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-600:hover {
  background-color: rgba(147, 197, 253, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-600:hover.nightwind-prevent {
  background-color: rgba(37, 99, 235, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-600:hover {
  background-color: rgba(37, 99, 235, var(--tw-bg-opacity));
}

.dark .bg-blue-700 {
  background-color: rgba(191, 219, 254, var(--tw-bg-opacity));
}

.dark .bg-blue-700.nightwind-prevent {
  background-color: rgba(29, 78, 216, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-700 {
  background-color: rgba(29, 78, 216, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-700:hover {
  background-color: rgba(191, 219, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-700:hover.nightwind-prevent {
  background-color: rgba(29, 78, 216, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-700:hover {
  background-color: rgba(29, 78, 216, var(--tw-bg-opacity));
}

.dark .bg-blue-800 {
  background-color: rgba(219, 234, 254, var(--tw-bg-opacity));
}

.dark .bg-blue-800.nightwind-prevent {
  background-color: rgba(30, 64, 175, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-800 {
  background-color: rgba(30, 64, 175, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-800:hover {
  background-color: rgba(219, 234, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-800:hover.nightwind-prevent {
  background-color: rgba(30, 64, 175, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-800:hover {
  background-color: rgba(30, 64, 175, var(--tw-bg-opacity));
}

.dark .bg-blue-900 {
  background-color: rgba(239, 246, 255, var(--tw-bg-opacity));
}

.dark .bg-blue-900.nightwind-prevent {
  background-color: rgba(30, 58, 138, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-blue-900 {
  background-color: rgba(30, 58, 138, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-900:hover {
  background-color: rgba(239, 246, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-blue-900:hover.nightwind-prevent {
  background-color: rgba(30, 58, 138, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-blue-900:hover {
  background-color: rgba(30, 58, 138, var(--tw-bg-opacity));
}

.dark .bg-indigo-50 {
  background-color: rgba(49, 46, 129, var(--tw-bg-opacity));
}

.dark .bg-indigo-50.nightwind-prevent {
  background-color: rgba(238, 242, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-50 {
  background-color: rgba(238, 242, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-50:hover {
  background-color: rgba(49, 46, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-50:hover.nightwind-prevent {
  background-color: rgba(238, 242, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-50:hover {
  background-color: rgba(238, 242, 255, var(--tw-bg-opacity));
}

.dark .bg-indigo-100 {
  background-color: rgba(55, 48, 163, var(--tw-bg-opacity));
}

.dark .bg-indigo-100.nightwind-prevent {
  background-color: rgba(224, 231, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-100 {
  background-color: rgba(224, 231, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-100:hover {
  background-color: rgba(55, 48, 163, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-100:hover.nightwind-prevent {
  background-color: rgba(224, 231, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-100:hover {
  background-color: rgba(224, 231, 255, var(--tw-bg-opacity));
}

.dark .bg-indigo-200 {
  background-color: rgba(67, 56, 202, var(--tw-bg-opacity));
}

.dark .bg-indigo-200.nightwind-prevent {
  background-color: rgba(199, 210, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-200 {
  background-color: rgba(199, 210, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-200:hover {
  background-color: rgba(67, 56, 202, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-200:hover.nightwind-prevent {
  background-color: rgba(199, 210, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-200:hover {
  background-color: rgba(199, 210, 254, var(--tw-bg-opacity));
}

.dark .bg-indigo-300 {
  background-color: rgba(79, 70, 229, var(--tw-bg-opacity));
}

.dark .bg-indigo-300.nightwind-prevent {
  background-color: rgba(165, 180, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-300 {
  background-color: rgba(165, 180, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-300:hover {
  background-color: rgba(79, 70, 229, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-300:hover.nightwind-prevent {
  background-color: rgba(165, 180, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-300:hover {
  background-color: rgba(165, 180, 252, var(--tw-bg-opacity));
}

.dark .bg-indigo-400 {
  background-color: rgba(99, 102, 241, var(--tw-bg-opacity));
}

.dark .bg-indigo-400.nightwind-prevent {
  background-color: rgba(129, 140, 248, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-400 {
  background-color: rgba(129, 140, 248, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-400:hover {
  background-color: rgba(99, 102, 241, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-400:hover.nightwind-prevent {
  background-color: rgba(129, 140, 248, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-400:hover {
  background-color: rgba(129, 140, 248, var(--tw-bg-opacity));
}

.dark .bg-indigo-500 {
  background-color: rgba(129, 140, 248, var(--tw-bg-opacity));
}

.dark .bg-indigo-500.nightwind-prevent {
  background-color: rgba(99, 102, 241, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-500 {
  background-color: rgba(99, 102, 241, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-500:hover {
  background-color: rgba(129, 140, 248, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-500:hover.nightwind-prevent {
  background-color: rgba(99, 102, 241, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-500:hover {
  background-color: rgba(99, 102, 241, var(--tw-bg-opacity));
}

.dark .bg-indigo-600 {
  background-color: rgba(165, 180, 252, var(--tw-bg-opacity));
}

.dark .bg-indigo-600.nightwind-prevent {
  background-color: rgba(79, 70, 229, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-600 {
  background-color: rgba(79, 70, 229, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-600:hover {
  background-color: rgba(165, 180, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-600:hover.nightwind-prevent {
  background-color: rgba(79, 70, 229, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-600:hover {
  background-color: rgba(79, 70, 229, var(--tw-bg-opacity));
}

.dark .bg-indigo-700 {
  background-color: rgba(199, 210, 254, var(--tw-bg-opacity));
}

.dark .bg-indigo-700.nightwind-prevent {
  background-color: rgba(67, 56, 202, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-700 {
  background-color: rgba(67, 56, 202, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-700:hover {
  background-color: rgba(199, 210, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-700:hover.nightwind-prevent {
  background-color: rgba(67, 56, 202, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-700:hover {
  background-color: rgba(67, 56, 202, var(--tw-bg-opacity));
}

.dark .bg-indigo-800 {
  background-color: rgba(224, 231, 255, var(--tw-bg-opacity));
}

.dark .bg-indigo-800.nightwind-prevent {
  background-color: rgba(55, 48, 163, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-800 {
  background-color: rgba(55, 48, 163, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-800:hover {
  background-color: rgba(224, 231, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-800:hover.nightwind-prevent {
  background-color: rgba(55, 48, 163, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-800:hover {
  background-color: rgba(55, 48, 163, var(--tw-bg-opacity));
}

.dark .bg-indigo-900 {
  background-color: rgba(238, 242, 255, var(--tw-bg-opacity));
}

.dark .bg-indigo-900.nightwind-prevent {
  background-color: rgba(49, 46, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-indigo-900 {
  background-color: rgba(49, 46, 129, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-900:hover {
  background-color: rgba(238, 242, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-indigo-900:hover.nightwind-prevent {
  background-color: rgba(49, 46, 129, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-indigo-900:hover {
  background-color: rgba(49, 46, 129, var(--tw-bg-opacity));
}

.dark .bg-violet-50 {
  background-color: rgba(76, 29, 149, var(--tw-bg-opacity));
}

.dark .bg-violet-50.nightwind-prevent {
  background-color: rgba(245, 243, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-50 {
  background-color: rgba(245, 243, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-50:hover {
  background-color: rgba(76, 29, 149, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-50:hover.nightwind-prevent {
  background-color: rgba(245, 243, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-50:hover {
  background-color: rgba(245, 243, 255, var(--tw-bg-opacity));
}

.dark .bg-violet-100 {
  background-color: rgba(91, 33, 182, var(--tw-bg-opacity));
}

.dark .bg-violet-100.nightwind-prevent {
  background-color: rgba(237, 233, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-100 {
  background-color: rgba(237, 233, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-100:hover {
  background-color: rgba(91, 33, 182, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-100:hover.nightwind-prevent {
  background-color: rgba(237, 233, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-100:hover {
  background-color: rgba(237, 233, 254, var(--tw-bg-opacity));
}

.dark .bg-violet-200 {
  background-color: rgba(109, 40, 217, var(--tw-bg-opacity));
}

.dark .bg-violet-200.nightwind-prevent {
  background-color: rgba(221, 214, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-200 {
  background-color: rgba(221, 214, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-200:hover {
  background-color: rgba(109, 40, 217, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-200:hover.nightwind-prevent {
  background-color: rgba(221, 214, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-200:hover {
  background-color: rgba(221, 214, 254, var(--tw-bg-opacity));
}

.dark .bg-violet-300 {
  background-color: rgba(124, 58, 237, var(--tw-bg-opacity));
}

.dark .bg-violet-300.nightwind-prevent {
  background-color: rgba(196, 181, 253, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-300 {
  background-color: rgba(196, 181, 253, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-300:hover {
  background-color: rgba(124, 58, 237, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-300:hover.nightwind-prevent {
  background-color: rgba(196, 181, 253, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-300:hover {
  background-color: rgba(196, 181, 253, var(--tw-bg-opacity));
}

.dark .bg-violet-400 {
  background-color: rgba(139, 92, 246, var(--tw-bg-opacity));
}

.dark .bg-violet-400.nightwind-prevent {
  background-color: rgba(167, 139, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-400 {
  background-color: rgba(167, 139, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-400:hover {
  background-color: rgba(139, 92, 246, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-400:hover.nightwind-prevent {
  background-color: rgba(167, 139, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-400:hover {
  background-color: rgba(167, 139, 250, var(--tw-bg-opacity));
}

.dark .bg-violet-500 {
  background-color: rgba(167, 139, 250, var(--tw-bg-opacity));
}

.dark .bg-violet-500.nightwind-prevent {
  background-color: rgba(139, 92, 246, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-500 {
  background-color: rgba(139, 92, 246, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-500:hover {
  background-color: rgba(167, 139, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-500:hover.nightwind-prevent {
  background-color: rgba(139, 92, 246, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-500:hover {
  background-color: rgba(139, 92, 246, var(--tw-bg-opacity));
}

.dark .bg-violet-600 {
  background-color: rgba(196, 181, 253, var(--tw-bg-opacity));
}

.dark .bg-violet-600.nightwind-prevent {
  background-color: rgba(124, 58, 237, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-600 {
  background-color: rgba(124, 58, 237, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-600:hover {
  background-color: rgba(196, 181, 253, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-600:hover.nightwind-prevent {
  background-color: rgba(124, 58, 237, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-600:hover {
  background-color: rgba(124, 58, 237, var(--tw-bg-opacity));
}

.dark .bg-violet-700 {
  background-color: rgba(221, 214, 254, var(--tw-bg-opacity));
}

.dark .bg-violet-700.nightwind-prevent {
  background-color: rgba(109, 40, 217, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-700 {
  background-color: rgba(109, 40, 217, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-700:hover {
  background-color: rgba(221, 214, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-700:hover.nightwind-prevent {
  background-color: rgba(109, 40, 217, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-700:hover {
  background-color: rgba(109, 40, 217, var(--tw-bg-opacity));
}

.dark .bg-violet-800 {
  background-color: rgba(237, 233, 254, var(--tw-bg-opacity));
}

.dark .bg-violet-800.nightwind-prevent {
  background-color: rgba(91, 33, 182, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-800 {
  background-color: rgba(91, 33, 182, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-800:hover {
  background-color: rgba(237, 233, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-800:hover.nightwind-prevent {
  background-color: rgba(91, 33, 182, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-800:hover {
  background-color: rgba(91, 33, 182, var(--tw-bg-opacity));
}

.dark .bg-violet-900 {
  background-color: rgba(245, 243, 255, var(--tw-bg-opacity));
}

.dark .bg-violet-900.nightwind-prevent {
  background-color: rgba(76, 29, 149, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-violet-900 {
  background-color: rgba(76, 29, 149, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-900:hover {
  background-color: rgba(245, 243, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-violet-900:hover.nightwind-prevent {
  background-color: rgba(76, 29, 149, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-violet-900:hover {
  background-color: rgba(76, 29, 149, var(--tw-bg-opacity));
}

.dark .bg-purple-50 {
  background-color: rgba(88, 28, 135, var(--tw-bg-opacity));
}

.dark .bg-purple-50.nightwind-prevent {
  background-color: rgba(250, 245, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-50 {
  background-color: rgba(250, 245, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-50:hover {
  background-color: rgba(88, 28, 135, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-50:hover.nightwind-prevent {
  background-color: rgba(250, 245, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-50:hover {
  background-color: rgba(250, 245, 255, var(--tw-bg-opacity));
}

.dark .bg-purple-100 {
  background-color: rgba(107, 33, 168, var(--tw-bg-opacity));
}

.dark .bg-purple-100.nightwind-prevent {
  background-color: rgba(243, 232, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-100 {
  background-color: rgba(243, 232, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-100:hover {
  background-color: rgba(107, 33, 168, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-100:hover.nightwind-prevent {
  background-color: rgba(243, 232, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-100:hover {
  background-color: rgba(243, 232, 255, var(--tw-bg-opacity));
}

.dark .bg-purple-200 {
  background-color: rgba(126, 34, 206, var(--tw-bg-opacity));
}

.dark .bg-purple-200.nightwind-prevent {
  background-color: rgba(233, 213, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-200 {
  background-color: rgba(233, 213, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-200:hover {
  background-color: rgba(126, 34, 206, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-200:hover.nightwind-prevent {
  background-color: rgba(233, 213, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-200:hover {
  background-color: rgba(233, 213, 255, var(--tw-bg-opacity));
}

.dark .bg-purple-300 {
  background-color: rgba(147, 51, 234, var(--tw-bg-opacity));
}

.dark .bg-purple-300.nightwind-prevent {
  background-color: rgba(216, 180, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-300 {
  background-color: rgba(216, 180, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-300:hover {
  background-color: rgba(147, 51, 234, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-300:hover.nightwind-prevent {
  background-color: rgba(216, 180, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-300:hover {
  background-color: rgba(216, 180, 254, var(--tw-bg-opacity));
}

.dark .bg-purple-400 {
  background-color: rgba(168, 85, 247, var(--tw-bg-opacity));
}

.dark .bg-purple-400.nightwind-prevent {
  background-color: rgba(192, 132, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-400 {
  background-color: rgba(192, 132, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-400:hover {
  background-color: rgba(168, 85, 247, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-400:hover.nightwind-prevent {
  background-color: rgba(192, 132, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-400:hover {
  background-color: rgba(192, 132, 252, var(--tw-bg-opacity));
}

.dark .bg-purple-500 {
  background-color: rgba(192, 132, 252, var(--tw-bg-opacity));
}

.dark .bg-purple-500.nightwind-prevent {
  background-color: rgba(168, 85, 247, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-500 {
  background-color: rgba(168, 85, 247, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-500:hover {
  background-color: rgba(192, 132, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-500:hover.nightwind-prevent {
  background-color: rgba(168, 85, 247, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-500:hover {
  background-color: rgba(168, 85, 247, var(--tw-bg-opacity));
}

.dark .bg-purple-600 {
  background-color: rgba(216, 180, 254, var(--tw-bg-opacity));
}

.dark .bg-purple-600.nightwind-prevent {
  background-color: rgba(147, 51, 234, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-600 {
  background-color: rgba(147, 51, 234, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-600:hover {
  background-color: rgba(216, 180, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-600:hover.nightwind-prevent {
  background-color: rgba(147, 51, 234, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-600:hover {
  background-color: rgba(147, 51, 234, var(--tw-bg-opacity));
}

.dark .bg-purple-700 {
  background-color: rgba(233, 213, 255, var(--tw-bg-opacity));
}

.dark .bg-purple-700.nightwind-prevent {
  background-color: rgba(126, 34, 206, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-700 {
  background-color: rgba(126, 34, 206, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-700:hover {
  background-color: rgba(233, 213, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-700:hover.nightwind-prevent {
  background-color: rgba(126, 34, 206, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-700:hover {
  background-color: rgba(126, 34, 206, var(--tw-bg-opacity));
}

.dark .bg-purple-800 {
  background-color: rgba(243, 232, 255, var(--tw-bg-opacity));
}

.dark .bg-purple-800.nightwind-prevent {
  background-color: rgba(107, 33, 168, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-800 {
  background-color: rgba(107, 33, 168, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-800:hover {
  background-color: rgba(243, 232, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-800:hover.nightwind-prevent {
  background-color: rgba(107, 33, 168, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-800:hover {
  background-color: rgba(107, 33, 168, var(--tw-bg-opacity));
}

.dark .bg-purple-900 {
  background-color: rgba(250, 245, 255, var(--tw-bg-opacity));
}

.dark .bg-purple-900.nightwind-prevent {
  background-color: rgba(88, 28, 135, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-purple-900 {
  background-color: rgba(88, 28, 135, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-900:hover {
  background-color: rgba(250, 245, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-purple-900:hover.nightwind-prevent {
  background-color: rgba(88, 28, 135, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-purple-900:hover {
  background-color: rgba(88, 28, 135, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-50 {
  background-color: rgba(112, 26, 117, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-50.nightwind-prevent {
  background-color: rgba(253, 244, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-50 {
  background-color: rgba(253, 244, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-50:hover {
  background-color: rgba(112, 26, 117, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-50:hover.nightwind-prevent {
  background-color: rgba(253, 244, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-50:hover {
  background-color: rgba(253, 244, 255, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-100 {
  background-color: rgba(134, 25, 143, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-100.nightwind-prevent {
  background-color: rgba(250, 232, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-100 {
  background-color: rgba(250, 232, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-100:hover {
  background-color: rgba(134, 25, 143, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-100:hover.nightwind-prevent {
  background-color: rgba(250, 232, 255, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-100:hover {
  background-color: rgba(250, 232, 255, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-200 {
  background-color: rgba(162, 28, 175, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-200.nightwind-prevent {
  background-color: rgba(245, 208, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-200 {
  background-color: rgba(245, 208, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-200:hover {
  background-color: rgba(162, 28, 175, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-200:hover.nightwind-prevent {
  background-color: rgba(245, 208, 254, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-200:hover {
  background-color: rgba(245, 208, 254, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-300 {
  background-color: rgba(192, 38, 211, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-300.nightwind-prevent {
  background-color: rgba(240, 171, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-300 {
  background-color: rgba(240, 171, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-300:hover {
  background-color: rgba(192, 38, 211, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-300:hover.nightwind-prevent {
  background-color: rgba(240, 171, 252, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-300:hover {
  background-color: rgba(240, 171, 252, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-400 {
  background-color: rgba(217, 70, 239, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-400.nightwind-prevent {
  background-color: rgba(232, 121, 249, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-400 {
  background-color: rgba(232, 121, 249, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-400:hover {
  background-color: rgba(217, 70, 239, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-400:hover.nightwind-prevent {
  background-color: rgba(232, 121, 249, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-400:hover {
  background-color: rgba(232, 121, 249, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-500 {
  background-color: rgba(232, 121, 249, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-500.nightwind-prevent {
  background-color: rgba(217, 70, 239, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-500 {
  background-color: rgba(217, 70, 239, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-500:hover {
  background-color: rgba(232, 121, 249, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-500:hover.nightwind-prevent {
  background-color: rgba(217, 70, 239, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-500:hover {
  background-color: rgba(217, 70, 239, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-600 {
  background-color: rgba(240, 171, 252, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-600.nightwind-prevent {
  background-color: rgba(192, 38, 211, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-600 {
  background-color: rgba(192, 38, 211, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-600:hover {
  background-color: rgba(240, 171, 252, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-600:hover.nightwind-prevent {
  background-color: rgba(192, 38, 211, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-600:hover {
  background-color: rgba(192, 38, 211, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-700 {
  background-color: rgba(245, 208, 254, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-700.nightwind-prevent {
  background-color: rgba(162, 28, 175, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-700 {
  background-color: rgba(162, 28, 175, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-700:hover {
  background-color: rgba(245, 208, 254, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-700:hover.nightwind-prevent {
  background-color: rgba(162, 28, 175, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-700:hover {
  background-color: rgba(162, 28, 175, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-800 {
  background-color: rgba(250, 232, 255, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-800.nightwind-prevent {
  background-color: rgba(134, 25, 143, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-800 {
  background-color: rgba(134, 25, 143, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-800:hover {
  background-color: rgba(250, 232, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-800:hover.nightwind-prevent {
  background-color: rgba(134, 25, 143, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-800:hover {
  background-color: rgba(134, 25, 143, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-900 {
  background-color: rgba(253, 244, 255, var(--tw-bg-opacity));
}

.dark .bg-fuchsia-900.nightwind-prevent {
  background-color: rgba(112, 26, 117, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-fuchsia-900 {
  background-color: rgba(112, 26, 117, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-900:hover {
  background-color: rgba(253, 244, 255, var(--tw-bg-opacity));
}

.dark .hover\:bg-fuchsia-900:hover.nightwind-prevent {
  background-color: rgba(112, 26, 117, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-fuchsia-900:hover {
  background-color: rgba(112, 26, 117, var(--tw-bg-opacity));
}

.dark .bg-pink-50 {
  background-color: rgba(131, 24, 67, var(--tw-bg-opacity));
}

.dark .bg-pink-50.nightwind-prevent {
  background-color: rgba(253, 242, 248, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-50 {
  background-color: rgba(253, 242, 248, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-50:hover {
  background-color: rgba(131, 24, 67, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-50:hover.nightwind-prevent {
  background-color: rgba(253, 242, 248, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-50:hover {
  background-color: rgba(253, 242, 248, var(--tw-bg-opacity));
}

.dark .bg-pink-100 {
  background-color: rgba(157, 23, 77, var(--tw-bg-opacity));
}

.dark .bg-pink-100.nightwind-prevent {
  background-color: rgba(252, 231, 243, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-100 {
  background-color: rgba(252, 231, 243, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-100:hover {
  background-color: rgba(157, 23, 77, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-100:hover.nightwind-prevent {
  background-color: rgba(252, 231, 243, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-100:hover {
  background-color: rgba(252, 231, 243, var(--tw-bg-opacity));
}

.dark .bg-pink-200 {
  background-color: rgba(190, 24, 93, var(--tw-bg-opacity));
}

.dark .bg-pink-200.nightwind-prevent {
  background-color: rgba(251, 207, 232, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-200 {
  background-color: rgba(251, 207, 232, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-200:hover {
  background-color: rgba(190, 24, 93, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-200:hover.nightwind-prevent {
  background-color: rgba(251, 207, 232, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-200:hover {
  background-color: rgba(251, 207, 232, var(--tw-bg-opacity));
}

.dark .bg-pink-300 {
  background-color: rgba(219, 39, 119, var(--tw-bg-opacity));
}

.dark .bg-pink-300.nightwind-prevent {
  background-color: rgba(249, 168, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-300 {
  background-color: rgba(249, 168, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-300:hover {
  background-color: rgba(219, 39, 119, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-300:hover.nightwind-prevent {
  background-color: rgba(249, 168, 212, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-300:hover {
  background-color: rgba(249, 168, 212, var(--tw-bg-opacity));
}

.dark .bg-pink-400 {
  background-color: rgba(236, 72, 153, var(--tw-bg-opacity));
}

.dark .bg-pink-400.nightwind-prevent {
  background-color: rgba(244, 114, 182, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-400 {
  background-color: rgba(244, 114, 182, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-400:hover {
  background-color: rgba(236, 72, 153, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-400:hover.nightwind-prevent {
  background-color: rgba(244, 114, 182, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-400:hover {
  background-color: rgba(244, 114, 182, var(--tw-bg-opacity));
}

.dark .bg-pink-500 {
  background-color: rgba(244, 114, 182, var(--tw-bg-opacity));
}

.dark .bg-pink-500.nightwind-prevent {
  background-color: rgba(236, 72, 153, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-500 {
  background-color: rgba(236, 72, 153, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-500:hover {
  background-color: rgba(244, 114, 182, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-500:hover.nightwind-prevent {
  background-color: rgba(236, 72, 153, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-500:hover {
  background-color: rgba(236, 72, 153, var(--tw-bg-opacity));
}

.dark .bg-pink-600 {
  background-color: rgba(249, 168, 212, var(--tw-bg-opacity));
}

.dark .bg-pink-600.nightwind-prevent {
  background-color: rgba(219, 39, 119, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-600 {
  background-color: rgba(219, 39, 119, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-600:hover {
  background-color: rgba(249, 168, 212, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-600:hover.nightwind-prevent {
  background-color: rgba(219, 39, 119, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-600:hover {
  background-color: rgba(219, 39, 119, var(--tw-bg-opacity));
}

.dark .bg-pink-700 {
  background-color: rgba(251, 207, 232, var(--tw-bg-opacity));
}

.dark .bg-pink-700.nightwind-prevent {
  background-color: rgba(190, 24, 93, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-700 {
  background-color: rgba(190, 24, 93, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-700:hover {
  background-color: rgba(251, 207, 232, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-700:hover.nightwind-prevent {
  background-color: rgba(190, 24, 93, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-700:hover {
  background-color: rgba(190, 24, 93, var(--tw-bg-opacity));
}

.dark .bg-pink-800 {
  background-color: rgba(252, 231, 243, var(--tw-bg-opacity));
}

.dark .bg-pink-800.nightwind-prevent {
  background-color: rgba(157, 23, 77, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-800 {
  background-color: rgba(157, 23, 77, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-800:hover {
  background-color: rgba(252, 231, 243, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-800:hover.nightwind-prevent {
  background-color: rgba(157, 23, 77, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-800:hover {
  background-color: rgba(157, 23, 77, var(--tw-bg-opacity));
}

.dark .bg-pink-900 {
  background-color: rgba(253, 242, 248, var(--tw-bg-opacity));
}

.dark .bg-pink-900.nightwind-prevent {
  background-color: rgba(131, 24, 67, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-pink-900 {
  background-color: rgba(131, 24, 67, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-900:hover {
  background-color: rgba(253, 242, 248, var(--tw-bg-opacity));
}

.dark .hover\:bg-pink-900:hover.nightwind-prevent {
  background-color: rgba(131, 24, 67, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-pink-900:hover {
  background-color: rgba(131, 24, 67, var(--tw-bg-opacity));
}

.dark .bg-rose-50 {
  background-color: rgba(136, 19, 55, var(--tw-bg-opacity));
}

.dark .bg-rose-50.nightwind-prevent {
  background-color: rgba(255, 241, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-50 {
  background-color: rgba(255, 241, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-50:hover {
  background-color: rgba(136, 19, 55, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-50:hover.nightwind-prevent {
  background-color: rgba(255, 241, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-50:hover {
  background-color: rgba(255, 241, 242, var(--tw-bg-opacity));
}

.dark .bg-rose-100 {
  background-color: rgba(159, 18, 57, var(--tw-bg-opacity));
}

.dark .bg-rose-100.nightwind-prevent {
  background-color: rgba(255, 228, 230, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-100 {
  background-color: rgba(255, 228, 230, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-100:hover {
  background-color: rgba(159, 18, 57, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-100:hover.nightwind-prevent {
  background-color: rgba(255, 228, 230, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-100:hover {
  background-color: rgba(255, 228, 230, var(--tw-bg-opacity));
}

.dark .bg-rose-200 {
  background-color: rgba(190, 18, 60, var(--tw-bg-opacity));
}

.dark .bg-rose-200.nightwind-prevent {
  background-color: rgba(254, 205, 211, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-200 {
  background-color: rgba(254, 205, 211, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-200:hover {
  background-color: rgba(190, 18, 60, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-200:hover.nightwind-prevent {
  background-color: rgba(254, 205, 211, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-200:hover {
  background-color: rgba(254, 205, 211, var(--tw-bg-opacity));
}

.dark .bg-rose-300 {
  background-color: rgba(225, 29, 72, var(--tw-bg-opacity));
}

.dark .bg-rose-300.nightwind-prevent {
  background-color: rgba(253, 164, 175, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-300 {
  background-color: rgba(253, 164, 175, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-300:hover {
  background-color: rgba(225, 29, 72, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-300:hover.nightwind-prevent {
  background-color: rgba(253, 164, 175, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-300:hover {
  background-color: rgba(253, 164, 175, var(--tw-bg-opacity));
}

.dark .bg-rose-400 {
  background-color: rgba(244, 63, 94, var(--tw-bg-opacity));
}

.dark .bg-rose-400.nightwind-prevent {
  background-color: rgba(251, 113, 133, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-400 {
  background-color: rgba(251, 113, 133, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-400:hover {
  background-color: rgba(244, 63, 94, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-400:hover.nightwind-prevent {
  background-color: rgba(251, 113, 133, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-400:hover {
  background-color: rgba(251, 113, 133, var(--tw-bg-opacity));
}

.dark .bg-rose-500 {
  background-color: rgba(251, 113, 133, var(--tw-bg-opacity));
}

.dark .bg-rose-500.nightwind-prevent {
  background-color: rgba(244, 63, 94, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-500 {
  background-color: rgba(244, 63, 94, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-500:hover {
  background-color: rgba(251, 113, 133, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-500:hover.nightwind-prevent {
  background-color: rgba(244, 63, 94, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-500:hover {
  background-color: rgba(244, 63, 94, var(--tw-bg-opacity));
}

.dark .bg-rose-600 {
  background-color: rgba(253, 164, 175, var(--tw-bg-opacity));
}

.dark .bg-rose-600.nightwind-prevent {
  background-color: rgba(225, 29, 72, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-600 {
  background-color: rgba(225, 29, 72, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-600:hover {
  background-color: rgba(253, 164, 175, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-600:hover.nightwind-prevent {
  background-color: rgba(225, 29, 72, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-600:hover {
  background-color: rgba(225, 29, 72, var(--tw-bg-opacity));
}

.dark .bg-rose-700 {
  background-color: rgba(254, 205, 211, var(--tw-bg-opacity));
}

.dark .bg-rose-700.nightwind-prevent {
  background-color: rgba(190, 18, 60, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-700 {
  background-color: rgba(190, 18, 60, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-700:hover {
  background-color: rgba(254, 205, 211, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-700:hover.nightwind-prevent {
  background-color: rgba(190, 18, 60, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-700:hover {
  background-color: rgba(190, 18, 60, var(--tw-bg-opacity));
}

.dark .bg-rose-800 {
  background-color: rgba(255, 228, 230, var(--tw-bg-opacity));
}

.dark .bg-rose-800.nightwind-prevent {
  background-color: rgba(159, 18, 57, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-800 {
  background-color: rgba(159, 18, 57, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-800:hover {
  background-color: rgba(255, 228, 230, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-800:hover.nightwind-prevent {
  background-color: rgba(159, 18, 57, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-800:hover {
  background-color: rgba(159, 18, 57, var(--tw-bg-opacity));
}

.dark .bg-rose-900 {
  background-color: rgba(255, 241, 242, var(--tw-bg-opacity));
}

.dark .bg-rose-900.nightwind-prevent {
  background-color: rgba(136, 19, 55, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-rose-900 {
  background-color: rgba(136, 19, 55, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-900:hover {
  background-color: rgba(255, 241, 242, var(--tw-bg-opacity));
}

.dark .hover\:bg-rose-900:hover.nightwind-prevent {
  background-color: rgba(136, 19, 55, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-rose-900:hover {
  background-color: rgba(136, 19, 55, var(--tw-bg-opacity));
}

.dark .bg-background-50 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-50.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-50 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-50:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-50:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-50:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-100 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-100.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-100 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-100:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-100:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-100:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-200 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-200.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-200 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-200:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-200:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-200:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-300 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-300.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-300 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-300:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-300:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-300:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-400 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-400.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-400 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-400:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-400:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-400:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-500 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-500.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-500 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-500:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-500:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-500:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-600 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-600.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-600 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-600:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-600:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-600:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-700 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-700.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-700 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-700:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-700:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-700:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-800 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-800.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-800 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-800:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-800:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-800:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-900 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-background-900.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-background-900 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-900:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-background-900:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-background-900:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-50 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-50.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-50 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-50:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-50:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-50:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-100 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-100.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-100 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-100:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-100:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-100:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-200 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-200.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-200 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-200:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-200:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-200:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-300 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-300.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-300 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-300:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-300:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-300:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-400 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-400.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-400 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-400:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-400:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-400:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-500 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-500.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-500 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-500:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-500:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-500:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-600 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-600.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-600 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-600:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-600:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-600:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-700 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-700.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-700 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-700:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-700:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-700:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-800 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-800.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-800 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-800:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-800:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-800:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-900 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .bg-foreground-900.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .bg-foreground-900 {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-900:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .hover\:bg-foreground-900:hover.nightwind-prevent {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-foreground-900:hover {
  background-color: rgba(undefined, undefined, undefined, var(--tw-bg-opacity));
}

.dark .border-inherit-50 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-50.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-50 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-50:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-50:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-50:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-100 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-100.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-100 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-100:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-100:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-100:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-200 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-200.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-200 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-200:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-200:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-200:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-300 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-300.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-300 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-300:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-300:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-300:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-400 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-400.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-400 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-400:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-400:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-400:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-500 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-500.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-500 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-500:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-500:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-500:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-600 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-600.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-600 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-600:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-600:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-600:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-700 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-700.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-700 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-700:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-700:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-700:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-800 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-800.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-800 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-800:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-800:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-800:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-900 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-inherit-900.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-inherit-900 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-900:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-inherit-900:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-inherit-900:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-slate-50 {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .border-slate-50.nightwind-prevent {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-50 {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .hover\:border-slate-50:hover {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .hover\:border-slate-50:hover.nightwind-prevent {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-50:hover {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .border-slate-100 {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .border-slate-100.nightwind-prevent {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-100 {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .hover\:border-slate-100:hover {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .hover\:border-slate-100:hover.nightwind-prevent {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-100:hover {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .border-slate-200 {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .border-slate-200.nightwind-prevent {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-200 {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .hover\:border-slate-200:hover {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .hover\:border-slate-200:hover.nightwind-prevent {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-200:hover {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .border-slate-300 {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .border-slate-300.nightwind-prevent {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-300 {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .hover\:border-slate-300:hover {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .hover\:border-slate-300:hover.nightwind-prevent {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-300:hover {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .border-slate-400 {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .border-slate-400.nightwind-prevent {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-400 {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .hover\:border-slate-400:hover {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .hover\:border-slate-400:hover.nightwind-prevent {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-400:hover {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .border-slate-500 {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .border-slate-500.nightwind-prevent {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-500 {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .hover\:border-slate-500:hover {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .hover\:border-slate-500:hover.nightwind-prevent {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-500:hover {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .border-slate-600 {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .border-slate-600.nightwind-prevent {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-600 {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .hover\:border-slate-600:hover {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .hover\:border-slate-600:hover.nightwind-prevent {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-600:hover {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .border-slate-700 {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .border-slate-700.nightwind-prevent {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-700 {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .hover\:border-slate-700:hover {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .hover\:border-slate-700:hover.nightwind-prevent {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-700:hover {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .border-slate-800 {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .border-slate-800.nightwind-prevent {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-800 {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .hover\:border-slate-800:hover {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .hover\:border-slate-800:hover.nightwind-prevent {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-800:hover {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .border-slate-900 {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .border-slate-900.nightwind-prevent {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-slate-900 {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .hover\:border-slate-900:hover {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .hover\:border-slate-900:hover.nightwind-prevent {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-slate-900:hover {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .border-gray-50 {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .border-gray-50.nightwind-prevent {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-50 {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .hover\:border-gray-50:hover {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .hover\:border-gray-50:hover.nightwind-prevent {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-50:hover {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .border-gray-100 {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .border-gray-100.nightwind-prevent {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-100 {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .hover\:border-gray-100:hover {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .hover\:border-gray-100:hover.nightwind-prevent {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-100:hover {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .border-gray-200 {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .border-gray-200.nightwind-prevent {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-200 {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .hover\:border-gray-200:hover {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .hover\:border-gray-200:hover.nightwind-prevent {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-200:hover {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .border-gray-300 {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .border-gray-300.nightwind-prevent {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-300 {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .hover\:border-gray-300:hover {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .hover\:border-gray-300:hover.nightwind-prevent {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-300:hover {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .border-gray-400 {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .border-gray-400.nightwind-prevent {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-400 {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .hover\:border-gray-400:hover {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .hover\:border-gray-400:hover.nightwind-prevent {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-400:hover {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .border-gray-500 {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .border-gray-500.nightwind-prevent {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-500 {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .hover\:border-gray-500:hover {
  border-color: rgba(140, 149, 159, var(--tw-border-opacity));
}

.dark .hover\:border-gray-500:hover.nightwind-prevent {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-500:hover {
  border-color: rgba(110, 119, 129, var(--tw-border-opacity));
}

.dark .border-gray-600 {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .border-gray-600.nightwind-prevent {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-600 {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .hover\:border-gray-600:hover {
  border-color: rgba(175, 184, 193, var(--tw-border-opacity));
}

.dark .hover\:border-gray-600:hover.nightwind-prevent {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-600:hover {
  border-color: rgba(87, 96, 106, var(--tw-border-opacity));
}

.dark .border-gray-700 {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .border-gray-700.nightwind-prevent {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-700 {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .hover\:border-gray-700:hover {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .hover\:border-gray-700:hover.nightwind-prevent {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-700:hover {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .border-gray-800 {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .border-gray-800.nightwind-prevent {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-800 {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .hover\:border-gray-800:hover {
  border-color: rgba(234, 238, 242, var(--tw-border-opacity));
}

.dark .hover\:border-gray-800:hover.nightwind-prevent {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-800:hover {
  border-color: rgba(50, 56, 63, var(--tw-border-opacity));
}

.dark .border-gray-900 {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .border-gray-900.nightwind-prevent {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-gray-900 {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .hover\:border-gray-900:hover {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .hover\:border-gray-900:hover.nightwind-prevent {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-gray-900:hover {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .border-zinc-50 {
  border-color: rgba(24, 24, 27, var(--tw-border-opacity));
}

.dark .border-zinc-50.nightwind-prevent {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-50 {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-50:hover {
  border-color: rgba(24, 24, 27, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-50:hover.nightwind-prevent {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-50:hover {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .border-zinc-100 {
  border-color: rgba(39, 39, 42, var(--tw-border-opacity));
}

.dark .border-zinc-100.nightwind-prevent {
  border-color: rgba(244, 244, 245, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-100 {
  border-color: rgba(244, 244, 245, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-100:hover {
  border-color: rgba(39, 39, 42, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-100:hover.nightwind-prevent {
  border-color: rgba(244, 244, 245, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-100:hover {
  border-color: rgba(244, 244, 245, var(--tw-border-opacity));
}

.dark .border-zinc-200 {
  border-color: rgba(63, 63, 70, var(--tw-border-opacity));
}

.dark .border-zinc-200.nightwind-prevent {
  border-color: rgba(228, 228, 231, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-200 {
  border-color: rgba(228, 228, 231, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-200:hover {
  border-color: rgba(63, 63, 70, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-200:hover.nightwind-prevent {
  border-color: rgba(228, 228, 231, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-200:hover {
  border-color: rgba(228, 228, 231, var(--tw-border-opacity));
}

.dark .border-zinc-300 {
  border-color: rgba(82, 82, 91, var(--tw-border-opacity));
}

.dark .border-zinc-300.nightwind-prevent {
  border-color: rgba(212, 212, 216, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-300 {
  border-color: rgba(212, 212, 216, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-300:hover {
  border-color: rgba(82, 82, 91, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-300:hover.nightwind-prevent {
  border-color: rgba(212, 212, 216, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-300:hover {
  border-color: rgba(212, 212, 216, var(--tw-border-opacity));
}

.dark .border-zinc-400 {
  border-color: rgba(113, 113, 122, var(--tw-border-opacity));
}

.dark .border-zinc-400.nightwind-prevent {
  border-color: rgba(161, 161, 170, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-400 {
  border-color: rgba(161, 161, 170, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-400:hover {
  border-color: rgba(113, 113, 122, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-400:hover.nightwind-prevent {
  border-color: rgba(161, 161, 170, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-400:hover {
  border-color: rgba(161, 161, 170, var(--tw-border-opacity));
}

.dark .border-zinc-500 {
  border-color: rgba(161, 161, 170, var(--tw-border-opacity));
}

.dark .border-zinc-500.nightwind-prevent {
  border-color: rgba(113, 113, 122, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-500 {
  border-color: rgba(113, 113, 122, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-500:hover {
  border-color: rgba(161, 161, 170, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-500:hover.nightwind-prevent {
  border-color: rgba(113, 113, 122, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-500:hover {
  border-color: rgba(113, 113, 122, var(--tw-border-opacity));
}

.dark .border-zinc-600 {
  border-color: rgba(212, 212, 216, var(--tw-border-opacity));
}

.dark .border-zinc-600.nightwind-prevent {
  border-color: rgba(82, 82, 91, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-600 {
  border-color: rgba(82, 82, 91, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-600:hover {
  border-color: rgba(212, 212, 216, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-600:hover.nightwind-prevent {
  border-color: rgba(82, 82, 91, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-600:hover {
  border-color: rgba(82, 82, 91, var(--tw-border-opacity));
}

.dark .border-zinc-700 {
  border-color: rgba(228, 228, 231, var(--tw-border-opacity));
}

.dark .border-zinc-700.nightwind-prevent {
  border-color: rgba(63, 63, 70, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-700 {
  border-color: rgba(63, 63, 70, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-700:hover {
  border-color: rgba(228, 228, 231, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-700:hover.nightwind-prevent {
  border-color: rgba(63, 63, 70, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-700:hover {
  border-color: rgba(63, 63, 70, var(--tw-border-opacity));
}

.dark .border-zinc-800 {
  border-color: rgba(244, 244, 245, var(--tw-border-opacity));
}

.dark .border-zinc-800.nightwind-prevent {
  border-color: rgba(39, 39, 42, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-800 {
  border-color: rgba(39, 39, 42, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-800:hover {
  border-color: rgba(244, 244, 245, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-800:hover.nightwind-prevent {
  border-color: rgba(39, 39, 42, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-800:hover {
  border-color: rgba(39, 39, 42, var(--tw-border-opacity));
}

.dark .border-zinc-900 {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .border-zinc-900.nightwind-prevent {
  border-color: rgba(24, 24, 27, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-zinc-900 {
  border-color: rgba(24, 24, 27, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-900:hover {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .hover\:border-zinc-900:hover.nightwind-prevent {
  border-color: rgba(24, 24, 27, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-zinc-900:hover {
  border-color: rgba(24, 24, 27, var(--tw-border-opacity));
}

.dark .border-neutral-50 {
  border-color: rgba(23, 23, 23, var(--tw-border-opacity));
}

.dark .border-neutral-50.nightwind-prevent {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-50 {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-50:hover {
  border-color: rgba(23, 23, 23, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-50:hover.nightwind-prevent {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-50:hover {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .border-neutral-100 {
  border-color: rgba(38, 38, 38, var(--tw-border-opacity));
}

.dark .border-neutral-100.nightwind-prevent {
  border-color: rgba(245, 245, 245, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-100 {
  border-color: rgba(245, 245, 245, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-100:hover {
  border-color: rgba(38, 38, 38, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-100:hover.nightwind-prevent {
  border-color: rgba(245, 245, 245, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-100:hover {
  border-color: rgba(245, 245, 245, var(--tw-border-opacity));
}

.dark .border-neutral-200 {
  border-color: rgba(64, 64, 64, var(--tw-border-opacity));
}

.dark .border-neutral-200.nightwind-prevent {
  border-color: rgba(229, 229, 229, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-200 {
  border-color: rgba(229, 229, 229, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-200:hover {
  border-color: rgba(64, 64, 64, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-200:hover.nightwind-prevent {
  border-color: rgba(229, 229, 229, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-200:hover {
  border-color: rgba(229, 229, 229, var(--tw-border-opacity));
}

.dark .border-neutral-300 {
  border-color: rgba(82, 82, 82, var(--tw-border-opacity));
}

.dark .border-neutral-300.nightwind-prevent {
  border-color: rgba(212, 212, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-300 {
  border-color: rgba(212, 212, 212, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-300:hover {
  border-color: rgba(82, 82, 82, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-300:hover.nightwind-prevent {
  border-color: rgba(212, 212, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-300:hover {
  border-color: rgba(212, 212, 212, var(--tw-border-opacity));
}

.dark .border-neutral-400 {
  border-color: rgba(115, 115, 115, var(--tw-border-opacity));
}

.dark .border-neutral-400.nightwind-prevent {
  border-color: rgba(163, 163, 163, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-400 {
  border-color: rgba(163, 163, 163, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-400:hover {
  border-color: rgba(115, 115, 115, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-400:hover.nightwind-prevent {
  border-color: rgba(163, 163, 163, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-400:hover {
  border-color: rgba(163, 163, 163, var(--tw-border-opacity));
}

.dark .border-neutral-500 {
  border-color: rgba(163, 163, 163, var(--tw-border-opacity));
}

.dark .border-neutral-500.nightwind-prevent {
  border-color: rgba(115, 115, 115, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-500 {
  border-color: rgba(115, 115, 115, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-500:hover {
  border-color: rgba(163, 163, 163, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-500:hover.nightwind-prevent {
  border-color: rgba(115, 115, 115, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-500:hover {
  border-color: rgba(115, 115, 115, var(--tw-border-opacity));
}

.dark .border-neutral-600 {
  border-color: rgba(212, 212, 212, var(--tw-border-opacity));
}

.dark .border-neutral-600.nightwind-prevent {
  border-color: rgba(82, 82, 82, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-600 {
  border-color: rgba(82, 82, 82, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-600:hover {
  border-color: rgba(212, 212, 212, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-600:hover.nightwind-prevent {
  border-color: rgba(82, 82, 82, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-600:hover {
  border-color: rgba(82, 82, 82, var(--tw-border-opacity));
}

.dark .border-neutral-700 {
  border-color: rgba(229, 229, 229, var(--tw-border-opacity));
}

.dark .border-neutral-700.nightwind-prevent {
  border-color: rgba(64, 64, 64, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-700 {
  border-color: rgba(64, 64, 64, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-700:hover {
  border-color: rgba(229, 229, 229, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-700:hover.nightwind-prevent {
  border-color: rgba(64, 64, 64, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-700:hover {
  border-color: rgba(64, 64, 64, var(--tw-border-opacity));
}

.dark .border-neutral-800 {
  border-color: rgba(245, 245, 245, var(--tw-border-opacity));
}

.dark .border-neutral-800.nightwind-prevent {
  border-color: rgba(38, 38, 38, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-800 {
  border-color: rgba(38, 38, 38, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-800:hover {
  border-color: rgba(245, 245, 245, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-800:hover.nightwind-prevent {
  border-color: rgba(38, 38, 38, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-800:hover {
  border-color: rgba(38, 38, 38, var(--tw-border-opacity));
}

.dark .border-neutral-900 {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .border-neutral-900.nightwind-prevent {
  border-color: rgba(23, 23, 23, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-neutral-900 {
  border-color: rgba(23, 23, 23, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-900:hover {
  border-color: rgba(250, 250, 250, var(--tw-border-opacity));
}

.dark .hover\:border-neutral-900:hover.nightwind-prevent {
  border-color: rgba(23, 23, 23, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-neutral-900:hover {
  border-color: rgba(23, 23, 23, var(--tw-border-opacity));
}

.dark .border-stone-50 {
  border-color: rgba(28, 25, 23, var(--tw-border-opacity));
}

.dark .border-stone-50.nightwind-prevent {
  border-color: rgba(250, 250, 249, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-50 {
  border-color: rgba(250, 250, 249, var(--tw-border-opacity));
}

.dark .hover\:border-stone-50:hover {
  border-color: rgba(28, 25, 23, var(--tw-border-opacity));
}

.dark .hover\:border-stone-50:hover.nightwind-prevent {
  border-color: rgba(250, 250, 249, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-50:hover {
  border-color: rgba(250, 250, 249, var(--tw-border-opacity));
}

.dark .border-stone-100 {
  border-color: rgba(41, 37, 36, var(--tw-border-opacity));
}

.dark .border-stone-100.nightwind-prevent {
  border-color: rgba(245, 245, 244, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-100 {
  border-color: rgba(245, 245, 244, var(--tw-border-opacity));
}

.dark .hover\:border-stone-100:hover {
  border-color: rgba(41, 37, 36, var(--tw-border-opacity));
}

.dark .hover\:border-stone-100:hover.nightwind-prevent {
  border-color: rgba(245, 245, 244, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-100:hover {
  border-color: rgba(245, 245, 244, var(--tw-border-opacity));
}

.dark .border-stone-200 {
  border-color: rgba(68, 64, 60, var(--tw-border-opacity));
}

.dark .border-stone-200.nightwind-prevent {
  border-color: rgba(231, 229, 228, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-200 {
  border-color: rgba(231, 229, 228, var(--tw-border-opacity));
}

.dark .hover\:border-stone-200:hover {
  border-color: rgba(68, 64, 60, var(--tw-border-opacity));
}

.dark .hover\:border-stone-200:hover.nightwind-prevent {
  border-color: rgba(231, 229, 228, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-200:hover {
  border-color: rgba(231, 229, 228, var(--tw-border-opacity));
}

.dark .border-stone-300 {
  border-color: rgba(87, 83, 78, var(--tw-border-opacity));
}

.dark .border-stone-300.nightwind-prevent {
  border-color: rgba(214, 211, 209, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-300 {
  border-color: rgba(214, 211, 209, var(--tw-border-opacity));
}

.dark .hover\:border-stone-300:hover {
  border-color: rgba(87, 83, 78, var(--tw-border-opacity));
}

.dark .hover\:border-stone-300:hover.nightwind-prevent {
  border-color: rgba(214, 211, 209, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-300:hover {
  border-color: rgba(214, 211, 209, var(--tw-border-opacity));
}

.dark .border-stone-400 {
  border-color: rgba(120, 113, 108, var(--tw-border-opacity));
}

.dark .border-stone-400.nightwind-prevent {
  border-color: rgba(168, 162, 158, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-400 {
  border-color: rgba(168, 162, 158, var(--tw-border-opacity));
}

.dark .hover\:border-stone-400:hover {
  border-color: rgba(120, 113, 108, var(--tw-border-opacity));
}

.dark .hover\:border-stone-400:hover.nightwind-prevent {
  border-color: rgba(168, 162, 158, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-400:hover {
  border-color: rgba(168, 162, 158, var(--tw-border-opacity));
}

.dark .border-stone-500 {
  border-color: rgba(168, 162, 158, var(--tw-border-opacity));
}

.dark .border-stone-500.nightwind-prevent {
  border-color: rgba(120, 113, 108, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-500 {
  border-color: rgba(120, 113, 108, var(--tw-border-opacity));
}

.dark .hover\:border-stone-500:hover {
  border-color: rgba(168, 162, 158, var(--tw-border-opacity));
}

.dark .hover\:border-stone-500:hover.nightwind-prevent {
  border-color: rgba(120, 113, 108, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-500:hover {
  border-color: rgba(120, 113, 108, var(--tw-border-opacity));
}

.dark .border-stone-600 {
  border-color: rgba(214, 211, 209, var(--tw-border-opacity));
}

.dark .border-stone-600.nightwind-prevent {
  border-color: rgba(87, 83, 78, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-600 {
  border-color: rgba(87, 83, 78, var(--tw-border-opacity));
}

.dark .hover\:border-stone-600:hover {
  border-color: rgba(214, 211, 209, var(--tw-border-opacity));
}

.dark .hover\:border-stone-600:hover.nightwind-prevent {
  border-color: rgba(87, 83, 78, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-600:hover {
  border-color: rgba(87, 83, 78, var(--tw-border-opacity));
}

.dark .border-stone-700 {
  border-color: rgba(231, 229, 228, var(--tw-border-opacity));
}

.dark .border-stone-700.nightwind-prevent {
  border-color: rgba(68, 64, 60, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-700 {
  border-color: rgba(68, 64, 60, var(--tw-border-opacity));
}

.dark .hover\:border-stone-700:hover {
  border-color: rgba(231, 229, 228, var(--tw-border-opacity));
}

.dark .hover\:border-stone-700:hover.nightwind-prevent {
  border-color: rgba(68, 64, 60, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-700:hover {
  border-color: rgba(68, 64, 60, var(--tw-border-opacity));
}

.dark .border-stone-800 {
  border-color: rgba(245, 245, 244, var(--tw-border-opacity));
}

.dark .border-stone-800.nightwind-prevent {
  border-color: rgba(41, 37, 36, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-800 {
  border-color: rgba(41, 37, 36, var(--tw-border-opacity));
}

.dark .hover\:border-stone-800:hover {
  border-color: rgba(245, 245, 244, var(--tw-border-opacity));
}

.dark .hover\:border-stone-800:hover.nightwind-prevent {
  border-color: rgba(41, 37, 36, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-800:hover {
  border-color: rgba(41, 37, 36, var(--tw-border-opacity));
}

.dark .border-stone-900 {
  border-color: rgba(250, 250, 249, var(--tw-border-opacity));
}

.dark .border-stone-900.nightwind-prevent {
  border-color: rgba(28, 25, 23, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-stone-900 {
  border-color: rgba(28, 25, 23, var(--tw-border-opacity));
}

.dark .hover\:border-stone-900:hover {
  border-color: rgba(250, 250, 249, var(--tw-border-opacity));
}

.dark .hover\:border-stone-900:hover.nightwind-prevent {
  border-color: rgba(28, 25, 23, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-stone-900:hover {
  border-color: rgba(28, 25, 23, var(--tw-border-opacity));
}

.dark .border-red-50 {
  border-color: rgba(127, 29, 29, var(--tw-border-opacity));
}

.dark .border-red-50.nightwind-prevent {
  border-color: rgba(254, 242, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-50 {
  border-color: rgba(254, 242, 242, var(--tw-border-opacity));
}

.dark .hover\:border-red-50:hover {
  border-color: rgba(127, 29, 29, var(--tw-border-opacity));
}

.dark .hover\:border-red-50:hover.nightwind-prevent {
  border-color: rgba(254, 242, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-50:hover {
  border-color: rgba(254, 242, 242, var(--tw-border-opacity));
}

.dark .border-red-100 {
  border-color: rgba(153, 27, 27, var(--tw-border-opacity));
}

.dark .border-red-100.nightwind-prevent {
  border-color: rgba(254, 226, 226, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-100 {
  border-color: rgba(254, 226, 226, var(--tw-border-opacity));
}

.dark .hover\:border-red-100:hover {
  border-color: rgba(153, 27, 27, var(--tw-border-opacity));
}

.dark .hover\:border-red-100:hover.nightwind-prevent {
  border-color: rgba(254, 226, 226, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-100:hover {
  border-color: rgba(254, 226, 226, var(--tw-border-opacity));
}

.dark .border-red-200 {
  border-color: rgba(185, 28, 28, var(--tw-border-opacity));
}

.dark .border-red-200.nightwind-prevent {
  border-color: rgba(254, 202, 202, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-200 {
  border-color: rgba(254, 202, 202, var(--tw-border-opacity));
}

.dark .hover\:border-red-200:hover {
  border-color: rgba(185, 28, 28, var(--tw-border-opacity));
}

.dark .hover\:border-red-200:hover.nightwind-prevent {
  border-color: rgba(254, 202, 202, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-200:hover {
  border-color: rgba(254, 202, 202, var(--tw-border-opacity));
}

.dark .border-red-300 {
  border-color: rgba(220, 38, 38, var(--tw-border-opacity));
}

.dark .border-red-300.nightwind-prevent {
  border-color: rgba(252, 165, 165, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-300 {
  border-color: rgba(252, 165, 165, var(--tw-border-opacity));
}

.dark .hover\:border-red-300:hover {
  border-color: rgba(220, 38, 38, var(--tw-border-opacity));
}

.dark .hover\:border-red-300:hover.nightwind-prevent {
  border-color: rgba(252, 165, 165, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-300:hover {
  border-color: rgba(252, 165, 165, var(--tw-border-opacity));
}

.dark .border-red-400 {
  border-color: rgba(239, 68, 68, var(--tw-border-opacity));
}

.dark .border-red-400.nightwind-prevent {
  border-color: rgba(248, 113, 113, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-400 {
  border-color: rgba(248, 113, 113, var(--tw-border-opacity));
}

.dark .hover\:border-red-400:hover {
  border-color: rgba(239, 68, 68, var(--tw-border-opacity));
}

.dark .hover\:border-red-400:hover.nightwind-prevent {
  border-color: rgba(248, 113, 113, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-400:hover {
  border-color: rgba(248, 113, 113, var(--tw-border-opacity));
}

.dark .border-red-500 {
  border-color: rgba(248, 113, 113, var(--tw-border-opacity));
}

.dark .border-red-500.nightwind-prevent {
  border-color: rgba(239, 68, 68, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-500 {
  border-color: rgba(239, 68, 68, var(--tw-border-opacity));
}

.dark .hover\:border-red-500:hover {
  border-color: rgba(248, 113, 113, var(--tw-border-opacity));
}

.dark .hover\:border-red-500:hover.nightwind-prevent {
  border-color: rgba(239, 68, 68, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-500:hover {
  border-color: rgba(239, 68, 68, var(--tw-border-opacity));
}

.dark .border-red-600 {
  border-color: rgba(252, 165, 165, var(--tw-border-opacity));
}

.dark .border-red-600.nightwind-prevent {
  border-color: rgba(220, 38, 38, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-600 {
  border-color: rgba(220, 38, 38, var(--tw-border-opacity));
}

.dark .hover\:border-red-600:hover {
  border-color: rgba(252, 165, 165, var(--tw-border-opacity));
}

.dark .hover\:border-red-600:hover.nightwind-prevent {
  border-color: rgba(220, 38, 38, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-600:hover {
  border-color: rgba(220, 38, 38, var(--tw-border-opacity));
}

.dark .border-red-700 {
  border-color: rgba(254, 202, 202, var(--tw-border-opacity));
}

.dark .border-red-700.nightwind-prevent {
  border-color: rgba(185, 28, 28, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-700 {
  border-color: rgba(185, 28, 28, var(--tw-border-opacity));
}

.dark .hover\:border-red-700:hover {
  border-color: rgba(254, 202, 202, var(--tw-border-opacity));
}

.dark .hover\:border-red-700:hover.nightwind-prevent {
  border-color: rgba(185, 28, 28, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-700:hover {
  border-color: rgba(185, 28, 28, var(--tw-border-opacity));
}

.dark .border-red-800 {
  border-color: rgba(254, 226, 226, var(--tw-border-opacity));
}

.dark .border-red-800.nightwind-prevent {
  border-color: rgba(153, 27, 27, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-800 {
  border-color: rgba(153, 27, 27, var(--tw-border-opacity));
}

.dark .hover\:border-red-800:hover {
  border-color: rgba(254, 226, 226, var(--tw-border-opacity));
}

.dark .hover\:border-red-800:hover.nightwind-prevent {
  border-color: rgba(153, 27, 27, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-800:hover {
  border-color: rgba(153, 27, 27, var(--tw-border-opacity));
}

.dark .border-red-900 {
  border-color: rgba(254, 242, 242, var(--tw-border-opacity));
}

.dark .border-red-900.nightwind-prevent {
  border-color: rgba(127, 29, 29, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-red-900 {
  border-color: rgba(127, 29, 29, var(--tw-border-opacity));
}

.dark .hover\:border-red-900:hover {
  border-color: rgba(254, 242, 242, var(--tw-border-opacity));
}

.dark .hover\:border-red-900:hover.nightwind-prevent {
  border-color: rgba(127, 29, 29, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-red-900:hover {
  border-color: rgba(127, 29, 29, var(--tw-border-opacity));
}

.dark .border-orange-50 {
  border-color: rgba(124, 45, 18, var(--tw-border-opacity));
}

.dark .border-orange-50.nightwind-prevent {
  border-color: rgba(255, 247, 237, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-50 {
  border-color: rgba(255, 247, 237, var(--tw-border-opacity));
}

.dark .hover\:border-orange-50:hover {
  border-color: rgba(124, 45, 18, var(--tw-border-opacity));
}

.dark .hover\:border-orange-50:hover.nightwind-prevent {
  border-color: rgba(255, 247, 237, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-50:hover {
  border-color: rgba(255, 247, 237, var(--tw-border-opacity));
}

.dark .border-orange-100 {
  border-color: rgba(154, 52, 18, var(--tw-border-opacity));
}

.dark .border-orange-100.nightwind-prevent {
  border-color: rgba(255, 237, 213, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-100 {
  border-color: rgba(255, 237, 213, var(--tw-border-opacity));
}

.dark .hover\:border-orange-100:hover {
  border-color: rgba(154, 52, 18, var(--tw-border-opacity));
}

.dark .hover\:border-orange-100:hover.nightwind-prevent {
  border-color: rgba(255, 237, 213, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-100:hover {
  border-color: rgba(255, 237, 213, var(--tw-border-opacity));
}

.dark .border-orange-200 {
  border-color: rgba(194, 65, 12, var(--tw-border-opacity));
}

.dark .border-orange-200.nightwind-prevent {
  border-color: rgba(254, 215, 170, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-200 {
  border-color: rgba(254, 215, 170, var(--tw-border-opacity));
}

.dark .hover\:border-orange-200:hover {
  border-color: rgba(194, 65, 12, var(--tw-border-opacity));
}

.dark .hover\:border-orange-200:hover.nightwind-prevent {
  border-color: rgba(254, 215, 170, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-200:hover {
  border-color: rgba(254, 215, 170, var(--tw-border-opacity));
}

.dark .border-orange-300 {
  border-color: rgba(234, 88, 12, var(--tw-border-opacity));
}

.dark .border-orange-300.nightwind-prevent {
  border-color: rgba(253, 186, 116, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-300 {
  border-color: rgba(253, 186, 116, var(--tw-border-opacity));
}

.dark .hover\:border-orange-300:hover {
  border-color: rgba(234, 88, 12, var(--tw-border-opacity));
}

.dark .hover\:border-orange-300:hover.nightwind-prevent {
  border-color: rgba(253, 186, 116, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-300:hover {
  border-color: rgba(253, 186, 116, var(--tw-border-opacity));
}

.dark .border-orange-400 {
  border-color: rgba(249, 115, 22, var(--tw-border-opacity));
}

.dark .border-orange-400.nightwind-prevent {
  border-color: rgba(251, 146, 60, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-400 {
  border-color: rgba(251, 146, 60, var(--tw-border-opacity));
}

.dark .hover\:border-orange-400:hover {
  border-color: rgba(249, 115, 22, var(--tw-border-opacity));
}

.dark .hover\:border-orange-400:hover.nightwind-prevent {
  border-color: rgba(251, 146, 60, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-400:hover {
  border-color: rgba(251, 146, 60, var(--tw-border-opacity));
}

.dark .border-orange-500 {
  border-color: rgba(251, 146, 60, var(--tw-border-opacity));
}

.dark .border-orange-500.nightwind-prevent {
  border-color: rgba(249, 115, 22, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-500 {
  border-color: rgba(249, 115, 22, var(--tw-border-opacity));
}

.dark .hover\:border-orange-500:hover {
  border-color: rgba(251, 146, 60, var(--tw-border-opacity));
}

.dark .hover\:border-orange-500:hover.nightwind-prevent {
  border-color: rgba(249, 115, 22, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-500:hover {
  border-color: rgba(249, 115, 22, var(--tw-border-opacity));
}

.dark .border-orange-600 {
  border-color: rgba(253, 186, 116, var(--tw-border-opacity));
}

.dark .border-orange-600.nightwind-prevent {
  border-color: rgba(234, 88, 12, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-600 {
  border-color: rgba(234, 88, 12, var(--tw-border-opacity));
}

.dark .hover\:border-orange-600:hover {
  border-color: rgba(253, 186, 116, var(--tw-border-opacity));
}

.dark .hover\:border-orange-600:hover.nightwind-prevent {
  border-color: rgba(234, 88, 12, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-600:hover {
  border-color: rgba(234, 88, 12, var(--tw-border-opacity));
}

.dark .border-orange-700 {
  border-color: rgba(254, 215, 170, var(--tw-border-opacity));
}

.dark .border-orange-700.nightwind-prevent {
  border-color: rgba(194, 65, 12, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-700 {
  border-color: rgba(194, 65, 12, var(--tw-border-opacity));
}

.dark .hover\:border-orange-700:hover {
  border-color: rgba(254, 215, 170, var(--tw-border-opacity));
}

.dark .hover\:border-orange-700:hover.nightwind-prevent {
  border-color: rgba(194, 65, 12, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-700:hover {
  border-color: rgba(194, 65, 12, var(--tw-border-opacity));
}

.dark .border-orange-800 {
  border-color: rgba(255, 237, 213, var(--tw-border-opacity));
}

.dark .border-orange-800.nightwind-prevent {
  border-color: rgba(154, 52, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-800 {
  border-color: rgba(154, 52, 18, var(--tw-border-opacity));
}

.dark .hover\:border-orange-800:hover {
  border-color: rgba(255, 237, 213, var(--tw-border-opacity));
}

.dark .hover\:border-orange-800:hover.nightwind-prevent {
  border-color: rgba(154, 52, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-800:hover {
  border-color: rgba(154, 52, 18, var(--tw-border-opacity));
}

.dark .border-orange-900 {
  border-color: rgba(255, 247, 237, var(--tw-border-opacity));
}

.dark .border-orange-900.nightwind-prevent {
  border-color: rgba(124, 45, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-orange-900 {
  border-color: rgba(124, 45, 18, var(--tw-border-opacity));
}

.dark .hover\:border-orange-900:hover {
  border-color: rgba(255, 247, 237, var(--tw-border-opacity));
}

.dark .hover\:border-orange-900:hover.nightwind-prevent {
  border-color: rgba(124, 45, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-orange-900:hover {
  border-color: rgba(124, 45, 18, var(--tw-border-opacity));
}

.dark .border-amber-50 {
  border-color: rgba(120, 53, 15, var(--tw-border-opacity));
}

.dark .border-amber-50.nightwind-prevent {
  border-color: rgba(255, 251, 235, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-50 {
  border-color: rgba(255, 251, 235, var(--tw-border-opacity));
}

.dark .hover\:border-amber-50:hover {
  border-color: rgba(120, 53, 15, var(--tw-border-opacity));
}

.dark .hover\:border-amber-50:hover.nightwind-prevent {
  border-color: rgba(255, 251, 235, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-50:hover {
  border-color: rgba(255, 251, 235, var(--tw-border-opacity));
}

.dark .border-amber-100 {
  border-color: rgba(146, 64, 14, var(--tw-border-opacity));
}

.dark .border-amber-100.nightwind-prevent {
  border-color: rgba(254, 243, 199, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-100 {
  border-color: rgba(254, 243, 199, var(--tw-border-opacity));
}

.dark .hover\:border-amber-100:hover {
  border-color: rgba(146, 64, 14, var(--tw-border-opacity));
}

.dark .hover\:border-amber-100:hover.nightwind-prevent {
  border-color: rgba(254, 243, 199, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-100:hover {
  border-color: rgba(254, 243, 199, var(--tw-border-opacity));
}

.dark .border-amber-200 {
  border-color: rgba(180, 83, 9, var(--tw-border-opacity));
}

.dark .border-amber-200.nightwind-prevent {
  border-color: rgba(253, 230, 138, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-200 {
  border-color: rgba(253, 230, 138, var(--tw-border-opacity));
}

.dark .hover\:border-amber-200:hover {
  border-color: rgba(180, 83, 9, var(--tw-border-opacity));
}

.dark .hover\:border-amber-200:hover.nightwind-prevent {
  border-color: rgba(253, 230, 138, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-200:hover {
  border-color: rgba(253, 230, 138, var(--tw-border-opacity));
}

.dark .border-amber-300 {
  border-color: rgba(217, 119, 6, var(--tw-border-opacity));
}

.dark .border-amber-300.nightwind-prevent {
  border-color: rgba(252, 211, 77, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-300 {
  border-color: rgba(252, 211, 77, var(--tw-border-opacity));
}

.dark .hover\:border-amber-300:hover {
  border-color: rgba(217, 119, 6, var(--tw-border-opacity));
}

.dark .hover\:border-amber-300:hover.nightwind-prevent {
  border-color: rgba(252, 211, 77, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-300:hover {
  border-color: rgba(252, 211, 77, var(--tw-border-opacity));
}

.dark .border-amber-400 {
  border-color: rgba(245, 158, 11, var(--tw-border-opacity));
}

.dark .border-amber-400.nightwind-prevent {
  border-color: rgba(251, 191, 36, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-400 {
  border-color: rgba(251, 191, 36, var(--tw-border-opacity));
}

.dark .hover\:border-amber-400:hover {
  border-color: rgba(245, 158, 11, var(--tw-border-opacity));
}

.dark .hover\:border-amber-400:hover.nightwind-prevent {
  border-color: rgba(251, 191, 36, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-400:hover {
  border-color: rgba(251, 191, 36, var(--tw-border-opacity));
}

.dark .border-amber-500 {
  border-color: rgba(251, 191, 36, var(--tw-border-opacity));
}

.dark .border-amber-500.nightwind-prevent {
  border-color: rgba(245, 158, 11, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-500 {
  border-color: rgba(245, 158, 11, var(--tw-border-opacity));
}

.dark .hover\:border-amber-500:hover {
  border-color: rgba(251, 191, 36, var(--tw-border-opacity));
}

.dark .hover\:border-amber-500:hover.nightwind-prevent {
  border-color: rgba(245, 158, 11, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-500:hover {
  border-color: rgba(245, 158, 11, var(--tw-border-opacity));
}

.dark .border-amber-600 {
  border-color: rgba(252, 211, 77, var(--tw-border-opacity));
}

.dark .border-amber-600.nightwind-prevent {
  border-color: rgba(217, 119, 6, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-600 {
  border-color: rgba(217, 119, 6, var(--tw-border-opacity));
}

.dark .hover\:border-amber-600:hover {
  border-color: rgba(252, 211, 77, var(--tw-border-opacity));
}

.dark .hover\:border-amber-600:hover.nightwind-prevent {
  border-color: rgba(217, 119, 6, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-600:hover {
  border-color: rgba(217, 119, 6, var(--tw-border-opacity));
}

.dark .border-amber-700 {
  border-color: rgba(253, 230, 138, var(--tw-border-opacity));
}

.dark .border-amber-700.nightwind-prevent {
  border-color: rgba(180, 83, 9, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-700 {
  border-color: rgba(180, 83, 9, var(--tw-border-opacity));
}

.dark .hover\:border-amber-700:hover {
  border-color: rgba(253, 230, 138, var(--tw-border-opacity));
}

.dark .hover\:border-amber-700:hover.nightwind-prevent {
  border-color: rgba(180, 83, 9, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-700:hover {
  border-color: rgba(180, 83, 9, var(--tw-border-opacity));
}

.dark .border-amber-800 {
  border-color: rgba(254, 243, 199, var(--tw-border-opacity));
}

.dark .border-amber-800.nightwind-prevent {
  border-color: rgba(146, 64, 14, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-800 {
  border-color: rgba(146, 64, 14, var(--tw-border-opacity));
}

.dark .hover\:border-amber-800:hover {
  border-color: rgba(254, 243, 199, var(--tw-border-opacity));
}

.dark .hover\:border-amber-800:hover.nightwind-prevent {
  border-color: rgba(146, 64, 14, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-800:hover {
  border-color: rgba(146, 64, 14, var(--tw-border-opacity));
}

.dark .border-amber-900 {
  border-color: rgba(255, 251, 235, var(--tw-border-opacity));
}

.dark .border-amber-900.nightwind-prevent {
  border-color: rgba(120, 53, 15, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-amber-900 {
  border-color: rgba(120, 53, 15, var(--tw-border-opacity));
}

.dark .hover\:border-amber-900:hover {
  border-color: rgba(255, 251, 235, var(--tw-border-opacity));
}

.dark .hover\:border-amber-900:hover.nightwind-prevent {
  border-color: rgba(120, 53, 15, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-amber-900:hover {
  border-color: rgba(120, 53, 15, var(--tw-border-opacity));
}

.dark .border-yellow-50 {
  border-color: rgba(113, 63, 18, var(--tw-border-opacity));
}

.dark .border-yellow-50.nightwind-prevent {
  border-color: rgba(254, 252, 232, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-50 {
  border-color: rgba(254, 252, 232, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-50:hover {
  border-color: rgba(113, 63, 18, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-50:hover.nightwind-prevent {
  border-color: rgba(254, 252, 232, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-50:hover {
  border-color: rgba(254, 252, 232, var(--tw-border-opacity));
}

.dark .border-yellow-100 {
  border-color: rgba(133, 77, 14, var(--tw-border-opacity));
}

.dark .border-yellow-100.nightwind-prevent {
  border-color: rgba(254, 249, 195, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-100 {
  border-color: rgba(254, 249, 195, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-100:hover {
  border-color: rgba(133, 77, 14, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-100:hover.nightwind-prevent {
  border-color: rgba(254, 249, 195, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-100:hover {
  border-color: rgba(254, 249, 195, var(--tw-border-opacity));
}

.dark .border-yellow-200 {
  border-color: rgba(161, 98, 7, var(--tw-border-opacity));
}

.dark .border-yellow-200.nightwind-prevent {
  border-color: rgba(254, 240, 138, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-200 {
  border-color: rgba(254, 240, 138, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-200:hover {
  border-color: rgba(161, 98, 7, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-200:hover.nightwind-prevent {
  border-color: rgba(254, 240, 138, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-200:hover {
  border-color: rgba(254, 240, 138, var(--tw-border-opacity));
}

.dark .border-yellow-300 {
  border-color: rgba(202, 138, 4, var(--tw-border-opacity));
}

.dark .border-yellow-300.nightwind-prevent {
  border-color: rgba(253, 224, 71, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-300 {
  border-color: rgba(253, 224, 71, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-300:hover {
  border-color: rgba(202, 138, 4, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-300:hover.nightwind-prevent {
  border-color: rgba(253, 224, 71, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-300:hover {
  border-color: rgba(253, 224, 71, var(--tw-border-opacity));
}

.dark .border-yellow-400 {
  border-color: rgba(234, 179, 8, var(--tw-border-opacity));
}

.dark .border-yellow-400.nightwind-prevent {
  border-color: rgba(250, 204, 21, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-400 {
  border-color: rgba(250, 204, 21, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-400:hover {
  border-color: rgba(234, 179, 8, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-400:hover.nightwind-prevent {
  border-color: rgba(250, 204, 21, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-400:hover {
  border-color: rgba(250, 204, 21, var(--tw-border-opacity));
}

.dark .border-yellow-500 {
  border-color: rgba(250, 204, 21, var(--tw-border-opacity));
}

.dark .border-yellow-500.nightwind-prevent {
  border-color: rgba(234, 179, 8, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-500 {
  border-color: rgba(234, 179, 8, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-500:hover {
  border-color: rgba(250, 204, 21, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-500:hover.nightwind-prevent {
  border-color: rgba(234, 179, 8, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-500:hover {
  border-color: rgba(234, 179, 8, var(--tw-border-opacity));
}

.dark .border-yellow-600 {
  border-color: rgba(253, 224, 71, var(--tw-border-opacity));
}

.dark .border-yellow-600.nightwind-prevent {
  border-color: rgba(202, 138, 4, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-600 {
  border-color: rgba(202, 138, 4, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-600:hover {
  border-color: rgba(253, 224, 71, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-600:hover.nightwind-prevent {
  border-color: rgba(202, 138, 4, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-600:hover {
  border-color: rgba(202, 138, 4, var(--tw-border-opacity));
}

.dark .border-yellow-700 {
  border-color: rgba(254, 240, 138, var(--tw-border-opacity));
}

.dark .border-yellow-700.nightwind-prevent {
  border-color: rgba(161, 98, 7, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-700 {
  border-color: rgba(161, 98, 7, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-700:hover {
  border-color: rgba(254, 240, 138, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-700:hover.nightwind-prevent {
  border-color: rgba(161, 98, 7, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-700:hover {
  border-color: rgba(161, 98, 7, var(--tw-border-opacity));
}

.dark .border-yellow-800 {
  border-color: rgba(254, 249, 195, var(--tw-border-opacity));
}

.dark .border-yellow-800.nightwind-prevent {
  border-color: rgba(133, 77, 14, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-800 {
  border-color: rgba(133, 77, 14, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-800:hover {
  border-color: rgba(254, 249, 195, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-800:hover.nightwind-prevent {
  border-color: rgba(133, 77, 14, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-800:hover {
  border-color: rgba(133, 77, 14, var(--tw-border-opacity));
}

.dark .border-yellow-900 {
  border-color: rgba(254, 252, 232, var(--tw-border-opacity));
}

.dark .border-yellow-900.nightwind-prevent {
  border-color: rgba(113, 63, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-yellow-900 {
  border-color: rgba(113, 63, 18, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-900:hover {
  border-color: rgba(254, 252, 232, var(--tw-border-opacity));
}

.dark .hover\:border-yellow-900:hover.nightwind-prevent {
  border-color: rgba(113, 63, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-yellow-900:hover {
  border-color: rgba(113, 63, 18, var(--tw-border-opacity));
}

.dark .border-lime-50 {
  border-color: rgba(54, 83, 20, var(--tw-border-opacity));
}

.dark .border-lime-50.nightwind-prevent {
  border-color: rgba(247, 254, 231, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-50 {
  border-color: rgba(247, 254, 231, var(--tw-border-opacity));
}

.dark .hover\:border-lime-50:hover {
  border-color: rgba(54, 83, 20, var(--tw-border-opacity));
}

.dark .hover\:border-lime-50:hover.nightwind-prevent {
  border-color: rgba(247, 254, 231, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-50:hover {
  border-color: rgba(247, 254, 231, var(--tw-border-opacity));
}

.dark .border-lime-100 {
  border-color: rgba(63, 98, 18, var(--tw-border-opacity));
}

.dark .border-lime-100.nightwind-prevent {
  border-color: rgba(236, 252, 203, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-100 {
  border-color: rgba(236, 252, 203, var(--tw-border-opacity));
}

.dark .hover\:border-lime-100:hover {
  border-color: rgba(63, 98, 18, var(--tw-border-opacity));
}

.dark .hover\:border-lime-100:hover.nightwind-prevent {
  border-color: rgba(236, 252, 203, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-100:hover {
  border-color: rgba(236, 252, 203, var(--tw-border-opacity));
}

.dark .border-lime-200 {
  border-color: rgba(77, 124, 15, var(--tw-border-opacity));
}

.dark .border-lime-200.nightwind-prevent {
  border-color: rgba(217, 249, 157, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-200 {
  border-color: rgba(217, 249, 157, var(--tw-border-opacity));
}

.dark .hover\:border-lime-200:hover {
  border-color: rgba(77, 124, 15, var(--tw-border-opacity));
}

.dark .hover\:border-lime-200:hover.nightwind-prevent {
  border-color: rgba(217, 249, 157, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-200:hover {
  border-color: rgba(217, 249, 157, var(--tw-border-opacity));
}

.dark .border-lime-300 {
  border-color: rgba(101, 163, 13, var(--tw-border-opacity));
}

.dark .border-lime-300.nightwind-prevent {
  border-color: rgba(190, 242, 100, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-300 {
  border-color: rgba(190, 242, 100, var(--tw-border-opacity));
}

.dark .hover\:border-lime-300:hover {
  border-color: rgba(101, 163, 13, var(--tw-border-opacity));
}

.dark .hover\:border-lime-300:hover.nightwind-prevent {
  border-color: rgba(190, 242, 100, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-300:hover {
  border-color: rgba(190, 242, 100, var(--tw-border-opacity));
}

.dark .border-lime-400 {
  border-color: rgba(132, 204, 22, var(--tw-border-opacity));
}

.dark .border-lime-400.nightwind-prevent {
  border-color: rgba(163, 230, 53, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-400 {
  border-color: rgba(163, 230, 53, var(--tw-border-opacity));
}

.dark .hover\:border-lime-400:hover {
  border-color: rgba(132, 204, 22, var(--tw-border-opacity));
}

.dark .hover\:border-lime-400:hover.nightwind-prevent {
  border-color: rgba(163, 230, 53, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-400:hover {
  border-color: rgba(163, 230, 53, var(--tw-border-opacity));
}

.dark .border-lime-500 {
  border-color: rgba(163, 230, 53, var(--tw-border-opacity));
}

.dark .border-lime-500.nightwind-prevent {
  border-color: rgba(132, 204, 22, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-500 {
  border-color: rgba(132, 204, 22, var(--tw-border-opacity));
}

.dark .hover\:border-lime-500:hover {
  border-color: rgba(163, 230, 53, var(--tw-border-opacity));
}

.dark .hover\:border-lime-500:hover.nightwind-prevent {
  border-color: rgba(132, 204, 22, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-500:hover {
  border-color: rgba(132, 204, 22, var(--tw-border-opacity));
}

.dark .border-lime-600 {
  border-color: rgba(190, 242, 100, var(--tw-border-opacity));
}

.dark .border-lime-600.nightwind-prevent {
  border-color: rgba(101, 163, 13, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-600 {
  border-color: rgba(101, 163, 13, var(--tw-border-opacity));
}

.dark .hover\:border-lime-600:hover {
  border-color: rgba(190, 242, 100, var(--tw-border-opacity));
}

.dark .hover\:border-lime-600:hover.nightwind-prevent {
  border-color: rgba(101, 163, 13, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-600:hover {
  border-color: rgba(101, 163, 13, var(--tw-border-opacity));
}

.dark .border-lime-700 {
  border-color: rgba(217, 249, 157, var(--tw-border-opacity));
}

.dark .border-lime-700.nightwind-prevent {
  border-color: rgba(77, 124, 15, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-700 {
  border-color: rgba(77, 124, 15, var(--tw-border-opacity));
}

.dark .hover\:border-lime-700:hover {
  border-color: rgba(217, 249, 157, var(--tw-border-opacity));
}

.dark .hover\:border-lime-700:hover.nightwind-prevent {
  border-color: rgba(77, 124, 15, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-700:hover {
  border-color: rgba(77, 124, 15, var(--tw-border-opacity));
}

.dark .border-lime-800 {
  border-color: rgba(236, 252, 203, var(--tw-border-opacity));
}

.dark .border-lime-800.nightwind-prevent {
  border-color: rgba(63, 98, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-800 {
  border-color: rgba(63, 98, 18, var(--tw-border-opacity));
}

.dark .hover\:border-lime-800:hover {
  border-color: rgba(236, 252, 203, var(--tw-border-opacity));
}

.dark .hover\:border-lime-800:hover.nightwind-prevent {
  border-color: rgba(63, 98, 18, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-800:hover {
  border-color: rgba(63, 98, 18, var(--tw-border-opacity));
}

.dark .border-lime-900 {
  border-color: rgba(247, 254, 231, var(--tw-border-opacity));
}

.dark .border-lime-900.nightwind-prevent {
  border-color: rgba(54, 83, 20, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-lime-900 {
  border-color: rgba(54, 83, 20, var(--tw-border-opacity));
}

.dark .hover\:border-lime-900:hover {
  border-color: rgba(247, 254, 231, var(--tw-border-opacity));
}

.dark .hover\:border-lime-900:hover.nightwind-prevent {
  border-color: rgba(54, 83, 20, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-lime-900:hover {
  border-color: rgba(54, 83, 20, var(--tw-border-opacity));
}

.dark .border-green-50 {
  border-color: rgba(20, 83, 45, var(--tw-border-opacity));
}

.dark .border-green-50.nightwind-prevent {
  border-color: rgba(240, 253, 244, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-50 {
  border-color: rgba(240, 253, 244, var(--tw-border-opacity));
}

.dark .hover\:border-green-50:hover {
  border-color: rgba(20, 83, 45, var(--tw-border-opacity));
}

.dark .hover\:border-green-50:hover.nightwind-prevent {
  border-color: rgba(240, 253, 244, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-50:hover {
  border-color: rgba(240, 253, 244, var(--tw-border-opacity));
}

.dark .border-green-100 {
  border-color: rgba(22, 101, 52, var(--tw-border-opacity));
}

.dark .border-green-100.nightwind-prevent {
  border-color: rgba(220, 252, 231, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-100 {
  border-color: rgba(220, 252, 231, var(--tw-border-opacity));
}

.dark .hover\:border-green-100:hover {
  border-color: rgba(22, 101, 52, var(--tw-border-opacity));
}

.dark .hover\:border-green-100:hover.nightwind-prevent {
  border-color: rgba(220, 252, 231, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-100:hover {
  border-color: rgba(220, 252, 231, var(--tw-border-opacity));
}

.dark .border-green-200 {
  border-color: rgba(21, 128, 61, var(--tw-border-opacity));
}

.dark .border-green-200.nightwind-prevent {
  border-color: rgba(187, 247, 208, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-200 {
  border-color: rgba(187, 247, 208, var(--tw-border-opacity));
}

.dark .hover\:border-green-200:hover {
  border-color: rgba(21, 128, 61, var(--tw-border-opacity));
}

.dark .hover\:border-green-200:hover.nightwind-prevent {
  border-color: rgba(187, 247, 208, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-200:hover {
  border-color: rgba(187, 247, 208, var(--tw-border-opacity));
}

.dark .border-green-300 {
  border-color: rgba(22, 163, 74, var(--tw-border-opacity));
}

.dark .border-green-300.nightwind-prevent {
  border-color: rgba(134, 239, 172, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-300 {
  border-color: rgba(134, 239, 172, var(--tw-border-opacity));
}

.dark .hover\:border-green-300:hover {
  border-color: rgba(22, 163, 74, var(--tw-border-opacity));
}

.dark .hover\:border-green-300:hover.nightwind-prevent {
  border-color: rgba(134, 239, 172, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-300:hover {
  border-color: rgba(134, 239, 172, var(--tw-border-opacity));
}

.dark .border-green-400 {
  border-color: rgba(34, 197, 94, var(--tw-border-opacity));
}

.dark .border-green-400.nightwind-prevent {
  border-color: rgba(74, 222, 128, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-400 {
  border-color: rgba(74, 222, 128, var(--tw-border-opacity));
}

.dark .hover\:border-green-400:hover {
  border-color: rgba(34, 197, 94, var(--tw-border-opacity));
}

.dark .hover\:border-green-400:hover.nightwind-prevent {
  border-color: rgba(74, 222, 128, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-400:hover {
  border-color: rgba(74, 222, 128, var(--tw-border-opacity));
}

.dark .border-green-500 {
  border-color: rgba(74, 222, 128, var(--tw-border-opacity));
}

.dark .border-green-500.nightwind-prevent {
  border-color: rgba(34, 197, 94, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-500 {
  border-color: rgba(34, 197, 94, var(--tw-border-opacity));
}

.dark .hover\:border-green-500:hover {
  border-color: rgba(74, 222, 128, var(--tw-border-opacity));
}

.dark .hover\:border-green-500:hover.nightwind-prevent {
  border-color: rgba(34, 197, 94, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-500:hover {
  border-color: rgba(34, 197, 94, var(--tw-border-opacity));
}

.dark .border-green-600 {
  border-color: rgba(134, 239, 172, var(--tw-border-opacity));
}

.dark .border-green-600.nightwind-prevent {
  border-color: rgba(22, 163, 74, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-600 {
  border-color: rgba(22, 163, 74, var(--tw-border-opacity));
}

.dark .hover\:border-green-600:hover {
  border-color: rgba(134, 239, 172, var(--tw-border-opacity));
}

.dark .hover\:border-green-600:hover.nightwind-prevent {
  border-color: rgba(22, 163, 74, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-600:hover {
  border-color: rgba(22, 163, 74, var(--tw-border-opacity));
}

.dark .border-green-700 {
  border-color: rgba(187, 247, 208, var(--tw-border-opacity));
}

.dark .border-green-700.nightwind-prevent {
  border-color: rgba(21, 128, 61, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-700 {
  border-color: rgba(21, 128, 61, var(--tw-border-opacity));
}

.dark .hover\:border-green-700:hover {
  border-color: rgba(187, 247, 208, var(--tw-border-opacity));
}

.dark .hover\:border-green-700:hover.nightwind-prevent {
  border-color: rgba(21, 128, 61, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-700:hover {
  border-color: rgba(21, 128, 61, var(--tw-border-opacity));
}

.dark .border-green-800 {
  border-color: rgba(220, 252, 231, var(--tw-border-opacity));
}

.dark .border-green-800.nightwind-prevent {
  border-color: rgba(22, 101, 52, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-800 {
  border-color: rgba(22, 101, 52, var(--tw-border-opacity));
}

.dark .hover\:border-green-800:hover {
  border-color: rgba(220, 252, 231, var(--tw-border-opacity));
}

.dark .hover\:border-green-800:hover.nightwind-prevent {
  border-color: rgba(22, 101, 52, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-800:hover {
  border-color: rgba(22, 101, 52, var(--tw-border-opacity));
}

.dark .border-green-900 {
  border-color: rgba(240, 253, 244, var(--tw-border-opacity));
}

.dark .border-green-900.nightwind-prevent {
  border-color: rgba(20, 83, 45, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-green-900 {
  border-color: rgba(20, 83, 45, var(--tw-border-opacity));
}

.dark .hover\:border-green-900:hover {
  border-color: rgba(240, 253, 244, var(--tw-border-opacity));
}

.dark .hover\:border-green-900:hover.nightwind-prevent {
  border-color: rgba(20, 83, 45, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-green-900:hover {
  border-color: rgba(20, 83, 45, var(--tw-border-opacity));
}

.dark .border-emerald-50 {
  border-color: rgba(6, 78, 59, var(--tw-border-opacity));
}

.dark .border-emerald-50.nightwind-prevent {
  border-color: rgba(236, 253, 245, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-50 {
  border-color: rgba(236, 253, 245, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-50:hover {
  border-color: rgba(6, 78, 59, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-50:hover.nightwind-prevent {
  border-color: rgba(236, 253, 245, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-50:hover {
  border-color: rgba(236, 253, 245, var(--tw-border-opacity));
}

.dark .border-emerald-100 {
  border-color: rgba(6, 95, 70, var(--tw-border-opacity));
}

.dark .border-emerald-100.nightwind-prevent {
  border-color: rgba(209, 250, 229, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-100 {
  border-color: rgba(209, 250, 229, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-100:hover {
  border-color: rgba(6, 95, 70, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-100:hover.nightwind-prevent {
  border-color: rgba(209, 250, 229, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-100:hover {
  border-color: rgba(209, 250, 229, var(--tw-border-opacity));
}

.dark .border-emerald-200 {
  border-color: rgba(4, 120, 87, var(--tw-border-opacity));
}

.dark .border-emerald-200.nightwind-prevent {
  border-color: rgba(167, 243, 208, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-200 {
  border-color: rgba(167, 243, 208, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-200:hover {
  border-color: rgba(4, 120, 87, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-200:hover.nightwind-prevent {
  border-color: rgba(167, 243, 208, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-200:hover {
  border-color: rgba(167, 243, 208, var(--tw-border-opacity));
}

.dark .border-emerald-300 {
  border-color: rgba(5, 150, 105, var(--tw-border-opacity));
}

.dark .border-emerald-300.nightwind-prevent {
  border-color: rgba(110, 231, 183, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-300 {
  border-color: rgba(110, 231, 183, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-300:hover {
  border-color: rgba(5, 150, 105, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-300:hover.nightwind-prevent {
  border-color: rgba(110, 231, 183, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-300:hover {
  border-color: rgba(110, 231, 183, var(--tw-border-opacity));
}

.dark .border-emerald-400 {
  border-color: rgba(16, 185, 129, var(--tw-border-opacity));
}

.dark .border-emerald-400.nightwind-prevent {
  border-color: rgba(52, 211, 153, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-400 {
  border-color: rgba(52, 211, 153, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-400:hover {
  border-color: rgba(16, 185, 129, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-400:hover.nightwind-prevent {
  border-color: rgba(52, 211, 153, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-400:hover {
  border-color: rgba(52, 211, 153, var(--tw-border-opacity));
}

.dark .border-emerald-500 {
  border-color: rgba(52, 211, 153, var(--tw-border-opacity));
}

.dark .border-emerald-500.nightwind-prevent {
  border-color: rgba(16, 185, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-500 {
  border-color: rgba(16, 185, 129, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-500:hover {
  border-color: rgba(52, 211, 153, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-500:hover.nightwind-prevent {
  border-color: rgba(16, 185, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-500:hover {
  border-color: rgba(16, 185, 129, var(--tw-border-opacity));
}

.dark .border-emerald-600 {
  border-color: rgba(110, 231, 183, var(--tw-border-opacity));
}

.dark .border-emerald-600.nightwind-prevent {
  border-color: rgba(5, 150, 105, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-600 {
  border-color: rgba(5, 150, 105, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-600:hover {
  border-color: rgba(110, 231, 183, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-600:hover.nightwind-prevent {
  border-color: rgba(5, 150, 105, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-600:hover {
  border-color: rgba(5, 150, 105, var(--tw-border-opacity));
}

.dark .border-emerald-700 {
  border-color: rgba(167, 243, 208, var(--tw-border-opacity));
}

.dark .border-emerald-700.nightwind-prevent {
  border-color: rgba(4, 120, 87, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-700 {
  border-color: rgba(4, 120, 87, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-700:hover {
  border-color: rgba(167, 243, 208, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-700:hover.nightwind-prevent {
  border-color: rgba(4, 120, 87, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-700:hover {
  border-color: rgba(4, 120, 87, var(--tw-border-opacity));
}

.dark .border-emerald-800 {
  border-color: rgba(209, 250, 229, var(--tw-border-opacity));
}

.dark .border-emerald-800.nightwind-prevent {
  border-color: rgba(6, 95, 70, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-800 {
  border-color: rgba(6, 95, 70, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-800:hover {
  border-color: rgba(209, 250, 229, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-800:hover.nightwind-prevent {
  border-color: rgba(6, 95, 70, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-800:hover {
  border-color: rgba(6, 95, 70, var(--tw-border-opacity));
}

.dark .border-emerald-900 {
  border-color: rgba(236, 253, 245, var(--tw-border-opacity));
}

.dark .border-emerald-900.nightwind-prevent {
  border-color: rgba(6, 78, 59, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-emerald-900 {
  border-color: rgba(6, 78, 59, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-900:hover {
  border-color: rgba(236, 253, 245, var(--tw-border-opacity));
}

.dark .hover\:border-emerald-900:hover.nightwind-prevent {
  border-color: rgba(6, 78, 59, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-emerald-900:hover {
  border-color: rgba(6, 78, 59, var(--tw-border-opacity));
}

.dark .border-teal-50 {
  border-color: rgba(19, 78, 74, var(--tw-border-opacity));
}

.dark .border-teal-50.nightwind-prevent {
  border-color: rgba(240, 253, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-50 {
  border-color: rgba(240, 253, 250, var(--tw-border-opacity));
}

.dark .hover\:border-teal-50:hover {
  border-color: rgba(19, 78, 74, var(--tw-border-opacity));
}

.dark .hover\:border-teal-50:hover.nightwind-prevent {
  border-color: rgba(240, 253, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-50:hover {
  border-color: rgba(240, 253, 250, var(--tw-border-opacity));
}

.dark .border-teal-100 {
  border-color: rgba(17, 94, 89, var(--tw-border-opacity));
}

.dark .border-teal-100.nightwind-prevent {
  border-color: rgba(204, 251, 241, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-100 {
  border-color: rgba(204, 251, 241, var(--tw-border-opacity));
}

.dark .hover\:border-teal-100:hover {
  border-color: rgba(17, 94, 89, var(--tw-border-opacity));
}

.dark .hover\:border-teal-100:hover.nightwind-prevent {
  border-color: rgba(204, 251, 241, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-100:hover {
  border-color: rgba(204, 251, 241, var(--tw-border-opacity));
}

.dark .border-teal-200 {
  border-color: rgba(15, 118, 110, var(--tw-border-opacity));
}

.dark .border-teal-200.nightwind-prevent {
  border-color: rgba(153, 246, 228, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-200 {
  border-color: rgba(153, 246, 228, var(--tw-border-opacity));
}

.dark .hover\:border-teal-200:hover {
  border-color: rgba(15, 118, 110, var(--tw-border-opacity));
}

.dark .hover\:border-teal-200:hover.nightwind-prevent {
  border-color: rgba(153, 246, 228, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-200:hover {
  border-color: rgba(153, 246, 228, var(--tw-border-opacity));
}

.dark .border-teal-300 {
  border-color: rgba(13, 148, 136, var(--tw-border-opacity));
}

.dark .border-teal-300.nightwind-prevent {
  border-color: rgba(94, 234, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-300 {
  border-color: rgba(94, 234, 212, var(--tw-border-opacity));
}

.dark .hover\:border-teal-300:hover {
  border-color: rgba(13, 148, 136, var(--tw-border-opacity));
}

.dark .hover\:border-teal-300:hover.nightwind-prevent {
  border-color: rgba(94, 234, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-300:hover {
  border-color: rgba(94, 234, 212, var(--tw-border-opacity));
}

.dark .border-teal-400 {
  border-color: rgba(20, 184, 166, var(--tw-border-opacity));
}

.dark .border-teal-400.nightwind-prevent {
  border-color: rgba(45, 212, 191, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-400 {
  border-color: rgba(45, 212, 191, var(--tw-border-opacity));
}

.dark .hover\:border-teal-400:hover {
  border-color: rgba(20, 184, 166, var(--tw-border-opacity));
}

.dark .hover\:border-teal-400:hover.nightwind-prevent {
  border-color: rgba(45, 212, 191, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-400:hover {
  border-color: rgba(45, 212, 191, var(--tw-border-opacity));
}

.dark .border-teal-500 {
  border-color: rgba(45, 212, 191, var(--tw-border-opacity));
}

.dark .border-teal-500.nightwind-prevent {
  border-color: rgba(20, 184, 166, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-500 {
  border-color: rgba(20, 184, 166, var(--tw-border-opacity));
}

.dark .hover\:border-teal-500:hover {
  border-color: rgba(45, 212, 191, var(--tw-border-opacity));
}

.dark .hover\:border-teal-500:hover.nightwind-prevent {
  border-color: rgba(20, 184, 166, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-500:hover {
  border-color: rgba(20, 184, 166, var(--tw-border-opacity));
}

.dark .border-teal-600 {
  border-color: rgba(94, 234, 212, var(--tw-border-opacity));
}

.dark .border-teal-600.nightwind-prevent {
  border-color: rgba(13, 148, 136, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-600 {
  border-color: rgba(13, 148, 136, var(--tw-border-opacity));
}

.dark .hover\:border-teal-600:hover {
  border-color: rgba(94, 234, 212, var(--tw-border-opacity));
}

.dark .hover\:border-teal-600:hover.nightwind-prevent {
  border-color: rgba(13, 148, 136, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-600:hover {
  border-color: rgba(13, 148, 136, var(--tw-border-opacity));
}

.dark .border-teal-700 {
  border-color: rgba(153, 246, 228, var(--tw-border-opacity));
}

.dark .border-teal-700.nightwind-prevent {
  border-color: rgba(15, 118, 110, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-700 {
  border-color: rgba(15, 118, 110, var(--tw-border-opacity));
}

.dark .hover\:border-teal-700:hover {
  border-color: rgba(153, 246, 228, var(--tw-border-opacity));
}

.dark .hover\:border-teal-700:hover.nightwind-prevent {
  border-color: rgba(15, 118, 110, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-700:hover {
  border-color: rgba(15, 118, 110, var(--tw-border-opacity));
}

.dark .border-teal-800 {
  border-color: rgba(204, 251, 241, var(--tw-border-opacity));
}

.dark .border-teal-800.nightwind-prevent {
  border-color: rgba(17, 94, 89, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-800 {
  border-color: rgba(17, 94, 89, var(--tw-border-opacity));
}

.dark .hover\:border-teal-800:hover {
  border-color: rgba(204, 251, 241, var(--tw-border-opacity));
}

.dark .hover\:border-teal-800:hover.nightwind-prevent {
  border-color: rgba(17, 94, 89, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-800:hover {
  border-color: rgba(17, 94, 89, var(--tw-border-opacity));
}

.dark .border-teal-900 {
  border-color: rgba(240, 253, 250, var(--tw-border-opacity));
}

.dark .border-teal-900.nightwind-prevent {
  border-color: rgba(19, 78, 74, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-teal-900 {
  border-color: rgba(19, 78, 74, var(--tw-border-opacity));
}

.dark .hover\:border-teal-900:hover {
  border-color: rgba(240, 253, 250, var(--tw-border-opacity));
}

.dark .hover\:border-teal-900:hover.nightwind-prevent {
  border-color: rgba(19, 78, 74, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-teal-900:hover {
  border-color: rgba(19, 78, 74, var(--tw-border-opacity));
}

.dark .border-cyan-50 {
  border-color: rgba(22, 78, 99, var(--tw-border-opacity));
}

.dark .border-cyan-50.nightwind-prevent {
  border-color: rgba(236, 254, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-50 {
  border-color: rgba(236, 254, 255, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-50:hover {
  border-color: rgba(22, 78, 99, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-50:hover.nightwind-prevent {
  border-color: rgba(236, 254, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-50:hover {
  border-color: rgba(236, 254, 255, var(--tw-border-opacity));
}

.dark .border-cyan-100 {
  border-color: rgba(21, 94, 117, var(--tw-border-opacity));
}

.dark .border-cyan-100.nightwind-prevent {
  border-color: rgba(207, 250, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-100 {
  border-color: rgba(207, 250, 254, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-100:hover {
  border-color: rgba(21, 94, 117, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-100:hover.nightwind-prevent {
  border-color: rgba(207, 250, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-100:hover {
  border-color: rgba(207, 250, 254, var(--tw-border-opacity));
}

.dark .border-cyan-200 {
  border-color: rgba(14, 116, 144, var(--tw-border-opacity));
}

.dark .border-cyan-200.nightwind-prevent {
  border-color: rgba(165, 243, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-200 {
  border-color: rgba(165, 243, 252, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-200:hover {
  border-color: rgba(14, 116, 144, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-200:hover.nightwind-prevent {
  border-color: rgba(165, 243, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-200:hover {
  border-color: rgba(165, 243, 252, var(--tw-border-opacity));
}

.dark .border-cyan-300 {
  border-color: rgba(8, 145, 178, var(--tw-border-opacity));
}

.dark .border-cyan-300.nightwind-prevent {
  border-color: rgba(103, 232, 249, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-300 {
  border-color: rgba(103, 232, 249, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-300:hover {
  border-color: rgba(8, 145, 178, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-300:hover.nightwind-prevent {
  border-color: rgba(103, 232, 249, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-300:hover {
  border-color: rgba(103, 232, 249, var(--tw-border-opacity));
}

.dark .border-cyan-400 {
  border-color: rgba(6, 182, 212, var(--tw-border-opacity));
}

.dark .border-cyan-400.nightwind-prevent {
  border-color: rgba(34, 211, 238, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-400 {
  border-color: rgba(34, 211, 238, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-400:hover {
  border-color: rgba(6, 182, 212, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-400:hover.nightwind-prevent {
  border-color: rgba(34, 211, 238, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-400:hover {
  border-color: rgba(34, 211, 238, var(--tw-border-opacity));
}

.dark .border-cyan-500 {
  border-color: rgba(34, 211, 238, var(--tw-border-opacity));
}

.dark .border-cyan-500.nightwind-prevent {
  border-color: rgba(6, 182, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-500 {
  border-color: rgba(6, 182, 212, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-500:hover {
  border-color: rgba(34, 211, 238, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-500:hover.nightwind-prevent {
  border-color: rgba(6, 182, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-500:hover {
  border-color: rgba(6, 182, 212, var(--tw-border-opacity));
}

.dark .border-cyan-600 {
  border-color: rgba(103, 232, 249, var(--tw-border-opacity));
}

.dark .border-cyan-600.nightwind-prevent {
  border-color: rgba(8, 145, 178, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-600 {
  border-color: rgba(8, 145, 178, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-600:hover {
  border-color: rgba(103, 232, 249, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-600:hover.nightwind-prevent {
  border-color: rgba(8, 145, 178, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-600:hover {
  border-color: rgba(8, 145, 178, var(--tw-border-opacity));
}

.dark .border-cyan-700 {
  border-color: rgba(165, 243, 252, var(--tw-border-opacity));
}

.dark .border-cyan-700.nightwind-prevent {
  border-color: rgba(14, 116, 144, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-700 {
  border-color: rgba(14, 116, 144, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-700:hover {
  border-color: rgba(165, 243, 252, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-700:hover.nightwind-prevent {
  border-color: rgba(14, 116, 144, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-700:hover {
  border-color: rgba(14, 116, 144, var(--tw-border-opacity));
}

.dark .border-cyan-800 {
  border-color: rgba(207, 250, 254, var(--tw-border-opacity));
}

.dark .border-cyan-800.nightwind-prevent {
  border-color: rgba(21, 94, 117, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-800 {
  border-color: rgba(21, 94, 117, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-800:hover {
  border-color: rgba(207, 250, 254, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-800:hover.nightwind-prevent {
  border-color: rgba(21, 94, 117, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-800:hover {
  border-color: rgba(21, 94, 117, var(--tw-border-opacity));
}

.dark .border-cyan-900 {
  border-color: rgba(236, 254, 255, var(--tw-border-opacity));
}

.dark .border-cyan-900.nightwind-prevent {
  border-color: rgba(22, 78, 99, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-cyan-900 {
  border-color: rgba(22, 78, 99, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-900:hover {
  border-color: rgba(236, 254, 255, var(--tw-border-opacity));
}

.dark .hover\:border-cyan-900:hover.nightwind-prevent {
  border-color: rgba(22, 78, 99, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-cyan-900:hover {
  border-color: rgba(22, 78, 99, var(--tw-border-opacity));
}

.dark .border-sky-50 {
  border-color: rgba(12, 74, 110, var(--tw-border-opacity));
}

.dark .border-sky-50.nightwind-prevent {
  border-color: rgba(240, 249, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-50 {
  border-color: rgba(240, 249, 255, var(--tw-border-opacity));
}

.dark .hover\:border-sky-50:hover {
  border-color: rgba(12, 74, 110, var(--tw-border-opacity));
}

.dark .hover\:border-sky-50:hover.nightwind-prevent {
  border-color: rgba(240, 249, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-50:hover {
  border-color: rgba(240, 249, 255, var(--tw-border-opacity));
}

.dark .border-sky-100 {
  border-color: rgba(7, 89, 133, var(--tw-border-opacity));
}

.dark .border-sky-100.nightwind-prevent {
  border-color: rgba(224, 242, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-100 {
  border-color: rgba(224, 242, 254, var(--tw-border-opacity));
}

.dark .hover\:border-sky-100:hover {
  border-color: rgba(7, 89, 133, var(--tw-border-opacity));
}

.dark .hover\:border-sky-100:hover.nightwind-prevent {
  border-color: rgba(224, 242, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-100:hover {
  border-color: rgba(224, 242, 254, var(--tw-border-opacity));
}

.dark .border-sky-200 {
  border-color: rgba(3, 105, 161, var(--tw-border-opacity));
}

.dark .border-sky-200.nightwind-prevent {
  border-color: rgba(186, 230, 253, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-200 {
  border-color: rgba(186, 230, 253, var(--tw-border-opacity));
}

.dark .hover\:border-sky-200:hover {
  border-color: rgba(3, 105, 161, var(--tw-border-opacity));
}

.dark .hover\:border-sky-200:hover.nightwind-prevent {
  border-color: rgba(186, 230, 253, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-200:hover {
  border-color: rgba(186, 230, 253, var(--tw-border-opacity));
}

.dark .border-sky-300 {
  border-color: rgba(2, 132, 199, var(--tw-border-opacity));
}

.dark .border-sky-300.nightwind-prevent {
  border-color: rgba(125, 211, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-300 {
  border-color: rgba(125, 211, 252, var(--tw-border-opacity));
}

.dark .hover\:border-sky-300:hover {
  border-color: rgba(2, 132, 199, var(--tw-border-opacity));
}

.dark .hover\:border-sky-300:hover.nightwind-prevent {
  border-color: rgba(125, 211, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-300:hover {
  border-color: rgba(125, 211, 252, var(--tw-border-opacity));
}

.dark .border-sky-400 {
  border-color: rgba(14, 165, 233, var(--tw-border-opacity));
}

.dark .border-sky-400.nightwind-prevent {
  border-color: rgba(56, 189, 248, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-400 {
  border-color: rgba(56, 189, 248, var(--tw-border-opacity));
}

.dark .hover\:border-sky-400:hover {
  border-color: rgba(14, 165, 233, var(--tw-border-opacity));
}

.dark .hover\:border-sky-400:hover.nightwind-prevent {
  border-color: rgba(56, 189, 248, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-400:hover {
  border-color: rgba(56, 189, 248, var(--tw-border-opacity));
}

.dark .border-sky-500 {
  border-color: rgba(56, 189, 248, var(--tw-border-opacity));
}

.dark .border-sky-500.nightwind-prevent {
  border-color: rgba(14, 165, 233, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-500 {
  border-color: rgba(14, 165, 233, var(--tw-border-opacity));
}

.dark .hover\:border-sky-500:hover {
  border-color: rgba(56, 189, 248, var(--tw-border-opacity));
}

.dark .hover\:border-sky-500:hover.nightwind-prevent {
  border-color: rgba(14, 165, 233, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-500:hover {
  border-color: rgba(14, 165, 233, var(--tw-border-opacity));
}

.dark .border-sky-600 {
  border-color: rgba(125, 211, 252, var(--tw-border-opacity));
}

.dark .border-sky-600.nightwind-prevent {
  border-color: rgba(2, 132, 199, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-600 {
  border-color: rgba(2, 132, 199, var(--tw-border-opacity));
}

.dark .hover\:border-sky-600:hover {
  border-color: rgba(125, 211, 252, var(--tw-border-opacity));
}

.dark .hover\:border-sky-600:hover.nightwind-prevent {
  border-color: rgba(2, 132, 199, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-600:hover {
  border-color: rgba(2, 132, 199, var(--tw-border-opacity));
}

.dark .border-sky-700 {
  border-color: rgba(186, 230, 253, var(--tw-border-opacity));
}

.dark .border-sky-700.nightwind-prevent {
  border-color: rgba(3, 105, 161, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-700 {
  border-color: rgba(3, 105, 161, var(--tw-border-opacity));
}

.dark .hover\:border-sky-700:hover {
  border-color: rgba(186, 230, 253, var(--tw-border-opacity));
}

.dark .hover\:border-sky-700:hover.nightwind-prevent {
  border-color: rgba(3, 105, 161, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-700:hover {
  border-color: rgba(3, 105, 161, var(--tw-border-opacity));
}

.dark .border-sky-800 {
  border-color: rgba(224, 242, 254, var(--tw-border-opacity));
}

.dark .border-sky-800.nightwind-prevent {
  border-color: rgba(7, 89, 133, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-800 {
  border-color: rgba(7, 89, 133, var(--tw-border-opacity));
}

.dark .hover\:border-sky-800:hover {
  border-color: rgba(224, 242, 254, var(--tw-border-opacity));
}

.dark .hover\:border-sky-800:hover.nightwind-prevent {
  border-color: rgba(7, 89, 133, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-800:hover {
  border-color: rgba(7, 89, 133, var(--tw-border-opacity));
}

.dark .border-sky-900 {
  border-color: rgba(240, 249, 255, var(--tw-border-opacity));
}

.dark .border-sky-900.nightwind-prevent {
  border-color: rgba(12, 74, 110, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-sky-900 {
  border-color: rgba(12, 74, 110, var(--tw-border-opacity));
}

.dark .hover\:border-sky-900:hover {
  border-color: rgba(240, 249, 255, var(--tw-border-opacity));
}

.dark .hover\:border-sky-900:hover.nightwind-prevent {
  border-color: rgba(12, 74, 110, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-sky-900:hover {
  border-color: rgba(12, 74, 110, var(--tw-border-opacity));
}

.dark .border-blue-50 {
  border-color: rgba(30, 58, 138, var(--tw-border-opacity));
}

.dark .border-blue-50.nightwind-prevent {
  border-color: rgba(239, 246, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-50 {
  border-color: rgba(239, 246, 255, var(--tw-border-opacity));
}

.dark .hover\:border-blue-50:hover {
  border-color: rgba(30, 58, 138, var(--tw-border-opacity));
}

.dark .hover\:border-blue-50:hover.nightwind-prevent {
  border-color: rgba(239, 246, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-50:hover {
  border-color: rgba(239, 246, 255, var(--tw-border-opacity));
}

.dark .border-blue-100 {
  border-color: rgba(30, 64, 175, var(--tw-border-opacity));
}

.dark .border-blue-100.nightwind-prevent {
  border-color: rgba(219, 234, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-100 {
  border-color: rgba(219, 234, 254, var(--tw-border-opacity));
}

.dark .hover\:border-blue-100:hover {
  border-color: rgba(30, 64, 175, var(--tw-border-opacity));
}

.dark .hover\:border-blue-100:hover.nightwind-prevent {
  border-color: rgba(219, 234, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-100:hover {
  border-color: rgba(219, 234, 254, var(--tw-border-opacity));
}

.dark .border-blue-200 {
  border-color: rgba(29, 78, 216, var(--tw-border-opacity));
}

.dark .border-blue-200.nightwind-prevent {
  border-color: rgba(191, 219, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-200 {
  border-color: rgba(191, 219, 254, var(--tw-border-opacity));
}

.dark .hover\:border-blue-200:hover {
  border-color: rgba(29, 78, 216, var(--tw-border-opacity));
}

.dark .hover\:border-blue-200:hover.nightwind-prevent {
  border-color: rgba(191, 219, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-200:hover {
  border-color: rgba(191, 219, 254, var(--tw-border-opacity));
}

.dark .border-blue-300 {
  border-color: rgba(37, 99, 235, var(--tw-border-opacity));
}

.dark .border-blue-300.nightwind-prevent {
  border-color: rgba(147, 197, 253, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-300 {
  border-color: rgba(147, 197, 253, var(--tw-border-opacity));
}

.dark .hover\:border-blue-300:hover {
  border-color: rgba(37, 99, 235, var(--tw-border-opacity));
}

.dark .hover\:border-blue-300:hover.nightwind-prevent {
  border-color: rgba(147, 197, 253, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-300:hover {
  border-color: rgba(147, 197, 253, var(--tw-border-opacity));
}

.dark .border-blue-400 {
  border-color: rgba(59, 130, 246, var(--tw-border-opacity));
}

.dark .border-blue-400.nightwind-prevent {
  border-color: rgba(96, 165, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-400 {
  border-color: rgba(96, 165, 250, var(--tw-border-opacity));
}

.dark .hover\:border-blue-400:hover {
  border-color: rgba(59, 130, 246, var(--tw-border-opacity));
}

.dark .hover\:border-blue-400:hover.nightwind-prevent {
  border-color: rgba(96, 165, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-400:hover {
  border-color: rgba(96, 165, 250, var(--tw-border-opacity));
}

.dark .border-blue-500 {
  border-color: rgba(96, 165, 250, var(--tw-border-opacity));
}

.dark .border-blue-500.nightwind-prevent {
  border-color: rgba(59, 130, 246, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-500 {
  border-color: rgba(59, 130, 246, var(--tw-border-opacity));
}

.dark .hover\:border-blue-500:hover {
  border-color: rgba(96, 165, 250, var(--tw-border-opacity));
}

.dark .hover\:border-blue-500:hover.nightwind-prevent {
  border-color: rgba(59, 130, 246, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-500:hover {
  border-color: rgba(59, 130, 246, var(--tw-border-opacity));
}

.dark .border-blue-600 {
  border-color: rgba(147, 197, 253, var(--tw-border-opacity));
}

.dark .border-blue-600.nightwind-prevent {
  border-color: rgba(37, 99, 235, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-600 {
  border-color: rgba(37, 99, 235, var(--tw-border-opacity));
}

.dark .hover\:border-blue-600:hover {
  border-color: rgba(147, 197, 253, var(--tw-border-opacity));
}

.dark .hover\:border-blue-600:hover.nightwind-prevent {
  border-color: rgba(37, 99, 235, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-600:hover {
  border-color: rgba(37, 99, 235, var(--tw-border-opacity));
}

.dark .border-blue-700 {
  border-color: rgba(191, 219, 254, var(--tw-border-opacity));
}

.dark .border-blue-700.nightwind-prevent {
  border-color: rgba(29, 78, 216, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-700 {
  border-color: rgba(29, 78, 216, var(--tw-border-opacity));
}

.dark .hover\:border-blue-700:hover {
  border-color: rgba(191, 219, 254, var(--tw-border-opacity));
}

.dark .hover\:border-blue-700:hover.nightwind-prevent {
  border-color: rgba(29, 78, 216, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-700:hover {
  border-color: rgba(29, 78, 216, var(--tw-border-opacity));
}

.dark .border-blue-800 {
  border-color: rgba(219, 234, 254, var(--tw-border-opacity));
}

.dark .border-blue-800.nightwind-prevent {
  border-color: rgba(30, 64, 175, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-800 {
  border-color: rgba(30, 64, 175, var(--tw-border-opacity));
}

.dark .hover\:border-blue-800:hover {
  border-color: rgba(219, 234, 254, var(--tw-border-opacity));
}

.dark .hover\:border-blue-800:hover.nightwind-prevent {
  border-color: rgba(30, 64, 175, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-800:hover {
  border-color: rgba(30, 64, 175, var(--tw-border-opacity));
}

.dark .border-blue-900 {
  border-color: rgba(239, 246, 255, var(--tw-border-opacity));
}

.dark .border-blue-900.nightwind-prevent {
  border-color: rgba(30, 58, 138, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-blue-900 {
  border-color: rgba(30, 58, 138, var(--tw-border-opacity));
}

.dark .hover\:border-blue-900:hover {
  border-color: rgba(239, 246, 255, var(--tw-border-opacity));
}

.dark .hover\:border-blue-900:hover.nightwind-prevent {
  border-color: rgba(30, 58, 138, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-blue-900:hover {
  border-color: rgba(30, 58, 138, var(--tw-border-opacity));
}

.dark .border-indigo-50 {
  border-color: rgba(49, 46, 129, var(--tw-border-opacity));
}

.dark .border-indigo-50.nightwind-prevent {
  border-color: rgba(238, 242, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-50 {
  border-color: rgba(238, 242, 255, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-50:hover {
  border-color: rgba(49, 46, 129, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-50:hover.nightwind-prevent {
  border-color: rgba(238, 242, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-50:hover {
  border-color: rgba(238, 242, 255, var(--tw-border-opacity));
}

.dark .border-indigo-100 {
  border-color: rgba(55, 48, 163, var(--tw-border-opacity));
}

.dark .border-indigo-100.nightwind-prevent {
  border-color: rgba(224, 231, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-100 {
  border-color: rgba(224, 231, 255, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-100:hover {
  border-color: rgba(55, 48, 163, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-100:hover.nightwind-prevent {
  border-color: rgba(224, 231, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-100:hover {
  border-color: rgba(224, 231, 255, var(--tw-border-opacity));
}

.dark .border-indigo-200 {
  border-color: rgba(67, 56, 202, var(--tw-border-opacity));
}

.dark .border-indigo-200.nightwind-prevent {
  border-color: rgba(199, 210, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-200 {
  border-color: rgba(199, 210, 254, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-200:hover {
  border-color: rgba(67, 56, 202, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-200:hover.nightwind-prevent {
  border-color: rgba(199, 210, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-200:hover {
  border-color: rgba(199, 210, 254, var(--tw-border-opacity));
}

.dark .border-indigo-300 {
  border-color: rgba(79, 70, 229, var(--tw-border-opacity));
}

.dark .border-indigo-300.nightwind-prevent {
  border-color: rgba(165, 180, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-300 {
  border-color: rgba(165, 180, 252, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-300:hover {
  border-color: rgba(79, 70, 229, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-300:hover.nightwind-prevent {
  border-color: rgba(165, 180, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-300:hover {
  border-color: rgba(165, 180, 252, var(--tw-border-opacity));
}

.dark .border-indigo-400 {
  border-color: rgba(99, 102, 241, var(--tw-border-opacity));
}

.dark .border-indigo-400.nightwind-prevent {
  border-color: rgba(129, 140, 248, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-400 {
  border-color: rgba(129, 140, 248, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-400:hover {
  border-color: rgba(99, 102, 241, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-400:hover.nightwind-prevent {
  border-color: rgba(129, 140, 248, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-400:hover {
  border-color: rgba(129, 140, 248, var(--tw-border-opacity));
}

.dark .border-indigo-500 {
  border-color: rgba(129, 140, 248, var(--tw-border-opacity));
}

.dark .border-indigo-500.nightwind-prevent {
  border-color: rgba(99, 102, 241, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-500 {
  border-color: rgba(99, 102, 241, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-500:hover {
  border-color: rgba(129, 140, 248, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-500:hover.nightwind-prevent {
  border-color: rgba(99, 102, 241, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-500:hover {
  border-color: rgba(99, 102, 241, var(--tw-border-opacity));
}

.dark .border-indigo-600 {
  border-color: rgba(165, 180, 252, var(--tw-border-opacity));
}

.dark .border-indigo-600.nightwind-prevent {
  border-color: rgba(79, 70, 229, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-600 {
  border-color: rgba(79, 70, 229, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-600:hover {
  border-color: rgba(165, 180, 252, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-600:hover.nightwind-prevent {
  border-color: rgba(79, 70, 229, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-600:hover {
  border-color: rgba(79, 70, 229, var(--tw-border-opacity));
}

.dark .border-indigo-700 {
  border-color: rgba(199, 210, 254, var(--tw-border-opacity));
}

.dark .border-indigo-700.nightwind-prevent {
  border-color: rgba(67, 56, 202, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-700 {
  border-color: rgba(67, 56, 202, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-700:hover {
  border-color: rgba(199, 210, 254, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-700:hover.nightwind-prevent {
  border-color: rgba(67, 56, 202, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-700:hover {
  border-color: rgba(67, 56, 202, var(--tw-border-opacity));
}

.dark .border-indigo-800 {
  border-color: rgba(224, 231, 255, var(--tw-border-opacity));
}

.dark .border-indigo-800.nightwind-prevent {
  border-color: rgba(55, 48, 163, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-800 {
  border-color: rgba(55, 48, 163, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-800:hover {
  border-color: rgba(224, 231, 255, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-800:hover.nightwind-prevent {
  border-color: rgba(55, 48, 163, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-800:hover {
  border-color: rgba(55, 48, 163, var(--tw-border-opacity));
}

.dark .border-indigo-900 {
  border-color: rgba(238, 242, 255, var(--tw-border-opacity));
}

.dark .border-indigo-900.nightwind-prevent {
  border-color: rgba(49, 46, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-indigo-900 {
  border-color: rgba(49, 46, 129, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-900:hover {
  border-color: rgba(238, 242, 255, var(--tw-border-opacity));
}

.dark .hover\:border-indigo-900:hover.nightwind-prevent {
  border-color: rgba(49, 46, 129, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-indigo-900:hover {
  border-color: rgba(49, 46, 129, var(--tw-border-opacity));
}

.dark .border-violet-50 {
  border-color: rgba(76, 29, 149, var(--tw-border-opacity));
}

.dark .border-violet-50.nightwind-prevent {
  border-color: rgba(245, 243, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-50 {
  border-color: rgba(245, 243, 255, var(--tw-border-opacity));
}

.dark .hover\:border-violet-50:hover {
  border-color: rgba(76, 29, 149, var(--tw-border-opacity));
}

.dark .hover\:border-violet-50:hover.nightwind-prevent {
  border-color: rgba(245, 243, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-50:hover {
  border-color: rgba(245, 243, 255, var(--tw-border-opacity));
}

.dark .border-violet-100 {
  border-color: rgba(91, 33, 182, var(--tw-border-opacity));
}

.dark .border-violet-100.nightwind-prevent {
  border-color: rgba(237, 233, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-100 {
  border-color: rgba(237, 233, 254, var(--tw-border-opacity));
}

.dark .hover\:border-violet-100:hover {
  border-color: rgba(91, 33, 182, var(--tw-border-opacity));
}

.dark .hover\:border-violet-100:hover.nightwind-prevent {
  border-color: rgba(237, 233, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-100:hover {
  border-color: rgba(237, 233, 254, var(--tw-border-opacity));
}

.dark .border-violet-200 {
  border-color: rgba(109, 40, 217, var(--tw-border-opacity));
}

.dark .border-violet-200.nightwind-prevent {
  border-color: rgba(221, 214, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-200 {
  border-color: rgba(221, 214, 254, var(--tw-border-opacity));
}

.dark .hover\:border-violet-200:hover {
  border-color: rgba(109, 40, 217, var(--tw-border-opacity));
}

.dark .hover\:border-violet-200:hover.nightwind-prevent {
  border-color: rgba(221, 214, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-200:hover {
  border-color: rgba(221, 214, 254, var(--tw-border-opacity));
}

.dark .border-violet-300 {
  border-color: rgba(124, 58, 237, var(--tw-border-opacity));
}

.dark .border-violet-300.nightwind-prevent {
  border-color: rgba(196, 181, 253, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-300 {
  border-color: rgba(196, 181, 253, var(--tw-border-opacity));
}

.dark .hover\:border-violet-300:hover {
  border-color: rgba(124, 58, 237, var(--tw-border-opacity));
}

.dark .hover\:border-violet-300:hover.nightwind-prevent {
  border-color: rgba(196, 181, 253, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-300:hover {
  border-color: rgba(196, 181, 253, var(--tw-border-opacity));
}

.dark .border-violet-400 {
  border-color: rgba(139, 92, 246, var(--tw-border-opacity));
}

.dark .border-violet-400.nightwind-prevent {
  border-color: rgba(167, 139, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-400 {
  border-color: rgba(167, 139, 250, var(--tw-border-opacity));
}

.dark .hover\:border-violet-400:hover {
  border-color: rgba(139, 92, 246, var(--tw-border-opacity));
}

.dark .hover\:border-violet-400:hover.nightwind-prevent {
  border-color: rgba(167, 139, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-400:hover {
  border-color: rgba(167, 139, 250, var(--tw-border-opacity));
}

.dark .border-violet-500 {
  border-color: rgba(167, 139, 250, var(--tw-border-opacity));
}

.dark .border-violet-500.nightwind-prevent {
  border-color: rgba(139, 92, 246, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-500 {
  border-color: rgba(139, 92, 246, var(--tw-border-opacity));
}

.dark .hover\:border-violet-500:hover {
  border-color: rgba(167, 139, 250, var(--tw-border-opacity));
}

.dark .hover\:border-violet-500:hover.nightwind-prevent {
  border-color: rgba(139, 92, 246, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-500:hover {
  border-color: rgba(139, 92, 246, var(--tw-border-opacity));
}

.dark .border-violet-600 {
  border-color: rgba(196, 181, 253, var(--tw-border-opacity));
}

.dark .border-violet-600.nightwind-prevent {
  border-color: rgba(124, 58, 237, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-600 {
  border-color: rgba(124, 58, 237, var(--tw-border-opacity));
}

.dark .hover\:border-violet-600:hover {
  border-color: rgba(196, 181, 253, var(--tw-border-opacity));
}

.dark .hover\:border-violet-600:hover.nightwind-prevent {
  border-color: rgba(124, 58, 237, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-600:hover {
  border-color: rgba(124, 58, 237, var(--tw-border-opacity));
}

.dark .border-violet-700 {
  border-color: rgba(221, 214, 254, var(--tw-border-opacity));
}

.dark .border-violet-700.nightwind-prevent {
  border-color: rgba(109, 40, 217, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-700 {
  border-color: rgba(109, 40, 217, var(--tw-border-opacity));
}

.dark .hover\:border-violet-700:hover {
  border-color: rgba(221, 214, 254, var(--tw-border-opacity));
}

.dark .hover\:border-violet-700:hover.nightwind-prevent {
  border-color: rgba(109, 40, 217, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-700:hover {
  border-color: rgba(109, 40, 217, var(--tw-border-opacity));
}

.dark .border-violet-800 {
  border-color: rgba(237, 233, 254, var(--tw-border-opacity));
}

.dark .border-violet-800.nightwind-prevent {
  border-color: rgba(91, 33, 182, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-800 {
  border-color: rgba(91, 33, 182, var(--tw-border-opacity));
}

.dark .hover\:border-violet-800:hover {
  border-color: rgba(237, 233, 254, var(--tw-border-opacity));
}

.dark .hover\:border-violet-800:hover.nightwind-prevent {
  border-color: rgba(91, 33, 182, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-800:hover {
  border-color: rgba(91, 33, 182, var(--tw-border-opacity));
}

.dark .border-violet-900 {
  border-color: rgba(245, 243, 255, var(--tw-border-opacity));
}

.dark .border-violet-900.nightwind-prevent {
  border-color: rgba(76, 29, 149, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-violet-900 {
  border-color: rgba(76, 29, 149, var(--tw-border-opacity));
}

.dark .hover\:border-violet-900:hover {
  border-color: rgba(245, 243, 255, var(--tw-border-opacity));
}

.dark .hover\:border-violet-900:hover.nightwind-prevent {
  border-color: rgba(76, 29, 149, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-violet-900:hover {
  border-color: rgba(76, 29, 149, var(--tw-border-opacity));
}

.dark .border-purple-50 {
  border-color: rgba(88, 28, 135, var(--tw-border-opacity));
}

.dark .border-purple-50.nightwind-prevent {
  border-color: rgba(250, 245, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-50 {
  border-color: rgba(250, 245, 255, var(--tw-border-opacity));
}

.dark .hover\:border-purple-50:hover {
  border-color: rgba(88, 28, 135, var(--tw-border-opacity));
}

.dark .hover\:border-purple-50:hover.nightwind-prevent {
  border-color: rgba(250, 245, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-50:hover {
  border-color: rgba(250, 245, 255, var(--tw-border-opacity));
}

.dark .border-purple-100 {
  border-color: rgba(107, 33, 168, var(--tw-border-opacity));
}

.dark .border-purple-100.nightwind-prevent {
  border-color: rgba(243, 232, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-100 {
  border-color: rgba(243, 232, 255, var(--tw-border-opacity));
}

.dark .hover\:border-purple-100:hover {
  border-color: rgba(107, 33, 168, var(--tw-border-opacity));
}

.dark .hover\:border-purple-100:hover.nightwind-prevent {
  border-color: rgba(243, 232, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-100:hover {
  border-color: rgba(243, 232, 255, var(--tw-border-opacity));
}

.dark .border-purple-200 {
  border-color: rgba(126, 34, 206, var(--tw-border-opacity));
}

.dark .border-purple-200.nightwind-prevent {
  border-color: rgba(233, 213, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-200 {
  border-color: rgba(233, 213, 255, var(--tw-border-opacity));
}

.dark .hover\:border-purple-200:hover {
  border-color: rgba(126, 34, 206, var(--tw-border-opacity));
}

.dark .hover\:border-purple-200:hover.nightwind-prevent {
  border-color: rgba(233, 213, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-200:hover {
  border-color: rgba(233, 213, 255, var(--tw-border-opacity));
}

.dark .border-purple-300 {
  border-color: rgba(147, 51, 234, var(--tw-border-opacity));
}

.dark .border-purple-300.nightwind-prevent {
  border-color: rgba(216, 180, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-300 {
  border-color: rgba(216, 180, 254, var(--tw-border-opacity));
}

.dark .hover\:border-purple-300:hover {
  border-color: rgba(147, 51, 234, var(--tw-border-opacity));
}

.dark .hover\:border-purple-300:hover.nightwind-prevent {
  border-color: rgba(216, 180, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-300:hover {
  border-color: rgba(216, 180, 254, var(--tw-border-opacity));
}

.dark .border-purple-400 {
  border-color: rgba(168, 85, 247, var(--tw-border-opacity));
}

.dark .border-purple-400.nightwind-prevent {
  border-color: rgba(192, 132, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-400 {
  border-color: rgba(192, 132, 252, var(--tw-border-opacity));
}

.dark .hover\:border-purple-400:hover {
  border-color: rgba(168, 85, 247, var(--tw-border-opacity));
}

.dark .hover\:border-purple-400:hover.nightwind-prevent {
  border-color: rgba(192, 132, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-400:hover {
  border-color: rgba(192, 132, 252, var(--tw-border-opacity));
}

.dark .border-purple-500 {
  border-color: rgba(192, 132, 252, var(--tw-border-opacity));
}

.dark .border-purple-500.nightwind-prevent {
  border-color: rgba(168, 85, 247, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-500 {
  border-color: rgba(168, 85, 247, var(--tw-border-opacity));
}

.dark .hover\:border-purple-500:hover {
  border-color: rgba(192, 132, 252, var(--tw-border-opacity));
}

.dark .hover\:border-purple-500:hover.nightwind-prevent {
  border-color: rgba(168, 85, 247, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-500:hover {
  border-color: rgba(168, 85, 247, var(--tw-border-opacity));
}

.dark .border-purple-600 {
  border-color: rgba(216, 180, 254, var(--tw-border-opacity));
}

.dark .border-purple-600.nightwind-prevent {
  border-color: rgba(147, 51, 234, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-600 {
  border-color: rgba(147, 51, 234, var(--tw-border-opacity));
}

.dark .hover\:border-purple-600:hover {
  border-color: rgba(216, 180, 254, var(--tw-border-opacity));
}

.dark .hover\:border-purple-600:hover.nightwind-prevent {
  border-color: rgba(147, 51, 234, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-600:hover {
  border-color: rgba(147, 51, 234, var(--tw-border-opacity));
}

.dark .border-purple-700 {
  border-color: rgba(233, 213, 255, var(--tw-border-opacity));
}

.dark .border-purple-700.nightwind-prevent {
  border-color: rgba(126, 34, 206, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-700 {
  border-color: rgba(126, 34, 206, var(--tw-border-opacity));
}

.dark .hover\:border-purple-700:hover {
  border-color: rgba(233, 213, 255, var(--tw-border-opacity));
}

.dark .hover\:border-purple-700:hover.nightwind-prevent {
  border-color: rgba(126, 34, 206, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-700:hover {
  border-color: rgba(126, 34, 206, var(--tw-border-opacity));
}

.dark .border-purple-800 {
  border-color: rgba(243, 232, 255, var(--tw-border-opacity));
}

.dark .border-purple-800.nightwind-prevent {
  border-color: rgba(107, 33, 168, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-800 {
  border-color: rgba(107, 33, 168, var(--tw-border-opacity));
}

.dark .hover\:border-purple-800:hover {
  border-color: rgba(243, 232, 255, var(--tw-border-opacity));
}

.dark .hover\:border-purple-800:hover.nightwind-prevent {
  border-color: rgba(107, 33, 168, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-800:hover {
  border-color: rgba(107, 33, 168, var(--tw-border-opacity));
}

.dark .border-purple-900 {
  border-color: rgba(250, 245, 255, var(--tw-border-opacity));
}

.dark .border-purple-900.nightwind-prevent {
  border-color: rgba(88, 28, 135, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-purple-900 {
  border-color: rgba(88, 28, 135, var(--tw-border-opacity));
}

.dark .hover\:border-purple-900:hover {
  border-color: rgba(250, 245, 255, var(--tw-border-opacity));
}

.dark .hover\:border-purple-900:hover.nightwind-prevent {
  border-color: rgba(88, 28, 135, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-purple-900:hover {
  border-color: rgba(88, 28, 135, var(--tw-border-opacity));
}

.dark .border-fuchsia-50 {
  border-color: rgba(112, 26, 117, var(--tw-border-opacity));
}

.dark .border-fuchsia-50.nightwind-prevent {
  border-color: rgba(253, 244, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-50 {
  border-color: rgba(253, 244, 255, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-50:hover {
  border-color: rgba(112, 26, 117, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-50:hover.nightwind-prevent {
  border-color: rgba(253, 244, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-50:hover {
  border-color: rgba(253, 244, 255, var(--tw-border-opacity));
}

.dark .border-fuchsia-100 {
  border-color: rgba(134, 25, 143, var(--tw-border-opacity));
}

.dark .border-fuchsia-100.nightwind-prevent {
  border-color: rgba(250, 232, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-100 {
  border-color: rgba(250, 232, 255, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-100:hover {
  border-color: rgba(134, 25, 143, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-100:hover.nightwind-prevent {
  border-color: rgba(250, 232, 255, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-100:hover {
  border-color: rgba(250, 232, 255, var(--tw-border-opacity));
}

.dark .border-fuchsia-200 {
  border-color: rgba(162, 28, 175, var(--tw-border-opacity));
}

.dark .border-fuchsia-200.nightwind-prevent {
  border-color: rgba(245, 208, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-200 {
  border-color: rgba(245, 208, 254, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-200:hover {
  border-color: rgba(162, 28, 175, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-200:hover.nightwind-prevent {
  border-color: rgba(245, 208, 254, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-200:hover {
  border-color: rgba(245, 208, 254, var(--tw-border-opacity));
}

.dark .border-fuchsia-300 {
  border-color: rgba(192, 38, 211, var(--tw-border-opacity));
}

.dark .border-fuchsia-300.nightwind-prevent {
  border-color: rgba(240, 171, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-300 {
  border-color: rgba(240, 171, 252, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-300:hover {
  border-color: rgba(192, 38, 211, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-300:hover.nightwind-prevent {
  border-color: rgba(240, 171, 252, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-300:hover {
  border-color: rgba(240, 171, 252, var(--tw-border-opacity));
}

.dark .border-fuchsia-400 {
  border-color: rgba(217, 70, 239, var(--tw-border-opacity));
}

.dark .border-fuchsia-400.nightwind-prevent {
  border-color: rgba(232, 121, 249, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-400 {
  border-color: rgba(232, 121, 249, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-400:hover {
  border-color: rgba(217, 70, 239, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-400:hover.nightwind-prevent {
  border-color: rgba(232, 121, 249, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-400:hover {
  border-color: rgba(232, 121, 249, var(--tw-border-opacity));
}

.dark .border-fuchsia-500 {
  border-color: rgba(232, 121, 249, var(--tw-border-opacity));
}

.dark .border-fuchsia-500.nightwind-prevent {
  border-color: rgba(217, 70, 239, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-500 {
  border-color: rgba(217, 70, 239, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-500:hover {
  border-color: rgba(232, 121, 249, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-500:hover.nightwind-prevent {
  border-color: rgba(217, 70, 239, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-500:hover {
  border-color: rgba(217, 70, 239, var(--tw-border-opacity));
}

.dark .border-fuchsia-600 {
  border-color: rgba(240, 171, 252, var(--tw-border-opacity));
}

.dark .border-fuchsia-600.nightwind-prevent {
  border-color: rgba(192, 38, 211, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-600 {
  border-color: rgba(192, 38, 211, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-600:hover {
  border-color: rgba(240, 171, 252, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-600:hover.nightwind-prevent {
  border-color: rgba(192, 38, 211, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-600:hover {
  border-color: rgba(192, 38, 211, var(--tw-border-opacity));
}

.dark .border-fuchsia-700 {
  border-color: rgba(245, 208, 254, var(--tw-border-opacity));
}

.dark .border-fuchsia-700.nightwind-prevent {
  border-color: rgba(162, 28, 175, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-700 {
  border-color: rgba(162, 28, 175, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-700:hover {
  border-color: rgba(245, 208, 254, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-700:hover.nightwind-prevent {
  border-color: rgba(162, 28, 175, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-700:hover {
  border-color: rgba(162, 28, 175, var(--tw-border-opacity));
}

.dark .border-fuchsia-800 {
  border-color: rgba(250, 232, 255, var(--tw-border-opacity));
}

.dark .border-fuchsia-800.nightwind-prevent {
  border-color: rgba(134, 25, 143, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-800 {
  border-color: rgba(134, 25, 143, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-800:hover {
  border-color: rgba(250, 232, 255, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-800:hover.nightwind-prevent {
  border-color: rgba(134, 25, 143, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-800:hover {
  border-color: rgba(134, 25, 143, var(--tw-border-opacity));
}

.dark .border-fuchsia-900 {
  border-color: rgba(253, 244, 255, var(--tw-border-opacity));
}

.dark .border-fuchsia-900.nightwind-prevent {
  border-color: rgba(112, 26, 117, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-fuchsia-900 {
  border-color: rgba(112, 26, 117, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-900:hover {
  border-color: rgba(253, 244, 255, var(--tw-border-opacity));
}

.dark .hover\:border-fuchsia-900:hover.nightwind-prevent {
  border-color: rgba(112, 26, 117, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-fuchsia-900:hover {
  border-color: rgba(112, 26, 117, var(--tw-border-opacity));
}

.dark .border-pink-50 {
  border-color: rgba(131, 24, 67, var(--tw-border-opacity));
}

.dark .border-pink-50.nightwind-prevent {
  border-color: rgba(253, 242, 248, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-50 {
  border-color: rgba(253, 242, 248, var(--tw-border-opacity));
}

.dark .hover\:border-pink-50:hover {
  border-color: rgba(131, 24, 67, var(--tw-border-opacity));
}

.dark .hover\:border-pink-50:hover.nightwind-prevent {
  border-color: rgba(253, 242, 248, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-50:hover {
  border-color: rgba(253, 242, 248, var(--tw-border-opacity));
}

.dark .border-pink-100 {
  border-color: rgba(157, 23, 77, var(--tw-border-opacity));
}

.dark .border-pink-100.nightwind-prevent {
  border-color: rgba(252, 231, 243, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-100 {
  border-color: rgba(252, 231, 243, var(--tw-border-opacity));
}

.dark .hover\:border-pink-100:hover {
  border-color: rgba(157, 23, 77, var(--tw-border-opacity));
}

.dark .hover\:border-pink-100:hover.nightwind-prevent {
  border-color: rgba(252, 231, 243, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-100:hover {
  border-color: rgba(252, 231, 243, var(--tw-border-opacity));
}

.dark .border-pink-200 {
  border-color: rgba(190, 24, 93, var(--tw-border-opacity));
}

.dark .border-pink-200.nightwind-prevent {
  border-color: rgba(251, 207, 232, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-200 {
  border-color: rgba(251, 207, 232, var(--tw-border-opacity));
}

.dark .hover\:border-pink-200:hover {
  border-color: rgba(190, 24, 93, var(--tw-border-opacity));
}

.dark .hover\:border-pink-200:hover.nightwind-prevent {
  border-color: rgba(251, 207, 232, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-200:hover {
  border-color: rgba(251, 207, 232, var(--tw-border-opacity));
}

.dark .border-pink-300 {
  border-color: rgba(219, 39, 119, var(--tw-border-opacity));
}

.dark .border-pink-300.nightwind-prevent {
  border-color: rgba(249, 168, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-300 {
  border-color: rgba(249, 168, 212, var(--tw-border-opacity));
}

.dark .hover\:border-pink-300:hover {
  border-color: rgba(219, 39, 119, var(--tw-border-opacity));
}

.dark .hover\:border-pink-300:hover.nightwind-prevent {
  border-color: rgba(249, 168, 212, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-300:hover {
  border-color: rgba(249, 168, 212, var(--tw-border-opacity));
}

.dark .border-pink-400 {
  border-color: rgba(236, 72, 153, var(--tw-border-opacity));
}

.dark .border-pink-400.nightwind-prevent {
  border-color: rgba(244, 114, 182, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-400 {
  border-color: rgba(244, 114, 182, var(--tw-border-opacity));
}

.dark .hover\:border-pink-400:hover {
  border-color: rgba(236, 72, 153, var(--tw-border-opacity));
}

.dark .hover\:border-pink-400:hover.nightwind-prevent {
  border-color: rgba(244, 114, 182, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-400:hover {
  border-color: rgba(244, 114, 182, var(--tw-border-opacity));
}

.dark .border-pink-500 {
  border-color: rgba(244, 114, 182, var(--tw-border-opacity));
}

.dark .border-pink-500.nightwind-prevent {
  border-color: rgba(236, 72, 153, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-500 {
  border-color: rgba(236, 72, 153, var(--tw-border-opacity));
}

.dark .hover\:border-pink-500:hover {
  border-color: rgba(244, 114, 182, var(--tw-border-opacity));
}

.dark .hover\:border-pink-500:hover.nightwind-prevent {
  border-color: rgba(236, 72, 153, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-500:hover {
  border-color: rgba(236, 72, 153, var(--tw-border-opacity));
}

.dark .border-pink-600 {
  border-color: rgba(249, 168, 212, var(--tw-border-opacity));
}

.dark .border-pink-600.nightwind-prevent {
  border-color: rgba(219, 39, 119, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-600 {
  border-color: rgba(219, 39, 119, var(--tw-border-opacity));
}

.dark .hover\:border-pink-600:hover {
  border-color: rgba(249, 168, 212, var(--tw-border-opacity));
}

.dark .hover\:border-pink-600:hover.nightwind-prevent {
  border-color: rgba(219, 39, 119, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-600:hover {
  border-color: rgba(219, 39, 119, var(--tw-border-opacity));
}

.dark .border-pink-700 {
  border-color: rgba(251, 207, 232, var(--tw-border-opacity));
}

.dark .border-pink-700.nightwind-prevent {
  border-color: rgba(190, 24, 93, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-700 {
  border-color: rgba(190, 24, 93, var(--tw-border-opacity));
}

.dark .hover\:border-pink-700:hover {
  border-color: rgba(251, 207, 232, var(--tw-border-opacity));
}

.dark .hover\:border-pink-700:hover.nightwind-prevent {
  border-color: rgba(190, 24, 93, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-700:hover {
  border-color: rgba(190, 24, 93, var(--tw-border-opacity));
}

.dark .border-pink-800 {
  border-color: rgba(252, 231, 243, var(--tw-border-opacity));
}

.dark .border-pink-800.nightwind-prevent {
  border-color: rgba(157, 23, 77, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-800 {
  border-color: rgba(157, 23, 77, var(--tw-border-opacity));
}

.dark .hover\:border-pink-800:hover {
  border-color: rgba(252, 231, 243, var(--tw-border-opacity));
}

.dark .hover\:border-pink-800:hover.nightwind-prevent {
  border-color: rgba(157, 23, 77, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-800:hover {
  border-color: rgba(157, 23, 77, var(--tw-border-opacity));
}

.dark .border-pink-900 {
  border-color: rgba(253, 242, 248, var(--tw-border-opacity));
}

.dark .border-pink-900.nightwind-prevent {
  border-color: rgba(131, 24, 67, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-pink-900 {
  border-color: rgba(131, 24, 67, var(--tw-border-opacity));
}

.dark .hover\:border-pink-900:hover {
  border-color: rgba(253, 242, 248, var(--tw-border-opacity));
}

.dark .hover\:border-pink-900:hover.nightwind-prevent {
  border-color: rgba(131, 24, 67, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-pink-900:hover {
  border-color: rgba(131, 24, 67, var(--tw-border-opacity));
}

.dark .border-rose-50 {
  border-color: rgba(136, 19, 55, var(--tw-border-opacity));
}

.dark .border-rose-50.nightwind-prevent {
  border-color: rgba(255, 241, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-50 {
  border-color: rgba(255, 241, 242, var(--tw-border-opacity));
}

.dark .hover\:border-rose-50:hover {
  border-color: rgba(136, 19, 55, var(--tw-border-opacity));
}

.dark .hover\:border-rose-50:hover.nightwind-prevent {
  border-color: rgba(255, 241, 242, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-50:hover {
  border-color: rgba(255, 241, 242, var(--tw-border-opacity));
}

.dark .border-rose-100 {
  border-color: rgba(159, 18, 57, var(--tw-border-opacity));
}

.dark .border-rose-100.nightwind-prevent {
  border-color: rgba(255, 228, 230, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-100 {
  border-color: rgba(255, 228, 230, var(--tw-border-opacity));
}

.dark .hover\:border-rose-100:hover {
  border-color: rgba(159, 18, 57, var(--tw-border-opacity));
}

.dark .hover\:border-rose-100:hover.nightwind-prevent {
  border-color: rgba(255, 228, 230, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-100:hover {
  border-color: rgba(255, 228, 230, var(--tw-border-opacity));
}

.dark .border-rose-200 {
  border-color: rgba(190, 18, 60, var(--tw-border-opacity));
}

.dark .border-rose-200.nightwind-prevent {
  border-color: rgba(254, 205, 211, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-200 {
  border-color: rgba(254, 205, 211, var(--tw-border-opacity));
}

.dark .hover\:border-rose-200:hover {
  border-color: rgba(190, 18, 60, var(--tw-border-opacity));
}

.dark .hover\:border-rose-200:hover.nightwind-prevent {
  border-color: rgba(254, 205, 211, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-200:hover {
  border-color: rgba(254, 205, 211, var(--tw-border-opacity));
}

.dark .border-rose-300 {
  border-color: rgba(225, 29, 72, var(--tw-border-opacity));
}

.dark .border-rose-300.nightwind-prevent {
  border-color: rgba(253, 164, 175, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-300 {
  border-color: rgba(253, 164, 175, var(--tw-border-opacity));
}

.dark .hover\:border-rose-300:hover {
  border-color: rgba(225, 29, 72, var(--tw-border-opacity));
}

.dark .hover\:border-rose-300:hover.nightwind-prevent {
  border-color: rgba(253, 164, 175, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-300:hover {
  border-color: rgba(253, 164, 175, var(--tw-border-opacity));
}

.dark .border-rose-400 {
  border-color: rgba(244, 63, 94, var(--tw-border-opacity));
}

.dark .border-rose-400.nightwind-prevent {
  border-color: rgba(251, 113, 133, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-400 {
  border-color: rgba(251, 113, 133, var(--tw-border-opacity));
}

.dark .hover\:border-rose-400:hover {
  border-color: rgba(244, 63, 94, var(--tw-border-opacity));
}

.dark .hover\:border-rose-400:hover.nightwind-prevent {
  border-color: rgba(251, 113, 133, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-400:hover {
  border-color: rgba(251, 113, 133, var(--tw-border-opacity));
}

.dark .border-rose-500 {
  border-color: rgba(251, 113, 133, var(--tw-border-opacity));
}

.dark .border-rose-500.nightwind-prevent {
  border-color: rgba(244, 63, 94, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-500 {
  border-color: rgba(244, 63, 94, var(--tw-border-opacity));
}

.dark .hover\:border-rose-500:hover {
  border-color: rgba(251, 113, 133, var(--tw-border-opacity));
}

.dark .hover\:border-rose-500:hover.nightwind-prevent {
  border-color: rgba(244, 63, 94, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-500:hover {
  border-color: rgba(244, 63, 94, var(--tw-border-opacity));
}

.dark .border-rose-600 {
  border-color: rgba(253, 164, 175, var(--tw-border-opacity));
}

.dark .border-rose-600.nightwind-prevent {
  border-color: rgba(225, 29, 72, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-600 {
  border-color: rgba(225, 29, 72, var(--tw-border-opacity));
}

.dark .hover\:border-rose-600:hover {
  border-color: rgba(253, 164, 175, var(--tw-border-opacity));
}

.dark .hover\:border-rose-600:hover.nightwind-prevent {
  border-color: rgba(225, 29, 72, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-600:hover {
  border-color: rgba(225, 29, 72, var(--tw-border-opacity));
}

.dark .border-rose-700 {
  border-color: rgba(254, 205, 211, var(--tw-border-opacity));
}

.dark .border-rose-700.nightwind-prevent {
  border-color: rgba(190, 18, 60, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-700 {
  border-color: rgba(190, 18, 60, var(--tw-border-opacity));
}

.dark .hover\:border-rose-700:hover {
  border-color: rgba(254, 205, 211, var(--tw-border-opacity));
}

.dark .hover\:border-rose-700:hover.nightwind-prevent {
  border-color: rgba(190, 18, 60, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-700:hover {
  border-color: rgba(190, 18, 60, var(--tw-border-opacity));
}

.dark .border-rose-800 {
  border-color: rgba(255, 228, 230, var(--tw-border-opacity));
}

.dark .border-rose-800.nightwind-prevent {
  border-color: rgba(159, 18, 57, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-800 {
  border-color: rgba(159, 18, 57, var(--tw-border-opacity));
}

.dark .hover\:border-rose-800:hover {
  border-color: rgba(255, 228, 230, var(--tw-border-opacity));
}

.dark .hover\:border-rose-800:hover.nightwind-prevent {
  border-color: rgba(159, 18, 57, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-800:hover {
  border-color: rgba(159, 18, 57, var(--tw-border-opacity));
}

.dark .border-rose-900 {
  border-color: rgba(255, 241, 242, var(--tw-border-opacity));
}

.dark .border-rose-900.nightwind-prevent {
  border-color: rgba(136, 19, 55, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-rose-900 {
  border-color: rgba(136, 19, 55, var(--tw-border-opacity));
}

.dark .hover\:border-rose-900:hover {
  border-color: rgba(255, 241, 242, var(--tw-border-opacity));
}

.dark .hover\:border-rose-900:hover.nightwind-prevent {
  border-color: rgba(136, 19, 55, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-rose-900:hover {
  border-color: rgba(136, 19, 55, var(--tw-border-opacity));
}

.dark .border-background-50 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-50.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-50 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-50:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-50:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-50:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-100 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-100.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-100 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-100:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-100:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-100:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-200 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-200.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-200 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-200:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-200:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-200:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-300 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-300.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-300 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-300:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-300:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-300:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-400 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-400.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-400 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-400:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-400:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-400:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-500 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-500.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-500 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-500:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-500:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-500:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-600 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-600.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-600 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-600:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-600:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-600:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-700 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-700.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-700 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-700:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-700:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-700:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-800 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-800.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-800 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-800:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-800:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-800:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-900 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-background-900.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-background-900 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-900:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-background-900:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-background-900:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-50 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-50.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-50 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-50:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-50:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-50:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-100 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-100.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-100 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-100:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-100:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-100:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-200 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-200.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-200 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-200:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-200:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-200:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-300 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-300.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-300 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-300:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-300:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-300:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-400 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-400.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-400 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-400:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-400:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-400:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-500 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-500.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-500 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-500:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-500:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-500:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-600 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-600.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-600 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-600:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-600:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-600:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-700 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-700.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-700 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-700:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-700:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-700:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-800 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-800.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-800 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-800:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-800:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-800:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-900 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .border-foreground-900.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .border-foreground-900 {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-900:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .hover\:border-foreground-900:hover.nightwind-prevent {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .hover\:border-foreground-900:hover {
  border-color: rgba(undefined, undefined, undefined, var(--tw-border-opacity));
}

.invisible {
  visibility: hidden;
}

.collapse {
  visibility: collapse;
}

.static {
  position: static;
}

.fixed {
  position: fixed;
}

.absolute {
  position: absolute;
}

.inset-0 {
  top: 0px;
  right: 0px;
  bottom: 0px;
  left: 0px;
}

.z-10 {
  z-index: 10;
}

.z-50 {
  z-index: 50;
}

.-mx-2 {
  margin-left: -0.5rem;
  margin-right: -0.5rem;
}

.mx-auto {
  margin-left: auto;
  margin-right: auto;
}

.mb-4 {
  margin-bottom: 1rem;
}

.mb-5 {
  margin-bottom: 1.25rem;
}

.mt-1 {
  margin-top: 0.25rem;
}

.mt-5 {
  margin-top: 1.25rem;
}

.mt-8 {
  margin-top: 2rem;
}

.block {
  display: block;
}

.inline-block {
  display: inline-block;
}

.flex {
  display: flex;
}

.inline-flex {
  display: inline-flex;
}

.table {
  display: table;
}

.grid {
  display: grid;
}

.hidden {
  display: none;
}

.h-2 {
  height: 0.5rem;
}

.h-2\.5 {
  height: 0.625rem;
}

.h-3 {
  height: 0.75rem;
}

.h-3\.5 {
  height: 0.875rem;
}

.h-4 {
  height: 1rem;
}

.h-6 {
  height: 1.5rem;
}

.h-px {
  height: 1px;
}

.w-2 {
  width: 0.5rem;
}

.w-2\.5 {
  width: 0.625rem;
}

.w-3 {
  width: 0.75rem;
}

.w-3\.5 {
  width: 0.875rem;
}

.w-4 {
  width: 1rem;
}

.w-6 {
  width: 1.5rem;
}

.w-full {
  width: 100%;
}

.w-px {
  width: 1px;
}

.min-w-full {
  min-width: 100%;
}

.max-w-\[85rem\] {
  max-width: 85rem;
}

.flex-none {
  flex: none;
}

.shrink {
  flex-shrink: 1;
}

.grow {
  flex-grow: 1;
}

.basis-full {
  flex-basis: 100%;
}

.transform {
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.resize {
  resize: both;
}

.flex-col {
  flex-direction: column;
}

.flex-wrap {
  flex-wrap: wrap;
}

.items-center {
  align-items: center;
}

.justify-center {
  justify-content: center;
}

.justify-between {
  justify-content: space-between;
}

.gap-2 {
  gap: 0.5rem;
}

.gap-3 {
  gap: 0.75rem;
}

.gap-4 {
  gap: 1rem;
}

.gap-5 {
  gap: 1.25rem;
}

.gap-x-2 {
  -moz-column-gap: 0.5rem;
       column-gap: 0.5rem;
}

.divide-y > :not([hidden]) ~ :not([hidden]) {
  --tw-divide-y-reverse: 0;
  border-top-width: calc(1px * calc(1 - var(--tw-divide-y-reverse)));
  border-bottom-width: calc(1px * var(--tw-divide-y-reverse));
}

.divide-gray-200 > :not([hidden]) ~ :not([hidden]) {
  --tw-divide-opacity: 1;
  border-color: rgb(208 215 222 / var(--tw-divide-opacity));
}

.overflow-hidden {
  overflow: hidden;
}

.whitespace-nowrap {
  white-space: nowrap;
}

.rounded-md {
  border-radius: 0.375rem;
}

.rounded-sm {
  border-radius: 0.125rem;
}

.rounded-xl {
  border-radius: 0.75rem;
}

.border {
  border-width: 1px;
}

.border-0 {
  border-width: 0px;
}

.border-b {
  border-bottom-width: 1px;
}

.border-gray-200 {
  --tw-border-opacity: 1;
  border-color: rgb(208 215 222 / var(--tw-border-opacity));
}

.border-gray-300 {
  --tw-border-opacity: 1;
  border-color: rgb(175 184 193 / var(--tw-border-opacity));
}

.border-gray-50 {
  --tw-border-opacity: 1;
  border-color: rgb(246 248 250 / var(--tw-border-opacity));
}

.border-slate-50 {
  --tw-border-opacity: 1;
  border-color: rgb(246 248 250 / var(--tw-border-opacity));
}

.border-slate-900 {
  --tw-border-opacity: 1;
  border-color: rgb(36 41 47 / var(--tw-border-opacity));
}

.border-slate-300 {
  --tw-border-opacity: 1;
  border-color: rgb(175 184 193 / var(--tw-border-opacity));
}

.border-slate-200 {
  --tw-border-opacity: 1;
  border-color: rgb(208 215 222 / var(--tw-border-opacity));
}

.bg-background {
  --tw-bg-opacity: 1;
  background-color: rgb(240 243 246 / var(--tw-bg-opacity));
}

.bg-blue-500 {
  --tw-bg-opacity: 1;
  background-color: rgb(59 130 246 / var(--tw-bg-opacity));
}

.bg-gray-50 {
  --tw-bg-opacity: 1;
  background-color: rgb(246 248 250 / var(--tw-bg-opacity));
}

.bg-gray-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(36 41 47 / var(--tw-bg-opacity));
}

.bg-white {
  --tw-bg-opacity: 1;
  background-color: rgb(255 255 255 / var(--tw-bg-opacity));
}

.bg-foreground {
  --tw-bg-opacity: 1;
  background-color: rgb(13 17 23 / var(--tw-bg-opacity));
}

.bg-opacity-50 {
  --tw-bg-opacity: 0.5;
}

.p-2 {
  padding: 0.5rem;
}

.p-4 {
  padding: 1rem;
}

.px-2 {
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}

.px-4 {
  padding-left: 1rem;
  padding-right: 1rem;
}

.px-6 {
  padding-left: 1.5rem;
  padding-right: 1.5rem;
}

.py-1 {
  padding-top: 0.25rem;
  padding-bottom: 0.25rem;
}

.py-2 {
  padding-top: 0.5rem;
  padding-bottom: 0.5rem;
}

.py-3 {
  padding-top: 0.75rem;
  padding-bottom: 0.75rem;
}

.py-4 {
  padding-top: 1rem;
  padding-bottom: 1rem;
}

.text-left {
  text-align: left;
}

.align-top {
  vertical-align: top;
}

.align-middle {
  vertical-align: middle;
}

.text-sm {
  font-size: 0.875rem;
  line-height: 1.25rem;
}

.text-xl {
  font-size: 1.25rem;
  line-height: 1.75rem;
}

.text-xs {
  font-size: 0.75rem;
  line-height: 1rem;
}

.font-medium {
  font-weight: 500;
}

.font-semibold {
  font-weight: 600;
}

.uppercase {
  text-transform: uppercase;
}

.tracking-wide {
  letter-spacing: 0.025em;
}

.text-foreground {
  --tw-text-opacity: 1;
  color: rgb(13 17 23 / var(--tw-text-opacity));
}

.text-gray-500 {
  --tw-text-opacity: 1;
  color: rgb(110 119 129 / var(--tw-text-opacity));
}

.text-gray-600 {
  --tw-text-opacity: 1;
  color: rgb(87 96 106 / var(--tw-text-opacity));
}

.text-gray-700 {
  --tw-text-opacity: 1;
  color: rgb(66 74 83 / var(--tw-text-opacity));
}

.text-gray-800 {
  --tw-text-opacity: 1;
  color: rgb(50 56 63 / var(--tw-text-opacity));
}

.text-white {
  --tw-text-opacity: 1;
  color: rgb(255 255 255 / var(--tw-text-opacity));
}

.opacity-0 {
  opacity: 0;
}

.shadow-sm {
  --tw-shadow: 0 1px 2px 0 rgb(0 0 0 / 0.05);
  --tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.blur {
  --tw-blur: blur(8px);
  filter: var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow);
}

.filter {
  filter: var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow);
}

.transition {
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}

.transition-\[height\] {
  transition-property: height;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}

.transition-all {
  transition-property: all;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}

.transition-opacity {
  transition-property: opacity;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}

.duration-300 {
  transition-duration: 300ms;
}

.nightwind .text-white {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .bg-white {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .border-slate-50 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .border-slate-200 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .border-slate-300 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .border-slate-900 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .text-gray-500 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .text-gray-600 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .text-gray-700 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .text-gray-800 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .bg-gray-50 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .bg-gray-900 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .border-gray-50 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .border-gray-200 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .border-gray-300 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .bg-blue-500 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.dark .hover\:text-gray-400:hover {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .hover\:text-gray-400:hover.nightwind-prevent {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .hover\:text-gray-400:hover {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .hover\:bg-gray-50:hover {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-50:hover.nightwind-prevent {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-50:hover {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-100:hover {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .hover\:bg-gray-100:hover.nightwind-prevent {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .hover\:bg-gray-100:hover {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .dark .dark\:text-white {
  color: rgba(0, 0, 0, var(--tw-text-opacity));
}

.dark .dark .dark\:text-white.nightwind-prevent {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:text-white {
  color: rgba(255, 255, 255, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-50 {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-50.nightwind-prevent {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:text-gray-50 {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-200 {
  color: rgba(66, 74, 83, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-200.nightwind-prevent {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:text-gray-200 {
  color: rgba(208, 215, 222, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-400 {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-400.nightwind-prevent {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:text-gray-400 {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-900 {
  color: rgba(246, 248, 250, var(--tw-text-opacity));
}

.dark .dark .dark\:text-gray-900.nightwind-prevent {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:text-gray-900 {
  color: rgba(36, 41, 47, var(--tw-text-opacity));
}

.dark .dark .dark\:bg-slate-700 {
  background-color: rgba(208, 215, 222, var(--tw-bg-opacity));
}

.dark .dark .dark\:bg-slate-700.nightwind-prevent {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:bg-slate-700 {
  background-color: rgba(66, 74, 83, var(--tw-bg-opacity));
}

.dark .dark .dark\:bg-slate-900 {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .dark .dark\:bg-slate-900.nightwind-prevent {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:bg-slate-900 {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .dark .dark\:border-slate-50 {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .dark .dark\:border-slate-50.nightwind-prevent {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:border-slate-50 {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .dark .dark\:border-slate-900 {
  border-color: rgba(246, 248, 250, var(--tw-border-opacity));
}

.dark .dark .dark\:border-slate-900.nightwind-prevent {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:border-slate-900 {
  border-color: rgba(36, 41, 47, var(--tw-border-opacity));
}

.dark .dark .dark\:border-gray-700 {
  border-color: rgba(208, 215, 222, var(--tw-border-opacity));
}

.dark .dark .dark\:border-gray-700.nightwind-prevent {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:border-gray-700 {
  border-color: rgba(66, 74, 83, var(--tw-border-opacity));
}

.dark .dark .dark\:hover\:text-gray-500:hover {
  color: rgba(140, 149, 159, var(--tw-text-opacity));
}

.dark .dark .dark\:hover\:text-gray-500:hover.nightwind-prevent {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:hover\:text-gray-500:hover {
  color: rgba(110, 119, 129, var(--tw-text-opacity));
}

.dark .dark .dark\:hover\:bg-slate-800:hover {
  background-color: rgba(234, 238, 242, var(--tw-bg-opacity));
}

.dark .dark .dark\:hover\:bg-slate-800:hover.nightwind-prevent {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:hover\:bg-slate-800:hover {
  background-color: rgba(50, 56, 63, var(--tw-bg-opacity));
}

.dark .dark .dark\:hover\:bg-slate-900:hover {
  background-color: rgba(246, 248, 250, var(--tw-bg-opacity));
}

.dark .dark .dark\:hover\:bg-slate-900:hover.nightwind-prevent {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.dark .nightwind-prevent-block .dark .dark\:hover\:bg-slate-900:hover {
  background-color: rgba(36, 41, 47, var(--tw-bg-opacity));
}

.hover\:bg-gray-100:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(234 238 242 / var(--tw-bg-opacity));
}

.hover\:bg-gray-50:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(246 248 250 / var(--tw-bg-opacity));
}

.hover\:text-gray-400:hover {
  --tw-text-opacity: 1;
  color: rgb(140 149 159 / var(--tw-text-opacity));
}

.nightwind .hover\:text-gray-400:hover {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .hover\:bg-gray-50:hover {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .hover\:bg-gray-100:hover {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.focus\:outline-none:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
}

.focus\:ring-2:focus {
  --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);
  --tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);
  box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);
}

.focus\:ring-blue-600:focus {
  --tw-ring-opacity: 1;
  --tw-ring-color: rgb(37 99 235 / var(--tw-ring-opacity));
}

.focus\:ring-offset-2:focus {
  --tw-ring-offset-width: 2px;
}

.focus\:ring-offset-white:focus {
  --tw-ring-offset-color: #fff;
}

.hs-tooltip.show .hs-tooltip-shown\:visible {
  visibility: visible;
}

.hs-tooltip.show .hs-tooltip-shown\:opacity-100 {
  opacity: 1;
}

.hs-collapse.open .hs-collapse-open\:block {
  display: block;
}

.hs-collapse.open .hs-collapse-open\:hidden {
  display: none;
}

.hs-collapse.open .hs-collapse-open\:rotate-90 {
  --tw-rotate: 90deg;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.hs-collapse.open.hs-collapse-open\:block {
  display: block;
}

.hs-collapse.open.hs-collapse-open\:hidden {
  display: none;
}

.hs-collapse.open.hs-collapse-open\:rotate-90 {
  --tw-rotate: 90deg;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.hs-collapse-toggle.open .hs-collapse-open\:block {
  display: block;
}

.hs-collapse-toggle.open .hs-collapse-open\:hidden {
  display: none;
}

.hs-collapse-toggle.open .hs-collapse-open\:rotate-90 {
  --tw-rotate: 90deg;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.hs-collapse-toggle.open.hs-collapse-open\:block {
  display: block;
}

.hs-collapse-toggle.open.hs-collapse-open\:hidden {
  display: none;
}

.hs-collapse-toggle.open.hs-collapse-open\:rotate-90 {
  --tw-rotate: 90deg;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.dark .dark\:divide-gray-700 > :not([hidden]) ~ :not([hidden]) {
  --tw-divide-opacity: 1;
  border-color: rgb(66 74 83 / var(--tw-divide-opacity));
}

.dark .dark\:border-foreground {
  --tw-border-opacity: 1;
  border-color: rgb(13 17 23 / var(--tw-border-opacity));
}

.dark .dark\:border-gray-700 {
  --tw-border-opacity: 1;
  border-color: rgb(66 74 83 / var(--tw-border-opacity));
}

.dark .dark\:border-slate-900 {
  --tw-border-opacity: 1;
  border-color: rgb(36 41 47 / var(--tw-border-opacity));
}

.dark .dark\:border-slate-50 {
  --tw-border-opacity: 1;
  border-color: rgb(246 248 250 / var(--tw-border-opacity));
}

.dark .dark\:bg-foreground {
  --tw-bg-opacity: 1;
  background-color: rgb(13 17 23 / var(--tw-bg-opacity));
}

.dark .dark\:bg-foreground\/\[\.7\] {
  background-color: rgb(13 17 23 / .7);
}

.dark .dark\:bg-slate-700 {
  --tw-bg-opacity: 1;
  background-color: rgb(66 74 83 / var(--tw-bg-opacity));
}

.dark .dark\:bg-slate-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(36 41 47 / var(--tw-bg-opacity));
}

.dark .dark\:bg-opacity-80 {
  --tw-bg-opacity: 0.8;
}

.dark .dark\:text-background {
  --tw-text-opacity: 1;
  color: rgb(240 243 246 / var(--tw-text-opacity));
}

.dark .dark\:text-gray-200 {
  --tw-text-opacity: 1;
  color: rgb(208 215 222 / var(--tw-text-opacity));
}

.dark .dark\:text-gray-400 {
  --tw-text-opacity: 1;
  color: rgb(140 149 159 / var(--tw-text-opacity));
}

.dark .dark\:text-white {
  --tw-text-opacity: 1;
  color: rgb(255 255 255 / var(--tw-text-opacity));
}

.dark .dark\:text-foreground {
  --tw-text-opacity: 1;
  color: rgb(13 17 23 / var(--tw-text-opacity));
}

.dark .dark\:text-gray-900 {
  --tw-text-opacity: 1;
  color: rgb(36 41 47 / var(--tw-text-opacity));
}

.dark .dark\:text-gray-50 {
  --tw-text-opacity: 1;
  color: rgb(246 248 250 / var(--tw-text-opacity));
}

.nightwind .dark .dark\:text-white {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:bg-slate-700 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:bg-slate-900 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:border-slate-50 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:border-slate-900 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:text-gray-50 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:text-gray-200 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:text-gray-400 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:text-gray-900 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:border-gray-700 {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.dark .dark\:hover\:bg-foreground:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(13 17 23 / var(--tw-bg-opacity));
}

.dark .dark\:hover\:bg-slate-800:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(50 56 63 / var(--tw-bg-opacity));
}

.dark .dark\:hover\:bg-slate-900:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(36 41 47 / var(--tw-bg-opacity));
}

.dark .dark\:hover\:text-gray-500:hover {
  --tw-text-opacity: 1;
  color: rgb(110 119 129 / var(--tw-text-opacity));
}

.nightwind .dark .dark\:hover\:bg-slate-800:hover {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:hover\:bg-slate-900:hover {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

.nightwind .dark .dark\:hover\:text-gray-500:hover {
  transition-duration: 300ms;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
}

@media (min-width: 640px) {
  .sm\:mt-0 {
    margin-top: 0px;
  }

  .sm\:block {
    display: block;
  }

  .sm\:flex {
    display: flex;
  }

  .sm\:hidden {
    display: none;
  }

  .sm\:grid-cols-2 {
    grid-template-columns: repeat(2, minmax(0, 1fr));
  }

  .sm\:flex-row {
    flex-direction: row;
  }

  .sm\:flex-nowrap {
    flex-wrap: nowrap;
  }

  .sm\:items-center {
    align-items: center;
  }

  .sm\:justify-start {
    justify-content: flex-start;
  }

  .sm\:justify-end {
    justify-content: flex-end;
  }

  .sm\:justify-between {
    justify-content: space-between;
  }

  .sm\:gap-6 {
    gap: 1.5rem;
  }

  .sm\:pl-5 {
    padding-left: 1.25rem;
  }

  .sm\:text-2xl {
    font-size: 1.5rem;
    line-height: 2rem;
  }
}

@media (min-width: 768px) {
  .md\:flex {
    display: flex;
  }

  .md\:w-1\/2 {
    width: 50%;
  }

  .md\:items-center {
    align-items: center;
  }

  .md\:justify-between {
    justify-content: space-between;
  }

  .md\:p-5 {
    padding: 1.25rem;
  }
}

@media (min-width: 1024px) {
  .lg\:grid-cols-4 {
    grid-template-columns: repeat(4, minmax(0, 1fr));
  }

  .lg\:py-6 {
    padding-top: 1.5rem;
    padding-bottom: 1.5rem;
  }
}